#Settings

'''

This file holds variables, values, lists, and
dictionaries for reference by other .py files.

Changes from previous version:
- Auto lower/upper case on keyboard
- Mark taps in/out of service
- Tap List screen functionality
- Add serving sizes/prices
- Recall previous beer info
- Create custom styles
- Improved formatting on Reports screen, added more On Tap stats
- Increased max number of taps from 10 to 18
- Click tap to bring up Tap Options GUI
- Increased text sizes
- Combo boxes adjust width of drop-down to fit text
- Removed sliders and slider range options
- Added 'View Files' button
- Improved start-up process (checks directories, files, images and reports results to History, updates data accordingly)
- Restricted ranges to Cellar entry boxes (forced min/max)
- Made screens and widgets adjust to min/maximized window size
- Add option to change size of Tap buttons
- 'Automatic' updates
- Add 'Check For Updates' button
- Add Emptied Date to batch info when saving to Log

'''


from os import path

#Root Window Settings
Title = "Keg Punk"
Favicon = path.join("img", "HalfBBL.ico")
Width = 800
Height = 480
Size = "800x480"

#Program Details
Program = "Keg Punk"
Version = "1.6"
PublishDate = "5Mar2021"
#Platform = "Windows"
Platform = "Pi"
Year = "2021"

FullDetails = Program + " " + Version + ", Published on " + PublishDate + ", Platform: " + Platform + ', Year: ' + str(Year)
List_VersionHeaders = ['Program', 'Version', 'Published On','Platform', 'Year']
Dict_VersionHeaders = {'Program':0, 'Version':1, 'Published On':2,'Platform':3, 'Year':4}

#Legal
Developer = "Arithmech LLC"
Creators = "Patrick Murphy"
Contributors = "Erin Murphy", "Johnathan Carter", "Philip Schaefer"
Initiated = "21Jan2021"

#Color Bank
B = "black"
W = "white"
Default = '#%02x%02x%02x' % (240, 240, 240) #Default

#Reds
R = 'red'
BF = '#%02x%02x%02x' % (218, 44, 56)  #Black Flag Red
WA = '#%02x%02x%02x' % (255, 71, 87) #Watermelon
BT = '#%02x%02x%02x' % (255, 99, 72) #Tomato

#Oranges
O = 'orange'
CO = '#%02x%02x%02x' % (255, 127, 80) #Coral
PM = '#%02x%02x%02x' % (255, 121, 63) #Pumpkin
MA = '#%02x%02x%02x' % (255, 177, 66) #Mandarin

#Yellows
Y = 'yellow'
SF = '#%02x%02x%02x' % (255, 195, 18) #Sunflower
TU = '#%02x%02x%02x' % (249, 202, 36) #Turbo
CS = '#%02x%02x%02x' % (254, 202, 87) #Casandra

#Greens
G = 'green'
TR = '#%02x%02x%02x' % (0, 98, 102) #Evergreen trees
UF = '#%02x%02x%02x' % (46, 213, 115) #UFO green
PL = '#%02x%02x%02x' % (33, 140, 116) #Palm

#Blues
BL = 'blue'
HB = '#%02x%02x%02x' % (62, 148, 218)  # Havelock Blue
DE = '#%02x%02x%02x' % (34, 112, 147) #Devil blue
FR = '#%02x%02x%02x' % (112, 161, 255) #French Sky

#Purples
P = 'purple'
PI = '#%02x%02x%02x' % (235, 123, 192) #Pink
KP = '#%02x%02x%02x' % (203, 156, 242)  #Kinda Pink
CT = '#%02x%02x%02x' % (112, 111, 211) #Cotton Candy
PU = '#%02x%02x%02x' % (44, 44, 84) #Twilight

#Greys
GR = 'grey'
SG = '#%02x%02x%02x' % (33, 33, 47)  # Steel Gray
SI = '#%02x%02x%02x' % (189, 195, 199) #Silver
GM = '#%02x%02x%02x' % (67, 80, 88)  #Gun Metal
AB = '#%02x%02x%02x' % (13, 19, 23)  #Almost Black

Dict_Colors = {'White':W, 'Black':B, 'Red':R, 'Red - Mosh Pit':BF, 'Red - Watermelon':WA, 'Red - Tomato':BT, 'Orange':O, 'Orange - Coral':CO, 'Orange - Pumpkin':PM, 'Orange - Mandarin':MA,
               'Yellow':Y, 'Yellow - Sunflower':SF, 'Yellow - Turbo':TU, 'Yellow - Sunrise': CS, 'Green':G, 'Green - Evergreen':TR, 'Green - UFO':UF, 'Green - Palm':PL,
               'Blue':BL, 'Blue - Havelock':HB, 'Blue - Devil':DE, 'Blue - French Sky':FR, 'Purple':P, 'Purple - Kinda Pink':KP, 'Purple - Cotton Candy':CT, 'Purple - Twilight':PU
               , 'Grey':GR, 'Grey - Steel':SG, 'Grey - Silver':SI, 'Grey - Gun Metal':GM, 'Grey - Almost Black':AB}

#Fonts
F1 = 'Lulo 8'
F2 = 'Lulo 8 bold'
F3 = 'Lulo 10'
F4 = 'Lulo 10 bold'
F5 = 'Lulo 12'
F6 = 'Lulo 12 bold'
F8 = 'Lulo 14 bold'
F10 = 'Lulo 16 bold'
F12 = 'Lulo 18 bold'
F14 = 'Lulo 20 bold'
F16 = 'Lulo 22 bold'
F18 = 'Lulo 24 bold'
F20 = 'Lulo 26 bold'
F22 = 'Lulo 28 bold'
F24 = 'Lulo 30 bold'
F26 = 'Lulo 32 bold'
F28 = 'Lulo 34 bold'
F30 = 'Lulo 36 bold'
F40 = 'Lulo 40 bold'
F60 = 'Lulo 60 bold'
F80 = 'Lulo 80 bold'
F100 = 'Lulo 100 bold'
F150 = 'Lulo 150 bold'
F200 = 'Lulo 200 bold'

#Other Values
MaxTaps = 19 #Subtract 1 (19 - 1 = 18 taps max)
NumTaps = list(range(1,MaxTaps)) #Number of taps in combobox (1 to MaxTaps)
TankTypes = ["5 Gal", "Sixtel", "Qtr-BBL", "Half-BBL", "Brite"]
Dict_TankVolumeGal = {'5 Gal':'5', 'Sixtel':'5.16', 'Qtr-BBL':'7.75', 'Half-BBL':'15.5'} #Dictionary for storing Tank/Volume pairs
VolumeUnits = ['Gal', 'BBL']
EntryTypes = ['Keyboard', 'Touch']
GallonsPerBBL = 31
ScreenSizes = ['Desktop', '7" Touchscreen']
Themes = ['Skate Park', 'Headliner', 'Mosh Pit']
DisplayInfo = ['Beer Only', 'Beer & Style', 'Beer & ABV', 'All']
Styles = ['BJCP', 'Basic Beer Styles', 'Custom']


#Tap List Options
FontSizes = [F6, F8, F10, F12, F14, F16, F18, F20, F22, F24, F26, F28, F30, F40, F60, F80, F100, F150, F200]
PadX = [0, 4, 8, 12, 16, 20, 24, 28, 32, 36, 40]
PadY = [0, 4, 8, 12, 16, 20, 24, 28, 32, 36, 40]
ListNames = ['ON TAP', 'TAP LIST', 'BEER', 'BEER LIST', 'DRAFT', 'DRAFT LIST', 'DRAFT BEER', 'DRAFT BEER LIST', 'MENU', 'DRAFT MENU', 'DRAFT BEER MENU', 'BEER MENU']
TopTitles = ['Name Only', 'Name + List Name', 'List Name + Name', 'List Name Only']
List_PresetThemes = ['Spy vs. Spy', 'Blackout', 'The Matrix', 'Mardi Gras', 'Mosh Pit']

#Directory/File Lists
List_Directories = ['img', 'Inventory', 'Options', 'Styles']
List_InventoryDirFiles = ['Archive.csv', 'CurrentInventory.csv', 'Log.csv', 'OnTap.csv']
List_PythonFiles = ['Main.py', 'Settings.py', 'Visuals.py']
List_OptionsDirFiles = ['Options.csv', 'Tap List Options.csv']
List_StylesDirFiles = ['BJCP Styles.csv', 'Basic Beer Styles.csv', 'Custom Styles.csv']
List_OtherFiles = ['HalfBBL.ico', 'Half-BBL.png', 'Ghost.png']

#Beer Styles List
List_BasicBeerStyles = ['Amber Ale', 'American Lager', 'Belgian Ale', 'Blonde Ale', 'Brown Ale', 'Fruit Beer', 'German Ale', 'German Lager', 'IPA', 'Octoberfest', 'Pale Ale', 'Pilsner', 'Porter', 'Red Ale', 'Saison', 'Sour', 'Stout', 'Wheat Beer']
List_BJCPStyles = ['Altbier', 'Alternative Grain Beer', 'Alternative Sugar Beer', 'Amber Kellerbier', 'American Amber Ale', 'American Barleywine', 'American Brown Ale', 'American IPA', 'American Lager'
                     , 'American Light Lager', 'American Pale Ale', 'American Porter', 'American Stout', 'American Strong Ale', 'American Wheat Beer', 'Australian Sparkling Ale', 'Autumn Seasonal Beer', 'Average Beer'
                     , 'Baltic Porter', 'Belgian Blond Ale', 'Belgian Dark Strong Ale', 'Belgian Dubbel', 'Belgian Golden Strong Ale', 'Belgian Pale Ale', 'Belgian Tripel', 'Berliner Weisse', 'Best Bitter', 'Biere de Garde'
                     , 'Blonde Ale', 'Brett Beer', 'British Brown Ale', 'British Golden Ale', 'British Strong Ale', 'Burton Ale', 'California Common', 'Catharina Sour', 'Classic Style Smoked Beer', 'Clone Beer', 'Cream Ale'
                     , 'Czech Amber Lager', 'Czech Dark Lager', 'Czech Pale Lager', 'Czech Premium Pale Lager', 'Dark Mild', 'Doppelbock', 'Double IPA', 'Dunkles Bock', 'Dunkles Weissbier', 'Eisbock'
                     , 'English Barleywine', 'English IPA', 'English Porter', 'Experimental Beer', 'Festbier', 'Flanders Red Ale', 'Foreign Extra Stout', 'Fruit and Spice Beer', 'Fruit Beer', 'Fruit Lambic', 'German Helles Exportbier'
                     , 'German Leichtbier', 'German Pils', 'Gose', 'Gueuze', 'Helles Bock', 'Imperial Stout', 'International Amber Lager', 'International Dark Lager', 'International Pale Lager'
                     , 'Irish Extra Stout', 'Irish Red Ale', 'Irish Stout', 'Kentucky Common', 'Kolsch', 'Lambic', 'Lichtenhainer', 'London Brown Ale', 'Marzen', 'Median Beer', 'Mixed-Fermentation Sour Beer', 'Mixed-Style Beer'
                     , 'Munich Dunkel', 'Munich Helles', 'New England IPA', 'New Zealand Pilsner', 'Oatmeal Stout', 'Old Ale', 'Ordinary Bitter', 'Oud Bruin', 'Pale Kellerbier', 'Piwo Grodziskie', 'Pre-Prohibition Lager', 'Pre-Prohibition Porter'
                     , 'Rauchbier', 'Roggenbier', 'Sahti', 'Saison', 'Schwarzbier', 'Scottish Export', 'Scottish Heavy', 'Scottish Light', 'Specialty Fruit Beer', 'Specialty IPA - Belgian IPA', 'Specialty IPA - Black IPA', 'Specialty IPA - Brown IPA'
                     , 'Specialty IPA - Red IPA', 'Specialty IPA - Rye IPA', 'Specialty IPA - White IPA', 'Specialty Smoked Beer', 'Specialty Wood-Aged Beer', 'Spice, Herb, or Vegetable Beer', 'Strong Bitter', 'Sweet Stout'
                     , 'Trappist Single', 'Tropical Stout', 'Vienna Lager', 'Wee Heavy', 'Weissbier', 'Weizenbock', 'Wheatwine', 'Wild Specialty Beer', 'Winter Seasonal Beer', 'Witbier', 'Wood-Aged Beer']

#File Header Lists and Column Index Dictionaries
List_CurrentInventoryHeaders = ['Input Date', 'Beer Name', 'Brew Date', 'Batch', 'Style', 'ABV', 'Tank Type', 'Quantity', 'Tank Volume', 'Volume Unit', 'Total Volume', 'Description',
                                'Str_SizePrice']
Dict_CurrentInventoryColumn = {'Input Date':0, 'Beer Name':1, 'Brew Date':2, 'Batch':3, 'Style':4, 'ABV':5, 'Tank Type':6, 'Quantity':7, 'Tank Volume':8, 'Volume Unit':9, 'Total Volume':10,
                               'Description':11, 'Str_SizePrice':12}
List_OnTapHeaders = ['Tap', 'Input Date', 'Beer Name', 'Brew Date', 'Batch', 'Style', 'ABV', 'Tank Type', 'Quantity', 'Tank Volume', 'Volume Unit', 'Total Volume', 'Description', 'Str_SizePrice',
                     'On Tap Date']
Dict_OnTapColumn = {'Tap':0, 'Input Date':1, 'Beer Name':2, 'Brew Date':3, 'Batch':4, 'Style':5, 'ABV':6, 'Tank Type':7, 'Quantity':8, 'Tank Volume':9, 'Volume Unit':10, 'Total Volume':11,
                    'Description':12, 'Str_SizePrice':13, 'On Tap Date':14}
List_LogHeaders = ['Input Date', 'Beer Name', 'Brew Date', 'Batch', 'Style', 'ABV', 'Tank Type', 'Quantity', 'Tank Volume', 'Volume Unit', 'Allocate To', 'Empty Date', 'On Tap Date']
Dict_LogColumn = {'Input Date':0, 'Beer Name':1, 'Brew Date':2, 'Batch':3, 'Style':4, 'ABV':5, 'Tank Type':6, 'Quantity':7, 'Tank Volume':8, 'Volume Unit':9, 'Allocate To':10, 'Empty Date':11
                  , 'On Tap Date':12}
List_ArchiveHeaders = ['Input Date', 'Beer Name', 'Brew Date', 'Batch', 'Style', 'ABV', 'Tank Type', 'Quantity', 'Tank Volume', 'Volume Unit', 'Total Volume', 'Description', 'Str_SizePrice']
Dict_ArchiveColumn = {'Input Date':0, 'Beer Name':1, 'Brew Date':2, 'Batch':3, 'Style':4, 'ABV':5, 'Tank Type':6, 'Quantity':7, 'Tank Volume':8, 'Volume Unit':9, 'Total Volume':10,
                    'Description':11, 'Str_SizePrice':12}
List_OptionsHeaders = ['Number of Taps', 'Entry Type', 'Volume Unit', 'Theme', 'Display Info', 'Screen Size', 'Styles', 'Tap Size']
Dict_OptionsColumn = {'Number of Taps':0, 'Entry Type':1, 'Volume Unit':2, 'Theme':3, 'Display Info':4, 'Screen Size':5, 'Styles':6, 'Tap Size':7}
List_TapListOptionsHeaders = ['Beer Font Size', 'Style Font Size', 'SizePrice Font Size', 'PadX', 'PadY', 'Name', 'List Name', 'Top Title', 'Columns', 'Background Color', 'Top Background Color',
                              'Name Text Color', 'List Name Text Color', 'Beer Background Color', 'Beer Text Color', 'Style Background Color', 'Style Text Color', 'SizePrice Background Color',
                              'SizePrice Text Color', 'Name Font Size', 'List Name Font Size', 'Display Style', 'Display ABV', 'Display Description', 'Display Wrap', 'Description Font Size',
                              'Description Background Color', 'Description Text Color', 'Display Pricing', 'Preset Theme']
Dict_TapListOptionsColumn = {'Beer Font Size':0, 'Style Font Size':1, 'SizePrice Font Size':2, 'PadX':3, 'PadY':4, 'Name':5, 'List Name':6, 'Top Title':7, 'Columns':8, 'Background Color':9,
                             'Top Background Color':10, 'Name Text Color':11, 'List Name Text Color':12, 'Beer Background Color':13, 'Beer Text Color':14, 'Style Background Color':15,
                             'Style Text Color':16, 'SizePrice Background Color':17, 'SizePrice Text Color':18, 'Name Font Size':19, 'List Name Font Size':20, 'Display Style':21, 'Display ABV':22,
                             'Display Description':23, 'Display Wrap':24, 'Description Font Size':25, 'Description Background Color':26, 'Description Text Color':27, 'Display Pricing': 28
                             , 'Preset Theme':29}

#Previous Versions Lists
List_v1LogHeaders = ['Input Date', 'Beer Name', 'Brew Date', 'Batch', 'Style', 'ABV', 'Tank Type', 'Quantity', 'Tank Volume', 'Volume Unit', 'Total Volume', 'Allocate To']



#File Paths
Path_CurrentInventory = path.join('Inventory', 'CurrentInventory.csv') #Get path to CurrentInventory.csv
Path_OnTap = path.join('Inventory', 'OnTap.csv') #Get path to OnTap.csv
Path_Archive = path.join('Inventory', 'Archive.csv') #Get path to Archive.csv
Path_Log = path.join('Inventory', 'Log.csv') #Get path to Log.csv
Path_Options = path.join('Options', 'Options.csv') #Get path to Options.csv
Path_TapListOptions = path.join('Options', 'Tap List Options.csv') #Get path to Tap List Options.csv
Path_BJCPStyles = path.join('Styles', 'BJCP Styles.csv') #Get path to BJCP Styles.csv
Path_BasicBeerStyles = path.join('Styles', 'Basic Beer Styles.csv') #Get path to Basic Beer Styles.csv
Path_CustomStyles = path.join('Styles', 'Custom Styles.csv') #Get path to Custom Styles.csv

#Image Paths
Path_ImgSnowboarder = path.join('img', 'Snowboarder.png') #Get path to Snowboarder image
Path_ImgMicrophone = path.join('img', 'Microphone.png') #Get path to Microphone image
Path_ImgRecordPlayer = path.join('img', 'RecordPlayer.png') #Get path to RecordPlayer image
Path_ImgSkull = path.join('img', 'Skull.png') #Get path to Skull image
Path_ImgSmash = path.join('img', 'Smash.png') #Get path to Smash image
Path_ImgSpeaker = path.join('img', 'Speaker.png') #Get path to Speaker image
Path_ImgRules = path.join('img', 'Rules.png') #Get path to Rules image
Path_ImgSoundboard = path.join('img', 'Soundboard.png') #Get path to Soundboard image
Path_Img5Gal = path.join('img', '5 Gal.png') #Get path to 5 Gal image
Path_ImgSixtel = path.join('img', 'Sixtel.png') #Get path to Sixtel image
Path_ImgQtrBBL = path.join('img', 'Qtr-BBL.png') #Get path to Qtr-BBL image
Path_ImgHalfBBL = path.join('img', 'Half-BBL.png') #Get path to Half-BBL image
Path_ImgBrite = path.join('img', 'Brite.png') #Get path to Brite image
Path_ImgTap = path.join('img', 'Tap.png') #Get path to Tap image
Path_ImgSad = path.join('img', 'Sad.png') #Get path to Sad image
Path_ImgYay = path.join('img', 'Yay.png') #Get path to Yay image
Path_ImgDrumset = path.join('img', 'Drumset.png') #Get path to Drumset image
Path_ImgAmp = path.join('img', 'Amp.png') #Get path to Amp image
Path_ImgKick = path.join('img', 'Kick.png') #Get path to Kick image
Path_ImgExpand = path.join('img', 'Expand.png') #Get path to Expand image
Path_ImgSnowboarder2 = path.join('img', 'Snowboarder2.png') #Get path to Snowboarder2 image
Path_ImgTape = path.join('img', 'Tape.png') #Get path to Tape image
Path_ImgHazard = path.join('img', 'Hazard.png') #Get path to Hazard image
Path_ImgKickWhite = path.join('img', 'KickWhite.png') #Get path to Kick (White) image
Path_ImgFiles = path.join('img', 'Files.png') #Get path to Files image

#Default Options
Def_Taps = 3
Def_Entry = 'Touch'
Def_Units = 'Gal'
Def_Theme = 'Skate Park'
Def_Info = 'All'
Def_Screen = '7" Touchscreen'
Def_Styles = 'Custom'
Def_TapSize = 60

#Default Tap List Options
Def_BeerFontSize = 'Lulo 20 bold'
Def_StyleFontSize = 'Lulo 20 bold'
Def_SizePriceFontSize = 'Lulo 12 bold'
Def_PadX = 4
Def_PadY = 4
Def_Name = 'Brewery Name?'
Def_ListName = "Draft List"
Def_TopTitle = 'List Name + Name'
Def_Columns = 1
Def_BackgroundColor = 'Black'
Def_TopBackgroundColor = 'Black'
Def_NameTextColor = 'White'
Def_ListNameTextColor = 'White'
Def_BeerBackgroundColor = 'Black'
Def_BeerTextColor = 'White'
Def_StyleBackgroundColor = 'Black'
Def_StyleTextColor = 'White'
Def_SizePriceBackgroundColor = 'Black'
Def_SizePriceTextColor = 'White'
Def_NameFontSize = 'Lulo 20 bold'
Def_ListNameFontSize = 'Lulo 20 bold'
Def_DisplayStyle = 'Yes'
Def_DisplayABV = 'Yes'
Def_DisplayDescription = 'Yes'
Def_DisplayWrap = 5
Def_DescriptionFontSize = 'Lulo 12 bold'
Def_DescriptionBackgroundColor = 'Black'
Def_DesriptionTextColor = 'White'
Def_DisplayPricing = 'Yes'
Def_PresetTheme = 'Blackout'