#Visuals

'''

This file builds and controls widgets and
other visuals for all screens of Keg Punk.

'''

import tkinter as tk
from PIL import ImageTk, Image
from tkcalendar import DateEntry
from Settings import *
from tkinter import ttk
import csv
from datetime import datetime
import datetime
import tkinter.font as tkFont
import pandas as pd
import traceback
import sys
from datetime import date

#Tap Status (Handles function directly linked to Taproom screen buttons)
class TapStatus:

    #Build taps (top/bottom label, tap image, tank image)
    def BuildTaps(self, NumTaps, Frame, Root, Size):

        '''
        This function creates 3 different Dictionaries to store and look up info about each tap.
        - self.Dict_TapFrame stores what frame each tap is in.
        - self.Dict_TapBeerInfo stores the beer info for each tap ("Empty" or Beer Info row)
        - self.Dict_TapTank stores what kind of tank each tap has on it.
        '''

        try:

            self.Frame_OnTap.update() #Update info for frame
            OnTapWidth = self.Frame_OnTap.winfo_width() #Get width in pixels of frame, this will be used to see if Tap Buttons fit with the selected size

            TapStatus.RootWindow = Root #Get root window (for use with Keyboard class)

            #Clear widgets in tap frame
            for wid in Frame.winfo_children():
                wid.destroy()

            TaproomManager.UpdateOnTapListbox(self) #Call function to open OnTap.csv and update On Tap listbox

            #Set up Frames and TapNum labels for each tap
            self.Dict_TapFrame = {} #Holds TapNum/Frame pairs (ex. - what frame is tap 1 in?)
            for tap in range(1,int(NumTaps) + 1):

                #If 5 taps or less, one row
                if tap <=6:
                    row = 0
                    column = tap
                if tap >6 and tap<=12: #If more than 5 taps, two rows
                    row = 1
                    column = tap - 6
                if tap >12:
                    row = 2
                    column = tap - 12

                #Create frame for each tap
                FrameName = tk.Frame(Frame, bg=self.BGColor)
                FrameName.grid(row = row, column = column, sticky = tk.N)

                '''
                self.Dict_TapFrame stores what frame each tap is in.
                The line below populates the TapFrame dictionary (created above) with TapNumber/FrameName pairs. This is critical to create AND update (if changes are made).
                This dictionary is used to place tap contents in the correct frame (when starting up program or changing screens) and look up what frame clicked tap is in.
                '''
                self.Dict_TapFrame[tap] = FrameName #Populate dictionary with TapNum/Frame pairs (used when looking up what frame clicked tap is in)

                #Create TapNum labels at top of each frame
                self.Lbl_TapNum = tk.Label(FrameName, text="TAP " + str(tap), font = F2, bg=self.BGColor, fg = self.Color).pack(side=tk.TOP, anchor = tk.N)

            '''
            self.Dict_TapBeerInfo stores the beer info for each tap ("Empty" or Beer Info row)
            The TapBeerInfo dictionary is initially set up as blank (ex. [Tap1:Empty, Tap2:Empty,...]). The dictionary is later updated after looking through OnTap file.
            If a tap is not empty, that tap/info pair is populated with the Beer Info. Beer Info row includes Tap, Beer Name, Style, and ABV. This is what is displayed
            below the tap tank image.
            
            self.Dict_TapTank stores what kind of tank each tap has on it.
            TapTank dictionary is initially empty and populated with TapNum/TankType pairs after reading through OnTap file. The dictionary stores tanks as their 
            name (5 gal., sixtel,...) or if nothing is on tap, it stores "Empty". This dictionary is used to look up what tank image is needed for each tap.
            '''

            self.Dict_TapBeerInfo = {}  # Set up a "blank" dictionary with TapNum/"Empty" pairs
            for tap in range(1, int(NumTaps) + 1):  # For the number of taps
                self.Dict_TapBeerInfo[tap] = "Empty"  # Create Tap/Empty pairs in dictionary

            self.Dict_TapTank = {}  # Start with empty dictionary

            TapStatus.AdjustTapSize(self)

            #Open OnTap file and update Dict_TapBeerInfo with what is on tap (Gets Tap, Beer Name, Style, and ABV), update Dict_TapTank
            with open(Path_OnTap) as csvfile:
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV)
                self.Rows = len(readCSV) #How many rows are in file? (How many on tap?)
                for i in range(0, self.Rows): #Loop through each row
                    TapNum = int(readCSV[i][Dict_OnTapColumn['Tap']]) #Tap Number
                    Beer = readCSV[i][Dict_OnTapColumn['Beer Name']] #Beer

                    if Beer == "Busted":
                        BeerRow = "Busted!"
                        pass
                    else:
                        Style = readCSV[i][Dict_OnTapColumn['Style']] #Style
                        ABV = readCSV[i][Dict_OnTapColumn['ABV']] #ABV

                        #Truncate length of string to fit under tank image (Only need to truncate Beer and Style since ABV will always be less than 14 characters)
                        if len(Beer) > TapStatus.Truncate:
                            Beer = Beer[0:TapStatus.Truncate - 3] + "..."
                        if len(Style) > TapStatus.Truncate:
                            Style = Style[0:TapStatus.Truncate - 3] + "..."

                        #Now that all Beer Info has been looked up, determine what info user has selected to display on each tap (from Options screen)
                        if self.Val_DisplayInfo == "Beer Only":
                            BeerRow = str(Beer)
                        elif self.Val_DisplayInfo == "Beer & Style":
                            BeerRow = str(Beer) + "\n" + str(Style)
                        elif self.Val_DisplayInfo == "Beer & ABV":
                            BeerRow = str(Beer)+ "\n" + str(ABV) + "%"
                        elif self.Val_DisplayInfo == "All":
                            BeerRow = str(Beer) + "\n" + str(Style) + "\n" + str(ABV) + "%"

                    #Update Dict_TapBeerInfo
                    self.Dict_TapBeerInfoUpdate = {TapNum: BeerRow} #Update dictionary with TapNum/BeerInfo pairs for non-empty taps. Leaves empty taps with TapNum/"Empty" pair.
                    self.Dict_TapBeerInfo.update(self.Dict_TapBeerInfoUpdate)

                    #Update Dict_TapTank with Non-Empty Tap/Tank pairs
                    TapNum = int(readCSV[i][Dict_OnTapColumn['Tap']]) #Get TapNum
                    TankType = readCSV[i][Dict_OnTapColumn['Tank Type']] #Get TankType
                    self.Dict_TapTank[TapNum] = TankType #Add TapNum/TankType pair to dictionary

            #Use Dict_TapBeerInfo to update Dict_TapTank for ALL taps (adds in Tap/"Empty" pairs)
            for TapNum in self.Dict_TapBeerInfo: #Loop through keys of Dict_TapBeerInfo
                Tank = self.Dict_TapBeerInfo[TapNum] #Get the value of the key
                if Tank == "Empty": #If the key (Tank) is "Empty"
                    self.Dict_TapTankUpdate = {TapNum: Tank} #Update Dict_TapTank with the TapNum/"Empty" pair
                    self.Dict_TapTank.update(self.Dict_TapTankUpdate)

            #Look up what kind of tank (if any) is on each tap, and add Beer Info label
            for TapNum in self.Dict_TapTank:  # Loop through dictionary
                TankType = self.Dict_TapTank[TapNum]  # Get the type of tank on each tap
                SelectedFrame = self.Dict_TapFrame[TapNum]  # Look up what frame current tap is in
                if TankType == "Empty":
                    bg = W #Set background color to White
                else:
                    bg = self.Color #Set background color to self.Color

                TapStatus.DrawButtonImage(self, SelectedFrame, TankType, bg, TapStatus.w, TapStatus.h, TapNum)  # Draw tap image, set on button
                self.Btn.pack(side=tk.TOP, padx=TapStatus.PadX, anchor=tk.N) #Add button to screen

                #Add Beer Info label under tank image
                BeerInfo = self.Dict_TapBeerInfo[TapNum] #Look up beer info by tap num
                self.Lbl_BeerInfo = tk.Label(SelectedFrame, text=BeerInfo, font = TapStatus.FontSize, bg=self.BGColor, fg = self.TextColor).pack(side=tk.TOP)  # Create label for beer info

            #Make sure tap buttons are not too big
            Frame.update()
            FrameWidth = Frame.winfo_width()  #Get the width in pixels of the frame holding all the taps

            Root.update()
            RootWidth = Root.winfo_width() #Get the width in pixels of the root window

            EmptySpace = RootWidth - (FrameWidth + OnTapWidth) #Calculate the space left between the tap frame on on tap frame

            #If the Empty Space is close to 0, the tap buttons may be sized too large
            if EmptySpace <10:
                ErrorHandling.ShowInfo(self, "Don't Crowd Me!", "The Tap Buttons are too big.\nGo to OPTIONS to make them smaller.")
            else:
                print("Tab buttons fit on page")

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue setting up the taps.")

    #Draw tank images and set on button
    def DrawButtonImage(self, Frame, Img, bg, w, h, TapNum):

        try:

            try:
                Path_Image = path.join('img', Img + ".png") #Get path to image
                render = ImageTk.PhotoImage(Image.open(Path_Image).resize((w, h)))  # Create and size image
            except:
                Path_Image = path.join('Ghost.png')  # Get path to image
                render = ImageTk.PhotoImage(Image.open(Path_Image).resize((w, h)))  # Create and size image

            img = tk.Label(Frame, image=render) #Create label from image
            img.image = render

            self.Btn = tk.Button(Frame, bg= bg, bd=1, image=img.image, command = lambda TapNum = TapNum: TapStatus.SelectTap(self, TapNum)) #Place label on button

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue loading a tap button.")

    #Click batch in Cellar listbox and get info
    def SelectAvailable(self, Listbox, Source):

        try:

            for item in Listbox.selection(): #Loop through batches in listbox and find batch highlighted
                RowIndex = Listbox.index(item) #Get row index of selected batch in listbox

            if Source == "CELLAR":
                CellarManager.ClickCellarListbox(self, RowIndex) #Call function to get index, batch, and configure "Delete" button

            elif Source == "Taproom":
                ListboxRow = CellarManager.List_AvailableInCellar[RowIndex]
                SelectedBatch = ListboxRow[0]
    
                with open(Path_CurrentInventory) as csvfile:
                    readCSV = csv.reader(csvfile, delimiter=',')
                    readCSV = list(readCSV)
                    rows = len(readCSV)  # How many rows are in the file?
    
                    if rows == 0:  # If rows == 0, this implies no beers in cellar
                        return  # End function
                    else:  # If there are beers in cellar
                        for i in range(0, rows):  # Loop through each row and look up Beer info
                            Batch = readCSV[i][Dict_CurrentInventoryColumn['Batch']]
                            if SelectedBatch == Batch:
                                RowIndex = i
                                TapStatus.SelectedRow = RowIndex

            TapStatus.AdjustTapSize(self)

            #Get the information of the selected batch
            with open(Path_CurrentInventory) as csvfile: #Open CurrentInventory.csv
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV) #Create list from file
                #Use CurrentInventory dictionary to look up column index value (the nth item in the row)
                self.InputDate = readCSV[RowIndex][Dict_CurrentInventoryColumn['Input Date']] #[Row][Column]
                self.Beer = readCSV[RowIndex][Dict_CurrentInventoryColumn['Beer Name']]
                self.BrewDate = readCSV[RowIndex][Dict_CurrentInventoryColumn['Brew Date']]
                self.Batch = readCSV[RowIndex][Dict_CurrentInventoryColumn['Batch']]
                self.Style = readCSV[RowIndex][Dict_CurrentInventoryColumn['Style']]
                self.ABV = readCSV[RowIndex][Dict_CurrentInventoryColumn['ABV']]
                self.TankType = readCSV[RowIndex][Dict_CurrentInventoryColumn['Tank Type']]
                self.Quantity = readCSV[RowIndex][Dict_CurrentInventoryColumn['Quantity']] #Current quantity in cellar
                self.TankVolume = readCSV[RowIndex][Dict_CurrentInventoryColumn['Tank Volume']]
                self.VolUnits = readCSV[RowIndex][Dict_CurrentInventoryColumn['Volume Unit']]
                self.TotalVolume = readCSV[RowIndex][Dict_CurrentInventoryColumn['Total Volume']]
                self.Description = readCSV[RowIndex][Dict_CurrentInventoryColumn['Description']]
                self.SizePrice = readCSV[RowIndex][Dict_CurrentInventoryColumn['Str_SizePrice']]

                self.Quantity = float(self.Quantity) - 1 #Convert string to float and subtract 1 (assuming user will put one keg of selected batch on tap)
                self.Quantity = int(self.Quantity) #Convert float to int (7.0 -> 7)

                #Used in SelectTap function for Current Inventory rows
                self.List_FullBeerInfoRow = [self.InputDate, self.Beer, self.BrewDate, self.Batch, self.Style, self.ABV, self.TankType, self.Quantity, self.TankVolume, self.VolUnits, self.TotalVolume, self.Description, self.SizePrice]

                # Truncate length of string to fit under tank image
                if len(self.Beer) > TapStatus.Truncate: #If beer name is greater than Truncate
                    self.Beer = self.Beer[0:TapStatus.Truncate-3] + "..."
                if len(self.Style) > TapStatus.Truncate: #If style is greater than Truncate
                    self.Style = self.Style[0:TapStatus.Truncate-3] + "..."

                # Determine what info user has selected to display on each tap (Options Tab - Display Info)
                if self.Val_DisplayInfo == "Beer Only":
                    self.Beer = str(self.Beer)
                elif self.Val_DisplayInfo == "Beer & Style":
                    self.Beer = str(self.Beer) + "\n" + str(self.Style)
                elif self.Val_DisplayInfo == "Beer & ABV":
                    self.Beer = str(self.Beer) + "\n" + str(self.ABV) + "%"
                elif self.Val_DisplayInfo == "All":
                    self.Beer = str(self.Beer) + "\n" + str(self.Style) + "\n" + str(self.ABV) + "%"

                TapStatus.Beer = self.Beer #This variable will be refernced in SelectTap function
                TapStatus.Batch = self.Batch #This variable will be refernced in SelectTap function

            try:
                TapStatus.Btn_AddToTap.config(state = tk.NORMAL) #If clicked empty tap, configure "Tap It!" button when user clicks in cellar listbox
            except:
                print("Full of Busted Tap") #If clicked full tap, don't do anything when user clicks in cellar listbox

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue when you clicked the Cellar listbox.")

    #Click tap image - do nothing, enable menu buttons, or loads tank type image and beer info, updates dictionaries
    def SelectTap(self, TapNum):

        try:

            self.CloseToplevels()

            TankOrEmpty = self.Dict_TapTank[TapNum] #Is the selected Tap "Empty" or a tank
            if TankOrEmpty == "Empty" or TankOrEmpty == "Skull": #If the tap is "Empty" or "Busted"

                SelectedFrame = self.Dict_TapFrame[TapNum]  # Look up what frame selected tap is in
                TapStatus.BuildTapOptions(self, TapNum, TankOrEmpty, SelectedFrame)
                return

            else: #If the tap is NOT empty, enable "EMPTY", "RETURN", and "CANCEL" buttons and end function
                SelectedFrame = self.Dict_TapFrame[TapNum] # Look up what frame selected tap is in
                TapStatus.BuildTapOptions(self, TapNum, TankOrEmpty, SelectedFrame)
                self.TapSelected = "True" #Set TapSelected variable to "True"
                return #End function

            # Since nothing currently on this tap and there is a selection from the listbox...
            SelectedFrame = self.Dict_TapFrame[TapNum] #Look up what frame selected tap is in

            #Clear any labels or button image already there (they will be replaced by label and image for selected batch)
            for wid in SelectedFrame.winfo_children(): #Loop through each widget in frame
                if wid.winfo_class() == "Button": #If widget is a button, destroy it
                    wid.destroy()
                elif wid.winfo_class() == "Label": #If widget is a label, destroy it
                    wid.destroy()

            #Create new label for TAP
            self.Lbl_TapNum = tk.Label(SelectedFrame, text="TAP " + str(TapNum), font=F2, fg = self.Color, bg = self.BGColor).pack(side=tk.TOP, anchor=tk.N)

            TapStatus.AdjustTapSize(self)

            #Draw tank image and put on button
            TapStatus.DrawButtonImage(self, SelectedFrame, self.TankType, self.Color, TapStatus.w, TapStatus.h, TapNum)  # Draw tank image
            self.Btn.pack(side=tk.TOP, padx=TapStatus.PadX) # Place button

            #Create label for Beer Info
            self.Lbl_BeerInfo = tk.Label(SelectedFrame, text= self.Beer, font = TapStatus.FontSize, fg = self.TextColor, bg = self.BGColor).pack(side=tk.TOP) # self.Beer comes from SelectAvailable function

            #Update CurrentInventory.csv and Cellar listbox
            TaproomManager.UpdateCurrentInventoryFile(self, self.List_FullBeerInfoRow) #Update CurrentInventory.csv (self.List_FullBeerInfoRow comes from SelectAvailable function)
            Remaining = self.List_FullBeerInfoRow[7] #How many kegs/tanks are left of this batch after adding one to On Tap?
            if Remaining == 0: #If there are no kegs/tanks remaining after putting one On Tap
                self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create DF from CurrentInventory file
                BatchIndex = self.DFCurrentInventory[self.DFCurrentInventory['Batch'] == TapStatus.Batch].index[0]  # Get the index of the row in the DF that has the same Batch
                self.DFCurrentInventory = self.DFCurrentInventory.drop(self.DFCurrentInventory.index[BatchIndex]) #Remove the row (since there are no kegs left)
                self.DFCurrentInventory.to_csv(Path_CurrentInventory, index=False, header=False)  # writes Dataframe back to csv
            CellarManager.UpdateCurrentInventoryListbox(self, "Taproom") #Call function to update the listbox

            #Update OnTap file and listbox
            self.List_FullBeerInfoRow.insert(0, TapNum) #Add TapNum as first element in list
            TaproomManager.SaveToOnTapFile(self, self.List_FullBeerInfoRow) #Call function to save to On Tap file
            TaproomManager.UpdateOnTapListbox(self) #Call function to update On Tap listbox

            # Update Dictionaries
            self.Dict_TapTankUpdate = {TapNum: str(self.TankType)} # Update Dict_TapTank with the TapNum/TankType pair
            self.Dict_TapTank.update(self.Dict_TapTankUpdate)

            self.Dict_TapBeerInfoUpdate = {TapNum: str(self.Beer)} # Update Dict_TapBeerInfo with the TapNum/BeerInfo pair
            self.Dict_TapBeerInfo.update(self.Dict_TapBeerInfoUpdate)

            self.Beer = "No Selection" #Reset self.Beer to nothing

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue when you clicked on a tap.")

    #If user clicks a tap button, build Tap Options GUI
    def BuildTapOptions(self, TapNum, Status, Frame):

        # Toplevel window
        TapStatus.Frame_TapOptions = tk.Toplevel(TapStatus.RootWindow)  # Create toplevel window
        TapStatus.Frame_TapOptions.title("TAP " + str(TapNum) + " Options")  # Assign window title
        if Platform == "Windows":
            TapStatus.Frame_TapOptions.grab_set()  # Prevents other Tkinter windows from being used

        x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
        y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root
        TapStatus.Frame_TapOptions.geometry("+%d+%d" % (x + 70, y + 100))  # Place Allocate window at these coordinates (roughly middle of root window)

        # Top/Bottom Frames
        Frame_Top = tk.Frame(TapStatus.Frame_TapOptions)
        Frame_Top.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE)
        Frame_TopLeft = tk.LabelFrame(Frame_Top, text="", font = F4)
        Frame_TopLeft.pack(side=tk.LEFT, fill=tk.BOTH, expand=tk.TRUE, padx=8, pady=8)
        Frame_TopRight = tk.LabelFrame(Frame_Top, text="TAP " + str(TapNum) + " OPTIONS", font = F4)
        Frame_TopRight.pack(side=tk.RIGHT, fill=tk.BOTH, expand=tk.TRUE, padx=8, pady=8)

        #Menu Buttons
        ImgWidth = 60
        ImgHeight = 60
        BtnWidth = 160
        BtnHeight = 40
        FontSize = F4

        #If selected tap is Empty
        if Status == "Empty" or Status == "Skull":

            CellarManager.BuildCurrentInventoryListbox(self, Frame_TopLeft, "Taproom") #Build Cellar listbox
            Frame_TopLeft.config(text = "IN CELLAR")

            # Add to Tap Button
            if Status == "Empty":
                try:
                    photo = ImageTk.PhotoImage(Image.open(Path_ImgTap).resize((ImgWidth, ImgHeight)))
                except:
                    photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                Lbl_Image = tk.Label(Frame_TopRight, image=photo)
                Lbl_Image.image = photo
                TapStatus.Btn_AddToTap = tk.Button(Frame_TopRight, text="TAP IT!", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color2, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                TapStatus.Btn_AddToTap.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.E)
                TapStatus.Btn_AddToTap.config(command=lambda: TapStatus.TapIt(self, TapNum, Frame))
                TapStatus.Btn_AddToTap.config(state=tk.DISABLED)
            elif Status == "Skull":
                pass

            #Tap Busted Button
            if Status == "Empty":
                try:
                    photo = ImageTk.PhotoImage(Image.open(Path_ImgSad).resize((ImgWidth, ImgHeight)))
                except:
                    photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                Lbl_Image = tk.Label(Frame_TopRight, image=photo)
                Lbl_Image.image = photo
                TapStatus.Btn_OutOfOrder = tk.Button(Frame_TopRight, text="TAP BUSTED!", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color2, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                TapStatus.Btn_OutOfOrder.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.E)
                TapStatus.Btn_OutOfOrder.config(command=lambda: TapStatus.TapBusted(self, TapNum, Frame))
            elif Status == "Skull":
                pass

            # In Order Button
            if Status == "Skull":
                try:
                    photo = ImageTk.PhotoImage(Image.open(Path_ImgYay).resize((ImgWidth, ImgHeight)))
                except:
                    photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                Lbl_Image = tk.Label(Frame_TopRight, image=photo)
                Lbl_Image.image = photo
                TapStatus.Btn_InOrder = tk.Button(Frame_TopRight, text="TAP FIXED!", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color2, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                TapStatus.Btn_InOrder.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.E)
                TapStatus.Btn_InOrder.config(command=lambda: TapStatus.TapFixed(self, TapNum, Frame))
            elif Status == "Empty":
                pass

        #If selected tap is NOT Empty
        else:

            Frame_TopLeft.config(text="SELECTED TAP")

            #Tap Info Labels
            List_InfoLabels = ["TAP - ", "INPUT DATE - ", "BEER - ", "BREW DATE - ", "BATCH - ", "STYLE - ", "% ABV - ", "TANK TYPE - ", "IN CELLAR - "]
            r = 0
            for Lbl in List_InfoLabels:
                Lbl_TapInfo = tk.Label(Frame_TopLeft, text = Lbl, font = F2)
                Lbl_TapInfo.grid(row = r, column = 0, sticky = tk.E)
                r = r + 1

            #Get Batch Info from selected tap
            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders)  # Create DF from OnTap file
            EmptyTapIndex = self.DFOnTap[self.DFOnTap['Tap'] == TapNum].index[0]  # Get the index of the row in the DF that has the same TapNum
            self.Batch = self.DFOnTap.iloc[EmptyTapIndex, 4]  # What batch is on this tap?
            self.List_BatchInfo = self.DFOnTap.loc[EmptyTapIndex, :].values.tolist()  # Create list from DF row (Used in Return function)
            self.List_BatchInfo = self.List_BatchInfo[:-3]

            #Tap info label values
            r = 0
            for Lbl in self.List_BatchInfo:
                if r > 8: #Only display the first 9 label values
                    pass
                else:
                    Lbl_TapInfoValue = tk.Label(Frame_TopLeft, text=Lbl)
                    Lbl_TapInfoValue.grid(row=r, column=1, sticky=tk.W)
                r = r + 1

            # Empty Button
            photo = ImageTk.PhotoImage(Image.open(Path_ImgRecordPlayer).resize((ImgWidth, ImgHeight)))
            Lbl_Image = tk.Label(Frame_TopRight, image=photo)
            Lbl_Image.image = photo
            TapStatus.Btn_Empty = tk.Button(Frame_TopRight, text="EMPTY", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color2, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
            TapStatus.Btn_Empty.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.E)
            TapStatus.Btn_Empty.config(command=lambda: TapStatus.MarkEmpty(self, TapNum, Frame, "Empty"))
            TapStatus.Btn_Empty.config(state=tk.NORMAL)

            # Return Button
            photo = ImageTk.PhotoImage(Image.open(Path_ImgMicrophone).resize((ImgWidth, ImgHeight)))
            Lbl_Image = tk.Label(Frame_TopRight, image=photo)
            Lbl_Image.image = photo
            TapStatus.Btn_Return = tk.Button(Frame_TopRight, text="RETURN", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color2, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
            TapStatus.Btn_Return.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.E)
            TapStatus.Btn_Return.config(command=lambda: TapStatus.Return(self, TapNum, Frame))
            TapStatus.Btn_Return.config(state=tk.NORMAL)

        #Cancel Button
        try:
            photo = ImageTk.PhotoImage(Image.open(Path_ImgSnowboarder).resize((ImgWidth, ImgHeight)))
        except:
            photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
        Lbl_Image = tk.Label(Frame_TopRight, image=photo)
        Lbl_Image.image = photo
        TapStatus.Btn_Cancel = tk.Button(Frame_TopRight, text="CANCEL", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color2, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
        TapStatus.Btn_Cancel.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.E)
        TapStatus.Btn_Cancel.config(command=lambda: TapStatus.Cancel(self, Frame))

    #User clicks "Tap It!" to add keg to tap
    def TapIt(self, TapNum, Frame):

        try:

            # Get todays date
            try:
                Date = date.today()  # Gets todays date in yyyy-mm-dd format
                format = "%m-%d-%y"
                Date = Date.strftime(format)  # Convert to mm-dd-yy format
            except:  # If unable to get date (not connected to Wifi) set as Date Unknown
                Date = "Date Unknown"

            # Clear any labels or button image already there (they will be replaced by label and image for selected batch)
            for wid in Frame.winfo_children():  # Loop through each widget in frame
                if wid.winfo_class() == "Button":  # If widget is a button, destroy it
                    wid.destroy()
                elif wid.winfo_class() == "Label":  # If widget is a label, destroy it
                    wid.destroy()

            # Create new label for TAP
            self.Lbl_TapNum = tk.Label(Frame, text="TAP " + str(TapNum), font=F2, fg=self.Color, bg=self.BGColor).pack(side=tk.TOP, anchor=tk.N)

            TapStatus.AdjustTapSize(self)

            # Draw tank image and put on button
            TapStatus.DrawButtonImage(self, Frame, self.TankType, self.Color, TapStatus.w, TapStatus.h, TapNum)  # Draw tank image
            self.Btn.pack(side=tk.TOP, padx=TapStatus.PadX)  # Place button

            # Create label for Beer Info
            self.Lbl_BeerInfo = tk.Label(Frame, text=self.Beer, font=TapStatus.FontSize, fg=self.TextColor, bg=self.BGColor).pack(side=tk.TOP)  # self.Beer comes from SelectAvailable function

            # Update CurrentInventory.csv and Cellar listbox
            TaproomManager.UpdateCurrentInventoryFile(self, self.List_FullBeerInfoRow)  # Update CurrentInventory.csv (self.List_FullBeerInfoRow comes from SelectAvailable function)
            Remaining = self.List_FullBeerInfoRow[Dict_CurrentInventoryColumn['Quantity']]  # How many kegs/tanks are left of this batch after adding one to On Tap?
            if Remaining == 0:  # If there are no kegs/tanks remaining after putting one On Tap
                self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create DF from CurrentInventory file
                BatchIndex = self.DFCurrentInventory[self.DFCurrentInventory['Batch'] == TapStatus.Batch].index[0]  # Get the index of the row in the DF that has the same Batch
                self.DFCurrentInventory = self.DFCurrentInventory.drop(self.DFCurrentInventory.index[BatchIndex])  # Remove the row (since there are no kegs left)
                self.DFCurrentInventory.to_csv(Path_CurrentInventory, index=False, header=False)  # writes Dataframe back to csv
            CellarManager.UpdateCurrentInventoryListbox(self, "Taproom")  # Call function to update the listbox

            # Update OnTap file and listbox
            self.List_FullBeerInfoRow.insert(Dict_OnTapColumn['Tap'], TapNum)  # Add TapNum as first element in list
            self.List_FullBeerInfoRow.insert(Dict_OnTapColumn['On Tap Date'], Date) #Add On Tap Date
            TaproomManager.SaveToOnTapFile(self, self.List_FullBeerInfoRow)  # Call function to save to On Tap file
            TaproomManager.UpdateOnTapListbox(self)  # Call function to update On Tap listbox

            # Update Dictionaries

            self.Dict_TapTankUpdate = {TapNum: str(self.TankType)}  # Update Dict_TapTank with the TapNum/TankType pair
            self.Dict_TapTank.update(self.Dict_TapTankUpdate)

            self.Dict_TapBeerInfoUpdate = {TapNum: str(self.Beer)}  # Update Dict_TapBeerInfo with the TapNum/BeerInfo pair
            self.Dict_TapBeerInfo.update(self.Dict_TapBeerInfoUpdate)

            self.Beer = "No Selection"  # Reset self.Beer to nothing

            TapStatus.Frame_TapOptions.destroy()

            try:
                TapList.CreateTapListScreen(self, TapStatus.RootWindow, "True")
            except:
                print("Tap List Not Visible")

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue when you clicked on a tap.")

    #Set tank and labels to "Empty", remove beer from On Tap listbox, update dictionaries, save to log
    def MarkEmpty(self, TapNum, Frame, Source):

        try:

            self.Beer = "No Selection" #Reset self.Beer to "No Selection"
            self.TapSelected = "False" #Reset self.TapSelected to "False"

            #Update Dictionaries for TapNum being marked as empty
            self.Dict_TapTankUpdate = {TapNum: "Empty"}  # Update Dict_TapTank with the TapNum/"Empty" pair
            self.Dict_TapTank.update(self.Dict_TapTankUpdate)

            self.Dict_TapBeerInfoUpdate = {TapNum: "Empty"}  # Update Dict_TapBeerInfo with the TapNum/"Empty" pair
            self.Dict_TapBeerInfo.update(self.Dict_TapBeerInfoUpdate)

            #Clear button and labels in frame
            for wid in Frame.winfo_children(): #Loop through each widget in frame
                if wid.winfo_class() == "Button": #If widget is a button, destroy it
                    wid.destroy()
                elif wid.winfo_class() == "Label": #If widget is a label, destroy it
                    wid.destroy()

            #Re-Create TapNum label on top
            self.Lbl_TapNum = tk.Label(Frame, text="TAP " + str(TapNum), font=F2, fg= self.Color, bg = self.BGColor).pack(side=tk.TOP, anchor=tk.N)

            TapStatus.AdjustTapSize(self)

            #Draw "Empty" tap button
            TapStatus.DrawButtonImage(self, Frame, "Empty", W, TapStatus.w, TapStatus.h, TapNum)
            self.Btn.pack(side=tk.TOP, padx=TapStatus.PadX)
            #"Empty" label on bottom
            self.Lbl_BeerInfo = tk.Label(Frame, text="Empty", font = TapStatus.FontSize, fg= self.TextColor, bg = self.BGColor).pack(side=tk.TOP)  # Create label for beer info

            # Remove beer from ON TAP listbox
            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders) #Create DF from OnTap file
            EmptyTapIndex = self.DFOnTap[self.DFOnTap['Tap'] == TapNum].index[0] #Get the index of the row in the DF that has the same TapNum
            self.Batch = self.DFOnTap.iloc[EmptyTapIndex, 4] #What batch is on this tap?
            self.List_BatchInfo = self.DFOnTap.loc[EmptyTapIndex, :].values.tolist() #Create list from DF row (Used in Return function)
            self.DFOnTap = self.DFOnTap.drop(self.DFOnTap.index[EmptyTapIndex]) #Remove this batch row
            self.DFOnTap.to_csv(Path_OnTap, index=False, header=False)  # writes Dataframe back to csv
            TaproomManager.UpdateOnTapListbox(self) #Call function to update On Tap listbox

            #Get todays date
            try:
                Date = date.today()  # Gets todays date in yyyy-mm-dd format
                format = "%m-%d-%y"
                Date = Date.strftime(format)  # Convert to mm-dd-yy format
                EmptyDate = Date
            except:  # If unable to get date (not connected to Wifi) set as Date Unknown
                Date = "Date Unknown"
                EmptyDate = Date

            #If Source is Empty (user clicked "Empty"), save to log. If Source is Return (user clicked "Return"), do NOT save to log.
            if Source == "Empty":
                
                #Delete things not being saved to Log (delete from highest index to lowest index)
                List_LogRow = self.List_BatchInfo
                OnTapDate = List_LogRow[Dict_OnTapColumn['On Tap Date']]

                List_NotInLogRow = ['On Tap Date','Str_SizePrice', 'Description', 'Total Volume', 'Tap']
                for ColumnHeader in List_NotInLogRow:
                    del List_LogRow[Dict_OnTapColumn[ColumnHeader]]

                #Add things being saved to Log
                List_LogRow.append("Taproom Draft") #Add Destination ("Allocate To") to log row (Either draft from taproom, or a destination from Allocation)
                List_LogRow.append(EmptyDate)  # Add Empty Date
                List_LogRow.append(OnTapDate)  # Add On Tap Date

                Reports.SaveToLog(self, List_LogRow) #Call function to save Emptied info to Log

            elif Source == "Return":
                print("User is returning a keg, do not save to log!")
            else:
                ErrorHandling.ShowError(self, "WTF?", "Source input should be either 'Empty' or 'Return' but is " + str(Source))

            TapStatus.Frame_TapOptions.destroy()

            try:
                TapList.CreateTapListScreen(self, TapStatus.RootWindow, "True")
            except:
                print("Tap List Not Visible")

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue with marking a tap as Empty.")

    #If user puts something on tap and then takes it off (return a keg to the cellar)
    def Return(self, TapNum, Frame):

        try:

            self.Beer = "No Selection" #Reset self.Beer to "No Selection"
            self.TapSelected = "False" #Reset self.TapSelected to "False"

            TapStatus.MarkEmpty(self, TapNum, Frame, "Return") #Call function to mark tap as empty and tells it NOT to save to log (since clicking Return instead of Empty)

            self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders) #Create data frame from CurrentInventory.csv

            try: #Check if there IS a row with the batch in CurrentInventory (Qnt > 0, implies there are still kegs left in the cellar)

                BatchIndex = self.DFCurrentInventory[self.DFCurrentInventory['Batch'] == self.Batch].index[0]  # Get the index of the row in the DF that has the same TapNum
                self.DFCurrentInventory = self.DFCurrentInventory.drop(self.DFCurrentInventory.index[BatchIndex]) #Drop outdated row
                self.DFCurrentInventory.to_csv(Path_CurrentInventory, index=False, header=False)  # writes Data to csv

                #Get Batch Info list back into correct format for adding back to cellar inventory
                List_BatchInfoToCurrentInventory = self.List_BatchInfo #Get Batch Info list from Mark Empty function
                #When deleting items from the list, make sure to delete items with higher indexes first (go from the end towards the front)
                del List_BatchInfoToCurrentInventory[Dict_OnTapColumn['On Tap Date']]  # Remove On Tap Date from list
                del List_BatchInfoToCurrentInventory[Dict_OnTapColumn['Tap']]  # Remove Tap from list

                #The list is now in the format of CurrentInventory.csv, use Dict_CurrentInventoryColumn
                Quantity = List_BatchInfoToCurrentInventory[Dict_CurrentInventoryColumn['Quantity']]  # Get the quantity (this is the "In Cellar" quantity value in the On Tap listbox)
                if Quantity == 0:  # Quantity should NOT be 0, but check anyway
                    pass
                else:
                    Quantity = Quantity + 1  # Add 1 to Quantity (this is the one you are returning)
                    List_BatchInfoToCurrentInventory[Dict_CurrentInventoryColumn['Quantity']] = Quantity  # Replace current Quantity with new Quantity

                    # Save it back to CurrentInventory
                    with open(Path_CurrentInventory, mode='a', newline='') as CurrentInventory_file:  # opens file with 'a' for append, does not overwrite anything already in it
                        CurrentInventory_writer = csv.writer(CurrentInventory_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                        CurrentInventory_writer.writerow(List_BatchInfoToCurrentInventory)

                    # Enable all other frames and widgets
                    for Frame in self.Dict_TapFrame.values():  # Loop through taps in self.Dict_TapFrame
                        for wid in Frame.winfo_children():  # Loop through widgets in the frame
                            wid.config(state=tk.NORMAL)  # Disable widget

            except: #There is NOT a row of this batch in Current Inventory (Qnt = 0, implies there are no kegs of the same batch in the cellar), add new row and set Qnt = 1

                # Get Batch Info list back into correct format for adding back to cellar inventory
                List_BatchInfoToCurrentInventory = self.List_BatchInfo  # Get Batch Info list from Mark Empty function
                # When deleting items from the list, make sure to delete items with higher indexes first (go from the end towards the front)
                del List_BatchInfoToCurrentInventory[Dict_OnTapColumn['On Tap Date']]  # Remove On Tap Date from list
                del List_BatchInfoToCurrentInventory[Dict_OnTapColumn['Tap']]  # Remove Tap from list

                # The list is now in the format of CurrentInventory.csv, use Dict_CurrentInventoryColumn
                Quantity = List_BatchInfoToCurrentInventory[Dict_CurrentInventoryColumn['Quantity']] #Get the quantity (should be 0)
                if Quantity == 0: #Quantity should be 0, but check anyway
                    Quantity = 1 #Add 1 to Quantity (this is the one you are returning)
                    List_BatchInfoToCurrentInventory[Dict_CurrentInventoryColumn['Quantity']] = Quantity #Replace current Quantity (0) with new Quantity (1)

                    # Save it back to CurrentInventory
                    with open(Path_CurrentInventory, mode='a', newline='') as CurrentInventory_file:  # opens file with 'a' for append, does not overwrite anything already in it
                        CurrentInventory_writer = csv.writer(CurrentInventory_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                        CurrentInventory_writer.writerow(List_BatchInfoToCurrentInventory)

                else:
                    ErrorHandling.ShowError(self, "Mismatch", "Batch does not have a row in CurrentInventory, but has a Quantity of " + str(Quantity))

            TapStatus.Frame_TapOptions.destroy()

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue with returning a keg to the cellar.")

    #User marks tap as Busted
    def TapBusted(self, TapNum, Frame):

        try:

            # Clear button and labels in frame
            for wid in Frame.winfo_children():  # Loop through each widget in frame
                if wid.winfo_class() == "Button":  # If widget is a button, destroy it
                    wid.destroy()
                elif wid.winfo_class() == "Label":  # If widget is a label, destroy it
                    wid.destroy()

            # Re-Create TapNum label on top
            self.Lbl_TapNum = tk.Label(Frame, text="TAP " + str(TapNum), font=F2, fg=self.Color, bg=self.BGColor).pack(side=tk.TOP, anchor=tk.N)

            TapStatus.AdjustTapSize(self)

            # Draw "Busted" tap button
            TapStatus.DrawButtonImage(self, Frame, "Skull", self.Color, TapStatus.w, TapStatus.h, TapNum)
            self.Btn.pack(side=tk.TOP, padx=TapStatus.PadX)
            # "Empty" label on bottom
            self.Lbl_BeerInfo = tk.Label(Frame, text="Busted!", font=TapStatus.FontSize, fg=self.TextColor, bg=self.BGColor).pack(side=tk.TOP)  # Create label for beer info

            # Update Dictionaries for TapNum being marked as empty
            self.Dict_TapTankUpdate = {TapNum: "Skull"}  # Update Dict_TapTank with the TapNum/"Empty" pair
            self.Dict_TapTank.update(self.Dict_TapTankUpdate)

            self.Dict_TapBeerInfoUpdate = {TapNum: "Skull"}  # Update Dict_TapBeerInfo with the TapNum/"Empty" pair
            self.Dict_TapBeerInfo.update(self.Dict_TapBeerInfoUpdate)

            # Update OnTap file and listbox
            self.List_FullBeerInfoRow = [TapNum, "", "Busted", "", "", "", "", "Skull", "", "", "", ""]
            TaproomManager.SaveToOnTapFile(self, self.List_FullBeerInfoRow)  # Call function to save to On Tap file

            TapStatus.Frame_TapOptions.destroy()

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue marking this tap as busted.")

    #User marks tap as Fixed
    def TapFixed(self, TapNum, Frame):

        try:

            # Clear button and labels in frame
            for wid in Frame.winfo_children():  # Loop through each widget in frame
                if wid.winfo_class() == "Button":  # If widget is a button, destroy it
                    wid.destroy()
                elif wid.winfo_class() == "Label":  # If widget is a label, destroy it
                    wid.destroy()

            # Re-Create TapNum label on top
            self.Lbl_TapNum = tk.Label(Frame, text="TAP " + str(TapNum), font=F2, fg=self.Color, bg=self.BGColor).pack(side=tk.TOP, anchor=tk.N)

            TapStatus.AdjustTapSize(self)

            # Draw "Busted" tap button
            TapStatus.DrawButtonImage(self, Frame, "Empty", W, TapStatus.w, TapStatus.h, TapNum)
            self.Btn.pack(side=tk.TOP, padx=TapStatus.PadX)
            # "Empty" label on bottom
            self.Lbl_BeerInfo = tk.Label(Frame, text="Empty", font=TapStatus.FontSize, fg=self.TextColor, bg=self.BGColor).pack(side=tk.TOP)  # Create label for beer info

            # Update Dictionaries for TapNum being marked as empty
            self.Dict_TapTankUpdate = {TapNum: "Empty"}  # Update Dict_TapTank with the TapNum/"Empty" pair
            self.Dict_TapTank.update(self.Dict_TapTankUpdate)

            self.Dict_TapBeerInfoUpdate = {TapNum: "Empty"}  # Update Dict_TapBeerInfo with the TapNum/"Empty" pair
            self.Dict_TapBeerInfo.update(self.Dict_TapBeerInfoUpdate)

            # Remove busted tap from ON TAP listbox
            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders)  # Create DF from OnTap file
            EmptyTapIndex = self.DFOnTap[self.DFOnTap['Tap'] == TapNum].index[0]  # Get the index of the row in the DF that has the same TapNum
            self.Batch = self.DFOnTap.iloc[EmptyTapIndex, 4]  # What batch is on this tap?
            self.List_BatchInfo = self.DFOnTap.loc[EmptyTapIndex, :].values.tolist()  # Create list from DF row (Used in Return function)
            self.DFOnTap = self.DFOnTap.drop(self.DFOnTap.index[EmptyTapIndex])  # Remove this batch row
            self.DFOnTap.to_csv(Path_OnTap, index=False, header=False)  # writes Dataframe back to csv
            TaproomManager.UpdateOnTapListbox(self)  # Call function to update On Tap listbox

            TapStatus.Frame_TapOptions.destroy()

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue marking this tap as busted.")

    #Disable bottom menu buttons and unhighlight an tap selected, set variables to no selection
    def Cancel(self, Frame):

        try:

            TapStatus.Frame_TapOptions.destroy()

            self.Beer = "No Selection" #Reset self.Beer to "No Selection"
            self.TapSelected = "False" #Reset self.TapSelected to "False"

            # Unhighlight beer info label
            for wid in Frame.winfo_children(): #Loop through all widgets in frame
                Wid_Type = wid.winfo_class() #Get class of widget (button, label, image, ...)
                if Wid_Type == "Label": #Loop through all labels in frame
                    Text = wid.cget('text') #Get the text of each label
                    if "TAP" in Text: #If the substring "TAP" is in the label text
                        if len(Text) == 5 or len(Text) == 6: #Check if the length is 5 or 6 characters (since "TAP X" is always 5 or 6 characters, ex. Tap 6 or Tap 10)
                            pass #If it is 5 or 6 characters, highly likely the label is the top TAP # label, so skip changing the color
                        else: #If the length is not 5 or 6 characters, assume the name of the beer has the substring "tap" in it (Like a beer named "Untapped Out")
                            wid.config(fg=self.TextColor) #Change color
                    else:
                        wid.config(fg = self.TextColor) #Change color

            # Enable all other frames and widgets
            for Frame in self.Dict_TapFrame.values():  # Loop through taps in self.Dict_TapFrame
                for wid in Frame.winfo_children():  # Loop through widgets in the frame
                    wid.config(state=tk.NORMAL)  # Disable widget

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue when you clicked Cancel.")

    # Get Size of tap buttons and set sizes for font and padding
    def AdjustTapSize(self):

        try:

            # Get Size of tap buttons and set sizes for font and padding
            Size = self.Val_TapSize
            Size = int(Size)  # Convert string to integer
            TapStatus.w = Size
            TapStatus.h = Size
    
            if Size < 80:
                TapStatus.PadX = 2
                TapStatus.FontSize = F1
                TapStatus.Truncate = 13
            elif Size >= 80 and Size < 100:
                TapStatus.PadX = 4
                TapStatus.FontSize = F2
                TapStatus.Truncate = 13
            elif Size >= 100 and Size < 120:
                TapStatus.PadX = 4
                TapStatus.FontSize = F4
                TapStatus.Truncate = 14
            elif Size >= 120 and Size < 140:
                TapStatus.PadX = 4
                TapStatus.FontSize = F4
                TapStatus.Truncate = 17
            elif Size >= 140 and Size < 160:
                TapStatus.PadX = 6
                TapStatus.FontSize = F4
                TapStatus.Truncate = 20
            elif Size >= 160 and Size < 180:
                TapStatus.PadX = 6
                TapStatus.FontSize = F6
                TapStatus.Truncate = 20
            elif Size >= 180 and Size <= 200:
                TapStatus.PadX = 8
                TapStatus.FontSize = F6
                TapStatus.Truncate = 22

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue adjusting the tap size.")

#Taproom Manager (Handles functions that support On Tap listbox and files for Current Inventory and On Tap)
class TaproomManager:

    #Build listbox that displays the beers currently on tap, tank type, and quantity remaining
    def BuildOnTapListbox(self, frame):

        try:

            # Set headers for listbox columns
            event_header = ['TAP','         BEER          ', '   TANK   ', 'IN CELLAR']

            # Creates multicolumn listbox
            self.Tree_OnTap = ttk.Treeview(frame, columns=event_header, show="headings")
            vsb = ttk.Scrollbar(frame, orient="vertical", command=self.Tree_OnTap.yview) #Set scrollbar
            self.Tree_OnTap.configure(yscrollcommand=vsb.set)
            self.Tree_OnTap.pack(side=tk.LEFT, fill=tk.BOTH, expand=True, anchor=tk.N)
            vsb.pack(side=tk.RIGHT, fill=tk.BOTH, anchor=tk.E)

            # adds header strings
            for col in event_header:
                self.Tree_OnTap.heading(col, text=col.title())
                self.Tree_OnTap.column(col, width=tkFont.Font().measure(col.title())) # adjust the column's width to the header string

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the On Tap listbox.")

    #Quickly adds Beer, Tank Type, and Quantity to On Tap listbox
    def UpdateOnTapListbox(self):

        try:

            #Clear all items in On Tap listbox
            for i in self.Tree_OnTap.get_children():
                self.Tree_OnTap.delete(i)

            TaproomManager.SortOnTapList(self) #Call function to sort On Tap list by Tap (Lowest to Highest)

            #Open OnTap.csv file
            with open(Path_OnTap) as csvfile:
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV)
                rows = len(readCSV) #How many rows are in the file?

                #Check if there are any beers on tap, if there are, look up info
                if rows == 0: #If rows == 0, this implies no beers on tap
                    return #End function
                else: #If there are beers on tap
                    for i in range(0, rows): #Loop through each row and look up Beer info
                        Tap = readCSV[i][Dict_OnTapColumn['Tap']] #[row index][column index]
                        Beer = readCSV[i][Dict_OnTapColumn['Beer Name']]

                        if Beer == "Busted":
                            pass
                        else:
                            TankType = readCSV[i][Dict_OnTapColumn['Tank Type']]
                            Qnt = readCSV[i][Dict_OnTapColumn['Quantity']]

                            BeerRow = [Tap, Beer, TankType, Qnt] #Create list that will be added to listbox as a single row
                            self.Tree_OnTap.insert('','end',values = BeerRow) #Add BeerRow to OnTap listbox

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue updating the On Tap listbox.")

    #Sort OnTap.csv rows by Tap (Lowest to Highest)
    def SortOnTapList(self):

        try:

            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders) #Create DF from OnTap file
            self.DFOnTapSorted = self.DFOnTap.sort_values(by='Tap', ascending=True) #Sort by Tap (low to high)
            self.DFOnTapSorted.to_csv(Path_OnTap, index=False, header=False)  # writes Data to csv

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue sorting the On Tap listbox.")

    #Sort CurrentInventory.csv by Qnt. (Lowest to Highest)
    def SortCurrentInventoryList(self):

        try:

            self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create DF from CurrentInventory file
            self.DFCurrentInventorySorted = self.DFCurrentInventory.sort_values(by='Quantity', ascending=True)  # Sort by Tap (low to high)
            self.DFCurrentInventorySorted.to_csv(Path_CurrentInventory, index=False, header=False)  # writes Data to csv

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue sorting the Cellar listbox.")

    #Creates DF from CurrentInventory file, removes selected batch row, writes updated row back to file
    def UpdateCurrentInventoryFile(self, FullBeerInfoRow):

        try:

            self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders) #Create Dataframe from CurrentInventory.csv
            self.DFCurrentInventory = self.DFCurrentInventory.drop(self.DFCurrentInventory.index[TapStatus.SelectedRow]) #Drop row with same index that was selected by user in listbox
            self.DFCurrentInventory.to_csv(Path_CurrentInventory, index=False, header=False)  # writes Data to csv

            #Save it to Current Inventory
            with open(Path_CurrentInventory, mode='a', newline='') as CurrentInventory_file:  # opens file with 'a' for append, does not overwrite anything already in it
                CurrentInventory_writer = csv.writer(CurrentInventory_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                CurrentInventory_writer.writerow(FullBeerInfoRow)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue updating the Current Inventory file.")

    #Save batch to the correct tap in the On Tap file
    def SaveToOnTapFile(self, FullBeerInfoRow):

        try:

            #Save it to On Tap
            with open(Path_OnTap, mode='a', newline='') as OnTap_file:  # opens file with 'a' for append, does not overwrite anything already in it
                OnTap_writer = csv.writer(OnTap_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                OnTap_writer.writerow(FullBeerInfoRow)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue saving to the On Tap file.")

#Cellar Manager (Handles functions for inputing/deleting batches and saving to inventory, and Cellar listbox)
class CellarManager:

    #Build entry widgets in Cellar screen
    def BuildEntryWidgets(self, LeftFrame, MiddleFrame, RightFrame, BottomFrame):

        try:

            LeftFrame.wait_visibility()
            MiddleFrame.wait_visibility()
            RightFrame.wait_visibility()

            #Set dimensions for widgets in Cellar screen
            if Platform == "Pi":
                ComboWidth = 13
                EntryWidth = 14
                PadX = 4
                PadY = 6
                FontSize = F8

            elif Platform == "Windows":
                ComboWidth = 24
                EntryWidth = 27

            #INPUT DATE label and date picker
            self.Lbl_InputDate = tk.Label(LeftFrame, text="INPUT\nDATE", fg=self.TextColor, bg=self.BGColor, font=F2, justify=tk.RIGHT)
            self.Lbl_InputDate.grid(row=0, column=0, sticky=tk.E)
            self.Pick_InputDate = DateEntry(LeftFrame, width=ComboWidth, foreground=W, borderwidth=2, state="readonly", font = FontSize)
            self.Pick_InputDate.grid(row=0, column=1, padx=PadX, pady=PadY, sticky=tk.W)
            self.Pick_InputDate.bind("<<DateEntrySelected>>", lambda event: Keyboard.ExitKeyboard(self))

            self.DFLog = pd.read_csv(Path_Archive, names=List_ArchiveHeaders)  # Create DF from Archive file
            List_AllBeers = self.DFLog['Beer Name'].to_list()  # Create list from "Beer Name" column
            List_AllBeers = list(set(List_AllBeers)) #Remove duplicates

            #BEER label and combo box
            self.Lbl_Beer = tk.Label(LeftFrame, text="BEER", fg=self.TextColor, bg=self.BGColor, font=F2, justify=tk.RIGHT)
            self.Lbl_Beer.grid(row=1, column=0, sticky=tk.E)
            self.In_Beer = tk.StringVar()
            self.Ent_Beer = tk.Entry(LeftFrame, textvariable=self.In_Beer, width=EntryWidth, font=FontSize)
            self.Ent_Beer.grid(row=1, column=1, padx=PadX, pady=PadY, sticky=tk.W)
            self.Ent_Beer.focus_set()

            if self.Val_EntryType == "Touch":
                self.Ent_Beer.bind("<Button-1>", lambda event: Keyboard.BuildKeyboard(self, TapStatus.RootWindow, "Cellar")) #If on Touch, and user clicks in Beer entry box, auto build keyboard

            #BREW DATE label and date picker
            self.Lbl_BrewDate = tk.Label(LeftFrame, text="BREW\nDATE", fg=self.TextColor, bg=self.BGColor, font=F2, justify=tk.RIGHT)
            self.Lbl_BrewDate.grid(row=2, column=0, sticky=tk.E)
            self.Pick_BrewDate = DateEntry(LeftFrame, width=ComboWidth, foreground=W, borderwidth=2, state="readonly", font = FontSize)
            self.Pick_BrewDate.grid(row=2, column=1, padx=PadX, pady=PadY, sticky=tk.W)

            #STYLE label and combo box
            if self.Val_Styles == "BJCP":
                file = Path_BJCPStyles
            elif self.Val_Styles == "Basic Beer Styles":
                file = Path_BasicBeerStyles
            elif self.Val_Styles == "Custom":
                file = Path_CustomStyles

            #open styles file
            with open(file) as csvfile: #Open correct styles file
                readCSV = csv.reader(csvfile, delimiter=',')
                List_Styles = []
                for row in readCSV: #Create list of styles by looping through each row
                    style = row[0]
                    List_Styles.append(style)

            #STYLE label and combo box
            self.Lbl_Style = tk.Label(MiddleFrame, text="STYLE", fg=self.TextColor, bg=self.BGColor, font=F2, justify=tk.RIGHT)
            self.Lbl_Style.grid(row=0, column=0, sticky=tk.E)
            self.Combo_Style = ttk.Combobox(MiddleFrame, values=sorted(List_Styles), width=ComboWidth+6, height = 13, font=FontSize)
            self.Combo_Style.grid(row=0, column=1, padx=PadX, pady=PadY, sticky=tk.W)
            self.Combo_Style.config(state="readonly")  # Don't allow user to type anything into combobox
            self.Combo_Style.bind("<<ComboboxSelected>>", lambda event: CellarManager.BuildAddCustomStyle(self, self.Combo_Style.get()))
            self.Combo_Style.option_add("*TCombobox*Listbox*Font", F8)  # THIS LINE SETS THE FONT SIZE FOR ALL COMBOBOXES
            self.Combo_Style.Sorted = True

            #TANK TYPE label and combo box
            self.Lbl_TankType = tk.Label(MiddleFrame, text="TANK\nTYPE", fg=self.TextColor, bg=self.BGColor, font = F2, justify=tk.RIGHT)
            self.Lbl_TankType.grid(row=1, column=0, sticky=tk.E)
            self.Combo_TankType = ttk.Combobox(MiddleFrame, values=TankTypes, width=ComboWidth+6, font = FontSize, state="readonly")
            self.Combo_TankType.grid(row=1, column=1, padx=PadX, pady=PadY, sticky=tk.W)
            self.Combo_TankType.bind("<<ComboboxSelected>>", lambda event: CellarManager.PickTank(self, self.Combo_TankType.get()))

            #QUANTITY label and entry box
            self.In_Quantity = tk.StringVar()
            self.Ent_Quantity = tk.Entry(MiddleFrame, textvariable=self.In_Quantity, width=EntryWidth+5, font = FontSize, state = tk.DISABLED)
            self.Ent_Quantity.grid(row=2, column=1, padx=PadX, sticky=tk.W, pady = PadY)
            self.In_Quantity.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_Quantity, "Integer", 1, 9999))  # allow integer values only
            self.Lbl_Quantity = tk.Label(MiddleFrame, text="QUANTITY", fg=self.TextColor, bg=self.BGColor, font=F2, justify=tk.RIGHT, state = tk.DISABLED)
            self.Lbl_Quantity.grid(row=2, column=0, sticky=tk.E)

            if self.Val_EntryType == "Touch":
                self.Ent_Quantity.bind("<Button-1>", lambda event: Keyboard.BuildKeyboard(self, TapStatus.RootWindow, "Cellar")) #If on Touch, and user clicks in entry box, auto build keyboard

            #BRITE VOLUME label and entry box
            self.In_BriteVolume = tk.StringVar()
            self.Ent_BriteVolume = tk.Entry(RightFrame, textvariable=self.In_BriteVolume, width=EntryWidth-5, font = FontSize, state=tk.DISABLED)
            self.Ent_BriteVolume.grid(row=0, column=1, padx=PadX, sticky=tk.W, pady = PadY)
            self.In_BriteVolume.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_BriteVolume, "Decimal", 1, 99999))  # allow decimal values only
            self.Lbl_BriteVolume = tk.Label(RightFrame, text="BRITE VOLUME\n(" + str(self.Val_VolumeUnit) + ")", fg=self.TextColor, bg=self.BGColor, font=F2, justify=tk.RIGHT, state=tk.DISABLED)
            self.Lbl_BriteVolume.grid(row=0, column=0, sticky=tk.E)

            if self.Val_EntryType == "Touch":
                self.Ent_BriteVolume.bind("<Button-1>", lambda event: Keyboard.BuildKeyboard(self, TapStatus.RootWindow, "Cellar")) #If on Touch, and user clicks in entry box, auto build keyboard

            #ABV label and entry box
            self.In_ABV = tk.StringVar()
            self.Ent_ABV = tk.Entry(RightFrame, textvariable=self.In_ABV, width=EntryWidth-5, font = FontSize)
            self.Ent_ABV.grid(row=1, column=1, sticky = tk.W, padx=PadX, pady = PadY)
            self.In_ABV.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_ABV, "Decimal", 0, 100))  # allow decimal values only
            self.Lbl_ABV = tk.Label(RightFrame, text="% ABV\n(0-100)", fg=self.TextColor, bg=self.BGColor, font=F2, justify=tk.RIGHT)
            self.Lbl_ABV.grid(row=1, column=0, sticky=tk.E)

            if self.Val_EntryType == "Touch":
                self.Ent_ABV.bind("<Button-1>", lambda event: Keyboard.BuildKeyboard(self, TapStatus.RootWindow, "Cellar")) #If on Touch, and user clicks in entry box, auto build keyboard

            #Menu Buttons
            BtnWidth = 8
            BtnHeight = 2
            PadX = 3
            PadY = 4

            CellarManager.RecalledDescription = ""
            CellarManager.RecalledSizePriceString = ""

            self.Btn_Recall = tk.Button(BottomFrame, text="RECALL", fg=self.TextColor2, bd=1, bg=self.Color2, font=F6, height=BtnHeight, width=BtnWidth, command=lambda: CellarManager.RecallMessageWindow(self))
            self.Btn_Recall.pack(side=tk.LEFT, anchor=tk.N, padx=PadX, pady=PadY)
            self.Btn_Details = tk.Button(BottomFrame, text="DETAILS", fg=self.TextColor2, bd=1, bg=self.Color2, font=F6, height=BtnHeight, width=BtnWidth, command=lambda: CellarManager.BuildDetails(self, "Cellar", "", ""))
            self.Btn_Details.pack(side=tk.LEFT, anchor=tk.N, padx=PadX, pady=PadY)
            self.Btn_Save = tk.Button(BottomFrame, text="SAVE", fg=self.TextColor2, bd=1, bg=self.Color2, font=F6, height=BtnHeight, width=BtnWidth, command=lambda: CellarManager.AddtoInventory(self))
            self.Btn_Save.pack(side=tk.LEFT, anchor=tk.N, padx=PadX, pady=PadY)
            self.Btn_Clear = tk.Button(BottomFrame, text="CLEAR", fg=self.TextColor2, bd=1, bg=self.Color2, font=F6, height=BtnHeight, width=BtnWidth, command=lambda: CellarManager.ClearEntry(self))
            self.Btn_Clear.pack(side=tk.LEFT, anchor=tk.N, padx=PadX, pady=PadY)
            self.Btn_Delete = tk.Button(BottomFrame, text="DELETE", fg=self.TextColor2, bd=1, bg=self.Color2, font=F6, height=BtnHeight, width=BtnWidth, state=tk.DISABLED, command=lambda: CellarManager.Delete(self))
            self.Btn_Delete.pack(side=tk.LEFT, anchor=tk.N, padx=PadX, pady=PadY)
            self.Btn_Allocate = tk.Button(BottomFrame, text="ALLOCATE", fg=self.TextColor2, bd=1, bg=self.Color2, font=F6, height=BtnHeight, width=BtnWidth, state=tk.DISABLED, command=lambda: CellarManager.BuildAllocate(self))
            self.Btn_Allocate.pack(side=tk.LEFT, anchor=tk.N, padx=PadX, pady=PadY)

            self.Frame_BottomFrame = BottomFrame

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the entry widgets.")

    #Gets value of slider widgets and configures label text (if you move a slider, the label value updates)
    def AdjustValue(self, Metric, Variable):

        try:

            Keyboard.ExitKeyboard(self)  # Exit Keyboard (if up)

            Value = Variable.get() #Get value from slider
            if Metric == "ABV": #If changing ABV, configure label with slider value
                self.Lbl_ABV.config(text = str(Metric) + "\n" + str(Value) + "%")
            elif Metric == "QUANTITY": #If changing QUANTITY, configure label with slider value
                self.Lbl_Quantity.config(text = str(Metric) + "\n" + str(Value))
            elif Metric == "BRITE VOLUME": #If changing BRITE VOLUME, configure label with slider value
                self.Lbl_BriteVolume.config(text = str(Metric) + "\n" + str(Value) + " " + str(self.Val_VolumeUnit))

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue adjusting the value of the " + str(Metric) + " slider.")

    #Build Details GUI
    def BuildDetails(self, Source, Description, SizePrice):

        try:

            self.CloseToplevels()

            #Try to get the Description and SizePrice values from SaveDetails function (these will only exist if have saved details in the same Cellar 'Session')
            if Source == "Cellar":
                try:
                    SizePrice = CellarManager.Str_SizePrice
                    Description = CellarManager.Description
                except:
                    print("No details saved this session")

            #If nothing has been previously saved this Cellar session
            if SizePrice == "": #If SizePrice is blank, nothing is saved
                List_RecalledSizes = [] #Create blank list since nothing saved previously
            else:
                #Convert SizePriceString into a dictionary with Size/Price pairs
                Dict_RecalledSizePrice = {} #Create empty dictionary
                for group in SizePrice.split(","): #Split the string into groups at each comma
                    group = group.replace(" ", "") #Remove spaces
                    group = group.replace("$", "") #Remove $ signs
                    if group == "": #If group is blank, disregard
                        pass
                    else: #If group not blank
                        w = 1
                        for word in group.split("-"): #Split group into two words at "-" sign
                            if w%2 == 1: #if this is the first word in the group
                                Size = word #then it's the size
                            else: #if it's not the first word, then it is the second word and is the price
                                Price = word
                            w = w + 1

                        Dict_RecalledSizePrice[Size] = Price #Add Size/Price pair to dictionary

                List_RecalledSizes = Dict_RecalledSizePrice.keys()

            # Toplevel window
            self.Frame_Details = tk.Toplevel(TapStatus.RootWindow)  # Create toplevel window
            self.Frame_Details.title("Details")
            if self.Val_ScreenSize == '7" Touchscreen': #If option set to run on 7" Touchsceen:
                self.Frame_Details.wm_attributes('-fullscreen', 'true')  # Removes border and title bar from toplevel
            if self.Val_ScreenSize == "Desktop":
                self.Frame_Details.resizable(False, False)  # Do not allow resizing details window

            if Platform == "Windows":
                self.Frame_Details.grab_set()  # Prevents other Tkinter windows from being used

            x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
            y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root
            self.Frame_Details.geometry("+%d+%d" % (x + 10, y + 10))  # Place message window at these coordinates (roughly middle of root window)

            GUIBG = SI

            #Frames
            self.Frame_DetailsTop = tk.Frame(self.Frame_Details, bg = GUIBG)
            self.Frame_DetailsTop.pack(side = tk.TOP, fill = tk.X, expand = tk.TRUE, anchor = tk.N)
            self.Frame_DetailsKeyboard = tk.Frame(self.Frame_Details, bg = GUIBG)
            self.Frame_DetailsKeyboard.pack(side=tk.TOP, fill=tk.X, expand=tk.TRUE, anchor = tk.S)
            self.Frame_DetailsBottom = tk.Frame(self.Frame_Details, bg = GUIBG)
            self.Frame_DetailsBottom.pack(side=tk.BOTTOM, fill=tk.X, expand=tk.TRUE, anchor = tk.S)

            self.Frame_DetailsTopDescription = tk.Frame(self.Frame_DetailsTop)
            self.Frame_DetailsTopDescription.pack(side=tk.TOP, fill=tk.X, expand=tk.TRUE, anchor = tk.W)
            self.Frame_DetailsTopPricing = tk.Frame(self.Frame_DetailsTop)
            self.Frame_DetailsTopPricing.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE, anchor = tk.E)

            self.Frame_DetailsTopDescriptionLabel = tk.Frame(self.Frame_DetailsTopDescription, bg = self.Color)
            self.Frame_DetailsTopDescriptionLabel.pack(side=tk.TOP, fill=tk.X, expand=tk.FALSE, anchor = tk.N)
            self.Frame_DetailsTopDescriptionEntry = tk.Frame(self.Frame_DetailsTopDescription, bg = GUIBG)
            self.Frame_DetailsTopDescriptionEntry.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE, anchor = tk.N)

            self.Frame_DetailsTopPricingLabel = tk.Frame(self.Frame_DetailsTopPricing, bg=self.Color)
            self.Frame_DetailsTopPricingLabel.pack(side=tk.TOP, fill=tk.X, expand=tk.TRUE, anchor = tk.N)
            self.Frame_DetailsTopPricingWidgets = tk.Frame(self.Frame_DetailsTopPricing, bg = GUIBG)
            self.Frame_DetailsTopPricingWidgets.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE)
            self.Frame_DetailsTopPricingWidgetsLeft = tk.Frame(self.Frame_DetailsTopPricingWidgets, bg = GUIBG)
            self.Frame_DetailsTopPricingWidgetsLeft.pack(side=tk.LEFT, fill=tk.Y, expand=tk.TRUE, padx = 4)
            self.Frame_DetailsTopPricingWidgetsMiddle = tk.Frame(self.Frame_DetailsTopPricingWidgets, bg=GUIBG)
            self.Frame_DetailsTopPricingWidgetsMiddle.pack(side=tk.LEFT, fill=tk.Y, expand=tk.TRUE, padx=4)
            self.Frame_DetailsTopPricingWidgetsRight = tk.Frame(self.Frame_DetailsTopPricingWidgets, bg = GUIBG)
            self.Frame_DetailsTopPricingWidgetsRight.pack(side=tk.RIGHT, fill=tk.Y, expand=tk.TRUE, padx = 4)

            #Detailed Description label and entry text box
            self.Lbl_Description = tk.Label(self.Frame_DetailsTopDescriptionLabel, text="DETAILED DESCRIPTION", fg=self.TextColor2, bg=self.Color, font=F4)
            self.Lbl_Description.pack()
            self.Ent_Description = tk.Entry(self.Frame_DetailsTopDescriptionEntry, width = 88)
            self.Ent_Description.pack(side = tk.LEFT, padx = 4, pady = 4, anchor = tk.W)
            self.Ent_Description.insert(0, Description)
            #Clear Button for description entry box
            self.Btn_ClearDescription = tk.Button(self.Frame_DetailsTopDescriptionEntry, text = "CLEAR", font = F2, fg = self.TextColor2, bg = self.Color2, command = lambda: self.Ent_Description.delete(0, 'end'))
            self.Btn_ClearDescription.pack(side = tk.LEFT, padx = 4, pady = 4, anchor = tk.W)

            #Pricing Label
            self.Lbl_Description = tk.Label(self.Frame_DetailsTopPricingLabel, text="SERVING SIZES & PRICING", fg=self.TextColor2, bg=self.Color, font=F4)
            self.Lbl_Description.pack()

            #Size Buttons
            WidgetWidth = 6
            FontSize = F4
            Indicator = 0
            PadX = 4
            PadY = 2
            Short = 8
            Long = 15
            Height = 2
            SelectColor = self.Color2

            #4 oz.
            self.Var_4oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsLeft, selectcolor = SelectColor, indicatoron = Indicator, width = Short, height = Height, text='4 oz.',
                           onvalue='Yes', offvalue='No', variable=self.Var_4oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_4oz, self.Var_4oz.get())).\
                            grid(row=0, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_4oz = tk.StringVar()
            self.Ent_4oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsLeft, width=WidgetWidth, textvariable = self.In_4oz, state = tk.DISABLED)
            self.Ent_4oz.grid(row = 0, column = 2, sticky = tk.W)
            self.In_4oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_4oz, "Decimal", 0, 10000))  # allow decimal values only

            if "4oz." in List_RecalledSizes:
                self.Ent_4oz.config(state = tk.NORMAL)
                self.Ent_4oz.insert(0, Dict_RecalledSizePrice["4oz."])
                self.Var_4oz.set(value = "Yes")

            #5 oz.
            self.Var_5oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsLeft, selectcolor = SelectColor, indicatoron = Indicator, width = Short, height = Height, text='5 oz.',
                           onvalue='Yes', offvalue='No', variable=self.Var_5oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_5oz, self.Var_5oz.get())).\
                            grid(row=1, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_5oz = tk.StringVar()
            self.Ent_5oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsLeft, width=WidgetWidth, textvariable = self.In_5oz, state = tk.DISABLED)
            self.Ent_5oz.grid(row=1, column=2, sticky=tk.W)
            self.In_5oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_5oz, "Decimal", 0, 10000))  # allow decimal values only

            if "5oz." in List_RecalledSizes:
                self.Ent_5oz.config(state=tk.NORMAL)
                self.Ent_5oz.insert(0, Dict_RecalledSizePrice["5oz."])
                self.Var_5oz.set(value = "Yes")

            #8 oz.
            self.Var_8oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsLeft, selectcolor = SelectColor, indicatoron = Indicator, width = Short, height = Height, text='8 oz.',
                           onvalue='Yes', offvalue='No', variable=self.Var_8oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_8oz, self.Var_8oz.get())).\
                            grid(row=2, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_8oz = tk.StringVar()
            self.Ent_8oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsLeft, width=WidgetWidth, textvariable = self.In_8oz, state = tk.DISABLED)
            self.Ent_8oz.grid(row=2, column=2, sticky=tk.W)
            self.In_8oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_8oz, "Decimal", 0, 10000))  # allow decimal values only

            if "8oz." in List_RecalledSizes:
                self.Ent_8oz.config(state=tk.NORMAL)
                self.Ent_8oz.insert(0, Dict_RecalledSizePrice["8oz."])
                self.Var_8oz.set(value = "Yes")

            #12 oz.
            self.Var_12oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsMiddle, selectcolor = SelectColor, indicatoron = Indicator, width = Short, height = Height, text='12 oz.',
                           onvalue='Yes', offvalue='No', variable=self.Var_12oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_12oz, self.Var_12oz.get())).\
                            grid(row=0, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_12oz = tk.StringVar()
            self.Ent_12oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsMiddle, width=WidgetWidth, textvariable = self.In_12oz, state = tk.DISABLED)
            self.Ent_12oz.grid(row=0, column=2, sticky=tk.W)
            self.In_12oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_12oz, "Decimal", 0, 10000))  # allow decimal values only

            if "12oz." in List_RecalledSizes:
                self.Ent_12oz.config(state=tk.NORMAL)
                self.Ent_12oz.insert(0, Dict_RecalledSizePrice["12oz."])
                self.Var_12oz.set(value = "Yes")

            # Right Column
            #16 oz.
            self.Var_16oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsMiddle, selectcolor = SelectColor, indicatoron = Indicator, width = Short, height = Height, text='16 oz.',
                           onvalue='Yes', offvalue='No', variable=self.Var_16oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_16oz, self.Var_16oz.get())).\
                            grid(row=1, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_16oz = tk.StringVar()
            self.Ent_16oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsMiddle, width=WidgetWidth, textvariable = self.In_16oz, state = tk.DISABLED)
            self.Ent_16oz.grid(row=1, column=2, sticky=tk.W)
            self.In_16oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_16oz, "Decimal", 0, 10000))  # allow decimal values only

            if "16oz." in List_RecalledSizes:
                self.Ent_16oz.config(state=tk.NORMAL)
                self.Ent_16oz.insert(0, Dict_RecalledSizePrice["16oz."])
                self.Var_16oz.set(value = "Yes")

            #20 oz.
            self.Var_20oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsMiddle, selectcolor = SelectColor, indicatoron = Indicator, width = Short, height = Height, text='20 oz.',
                           onvalue='Yes', offvalue='No', variable=self.Var_20oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_20oz, self.Var_20oz.get())).\
                            grid(row=2, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_20oz = tk.StringVar()
            self.Ent_20oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsMiddle, width=WidgetWidth, textvariable = self.In_20oz, state = tk.DISABLED)
            self.Ent_20oz.grid(row=2, column=2, sticky=tk.W)
            self.In_20oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_20oz, "Decimal", 0, 10000))  # allow decimal values only

            if "20oz." in List_RecalledSizes:
                self.Ent_20oz.config(state=tk.NORMAL)
                self.Ent_20oz.insert(0, Dict_RecalledSizePrice["20oz."])
                self.Var_20oz.set(value = "Yes")

            #32 oz. Crowler
            self.Var_32oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsRight, selectcolor = SelectColor, indicatoron = Indicator, width = Long, height = Height, text='Crowler',
                           onvalue='Yes', offvalue='No', variable=self.Var_32oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_32oz, self.Var_32oz.get())).\
                            grid(row=0, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_32oz = tk.StringVar()
            self.Ent_32oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsRight, width=WidgetWidth, textvariable = self.In_32oz, state = tk.DISABLED)
            self.Ent_32oz.grid(row=0, column=2, sticky=tk.W)
            self.In_32oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_32oz, "Decimal", 0, 10000))  # allow decimal values only

            if "Crowler" in List_RecalledSizes:
                self.Ent_32oz.config(state=tk.NORMAL)
                self.Ent_32oz.insert(0, Dict_RecalledSizePrice["Crowler"])
                self.Var_32oz.set(value = "Yes")

            #64 oz. Growler
            self.Var_64oz = tk.StringVar(value=0)
            tk.Checkbutton(self.Frame_DetailsTopPricingWidgetsRight, selectcolor = SelectColor, indicatoron = Indicator, width = Long, height = Height, text='Growler',
                           onvalue='Yes', offvalue='No', variable=self.Var_64oz, font = FontSize, command = lambda: CellarManager.SelectSize(self, self.Ent_64oz, self.Var_64oz.get())).\
                            grid(row=1, column=0, padx = PadX, pady = PadY, sticky=tk.W)
            self.In_64oz = tk.StringVar()
            self.Ent_64oz = tk.Entry(self.Frame_DetailsTopPricingWidgetsRight, width=WidgetWidth, textvariable = self.In_64oz, state = tk.DISABLED)
            self.Ent_64oz.grid(row=1, column=2, sticky=tk.W)
            self.In_64oz.trace("w", lambda name, index, mode: CellarManager.CheckEntry(self, self.Ent_64oz, "Decimal", 0, 10000))  # allow decimal values only

            if "Growler" in List_RecalledSizes:
                self.Ent_64oz.config(state=tk.NORMAL)
                self.Ent_64oz.insert(0, Dict_RecalledSizePrice["Growler"])
                self.Var_64oz.set(value = "Yes")

            #Dollar sign labels
            for size in range(0, 8):
                if size < 3:
                    #Left Column
                    Lbl_Dollar = tk.Label(self.Frame_DetailsTopPricingWidgetsLeft, text = "$", font = F3, bg = GUIBG)
                    Lbl_Dollar.grid(row = size, column = 1, sticky = tk.E)

                elif size >= 3 and size <6:
                    #Middle Column
                    Lbl_Dollar = tk.Label(self.Frame_DetailsTopPricingWidgetsMiddle, text = "$", font = F3, bg = GUIBG)
                    Lbl_Dollar.grid(row = size-3, column = 1, sticky = tk.E)

                else:
                    #Right Column
                    Lbl_Dollar = tk.Label(self.Frame_DetailsTopPricingWidgetsRight, text="$", font = F3, bg = GUIBG)
                    Lbl_Dollar.grid(row=size-6, column=1, sticky=tk.E)

            #Bottom Menu
            ImgWidth = 60
            ImgHeight = 60
            BtnWidth = 120
            BtnHeight = 40
            FontSize = F4

            if Source != "Recall":

                #Exit Button
                try:
                    photo = ImageTk.PhotoImage(Image.open(Path_ImgSnowboarder).resize((ImgWidth, ImgHeight)))
                except:
                    photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                Lbl_Image = tk.Label(self.Frame_DetailsBottom, image=photo)
                Lbl_Image.image = photo
                Btn_Exit = tk.Button(self.Frame_DetailsBottom, text="EXIT", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                Btn_Exit.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
                Btn_Exit.config(command=lambda: self.Frame_Details.destroy())

                #Save Button
                try:
                    photo = ImageTk.PhotoImage(Image.open(Path_ImgRecordPlayer).resize((ImgWidth, ImgHeight)))
                except:
                    photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                Lbl_Image = tk.Label(self.Frame_DetailsBottom, image=photo)
                Lbl_Image.image = photo
                Btn_Save = tk.Button(self.Frame_DetailsBottom, text="SAVE", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                Btn_Save.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
                Btn_Save.config(command=lambda: CellarManager.SaveDetails(self, "Cellar"))

            else:

                # Save Button
                try:
                    photo = ImageTk.PhotoImage(Image.open(Path_ImgRecordPlayer).resize((ImgWidth, ImgHeight)))
                except:
                    photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                Lbl_Image = tk.Label(self.Frame_DetailsBottom, image=photo)
                Lbl_Image.image = photo
                Btn_Save = tk.Button(self.Frame_DetailsBottom, text="SAVE", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                Btn_Save.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
                Btn_Save.config(command=lambda: CellarManager.SaveDetails(self, "Cellar"))

            # if self.Val_EntryType == "Touch":
            Keyboard.BuildKeyboard(self, self.Frame_DetailsKeyboard, "Details")
            self.Ent_Description.focus_set()

        except:
            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the Details GUI.")

    #Add Custom Style GUI
    def BuildAddCustomStyle(self, Style):

        try:

             if Style != "ADD STYLE":
                 return
             else:

                 self.CloseToplevels()

                 # Toplevel window
                 self.Frame_AddStyle = tk.Toplevel(TapStatus.RootWindow)  # Create toplevel window
                 self.Frame_AddStyle.title("Add Style")
                 if self.Val_ScreenSize == '7" Touchscreen':  # If option set to run on 7" Touchsceen:
                     self.Frame_AddStyle.wm_attributes('-fullscreen', 'true')  # Removes border and title bar from toplevel
                 if Platform == "Windows":
                     self.Frame_AddStyle.grab_set()  # Prevents other Tkinter windows from being used

                 x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
                 y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root
                 self.Frame_AddStyle.geometry("+%d+%d" % (x + 10, y + 10))  # Place message window at these coordinates (roughly middle of root window)

                 GUIBG = SI

                 # Frames
                 self.Frame_AddStyleTop = tk.Frame(self.Frame_AddStyle, bg=GUIBG)
                 self.Frame_AddStyleTop.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE, anchor=tk.N)
                 self.Frame_AddStyleTopLeft = tk.Frame(self.Frame_AddStyleTop, bg=GUIBG)
                 self.Frame_AddStyleTopLeft.pack(side=tk.LEFT, fill=tk.BOTH, expand=tk.TRUE, anchor=tk.N, padx = 4, pady = 4)
                 self.Frame_AddStyleTopLeftTop = tk.Frame(self.Frame_AddStyleTopLeft, bg=GUIBG)
                 self.Frame_AddStyleTopLeftTop.pack(side=tk.TOP, fill=tk.X, expand=tk.TRUE, anchor=tk.N)
                 self.Frame_AddStyleTopLeftBottom = tk.Frame(self.Frame_AddStyleTopLeft, bg=GUIBG)
                 self.Frame_AddStyleTopLeftBottom.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE, anchor=tk.N)
                 self.Frame_AddStyleTopRight = tk.Frame(self.Frame_AddStyleTop, bg=GUIBG)
                 self.Frame_AddStyleTopRight.pack(side=tk.RIGHT, fill=tk.Y, expand=tk.FALSE, anchor=tk.N, padx = 4, pady = 4)
                 self.Frame_AddStyleKeyboard = tk.Frame(self.Frame_AddStyle, bg=GUIBG)
                 self.Frame_AddStyleKeyboard.pack(side=tk.TOP, fill=tk.X, expand=tk.TRUE, anchor=tk.S)

                 EntryWidth = 35
                 FontSize = F8

                 #New Style Entry Box
                 self.Lbl_NewStyle = tk.Label(self.Frame_AddStyleTopLeftTop, text="CUSTOM STYLE", fg=self.TextColor2, bg=GUIBG, font=F4, justify=tk.RIGHT)
                 self.Lbl_NewStyle.pack(side = tk.LEFT, padx = 4, pady = 4)
                 CellarManager.In_NewStyle = tk.StringVar()
                 CellarManager.Ent_NewStyle = tk.Entry(self.Frame_AddStyleTopLeftTop, textvariable=CellarManager.In_NewStyle, width=EntryWidth, font=FontSize)
                 CellarManager.Ent_NewStyle.pack(side = tk.LEFT, padx = 4, pady = 4)
                 CellarManager.Ent_NewStyle.focus_set()
                 CellarManager.In_NewStyle.trace("w", lambda name, index, mode: CellarManager.CheckCustomStyleEntry(self, CellarManager.Btn_Add))

                 CellarManager.BuildCustomStylesListbox(self, self.Frame_AddStyleTopLeftBottom)
                 CellarManager.UpdateCustomStylesListbox(self)

                 #Menu
                 ImgWidth = 60
                 ImgHeight = 60
                 BtnWidth = 145
                 BtnHeight = 45
                 FontSize = F4

                 #Save New Style Button
                 try:
                     photo = ImageTk.PhotoImage(Image.open(Path_ImgRecordPlayer).resize((ImgWidth, ImgHeight)))
                 except:
                     photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                 Lbl_Image = tk.Label(self.Frame_AddStyleTopRight, image=photo)
                 Lbl_Image.image = photo
                 CellarManager.Btn_Add = tk.Button(self.Frame_AddStyleTopRight, text="SAVE IT!", width=BtnWidth, height=BtnHeight, state = tk.DISABLED, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                 CellarManager.Btn_Add.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.W)
                 CellarManager.Btn_Add.config(command=lambda: CellarManager.SaveCustomStyle(self, CellarManager.Ent_NewStyle.get()))

                 #Remove Button
                 try:
                     photo = ImageTk.PhotoImage(Image.open(Path_ImgKick).resize((ImgWidth, ImgHeight)))
                 except:
                     photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                 Lbl_Image = tk.Label(self.Frame_AddStyleTopRight, image=photo)
                 Lbl_Image.image = photo
                 CellarManager.Btn_Remove = tk.Button(self.Frame_AddStyleTopRight, text="TRASH IT!", width=BtnWidth, height=BtnHeight, state = tk.DISABLED, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                 CellarManager.Btn_Remove.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.W)
                 CellarManager.Btn_Remove.config(command=lambda: CellarManager.DeleteCustomStyle(self, CellarManager.StyleRowIndex))

                 # Exit Button
                 try:
                     photo = ImageTk.PhotoImage(Image.open(Path_ImgSnowboarder).resize((ImgWidth, ImgHeight)))
                 except:
                     photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
                 Lbl_Image = tk.Label(self.Frame_AddStyleTopRight, image=photo)
                 Lbl_Image.image = photo
                 Btn_Exit = tk.Button(self.Frame_AddStyleTopRight, text="EXIT", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
                 Btn_Exit.pack(side=tk.TOP, padx=4, pady=4, anchor=tk.E)
                 Btn_Exit.config(command=lambda: self.Frame_AddStyle.destroy())

                 if self.Val_EntryType == "Touch":
                    Keyboard.BuildKeyboard(self, self.Frame_AddStyleKeyboard, "Details")

        except:
            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the Add Custom Style screen.")

    #Enable "SAVE IT!" button in Add Style if Custom Style entry box entry is greater than 0 in length, disable otherwise
    def CheckCustomStyleEntry(self, AddButton):

        try:

            Entry = CellarManager.In_NewStyle.get()
            if len(Entry) == 0:
                AddButton.config(state = tk.DISABLED)
            else:
                AddButton.config(state = tk.NORMAL)

        except:
            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue checking the custom style entry.")

    #Save the users entry to Custom Styles.csv file and update listbox
    def SaveCustomStyle(self, Entry):

        try:

            # Save it to Custom Styles.csv
            with open(Path_CustomStyles, mode='a', newline='') as CustomStyles_file:  # opens file with 'a' for append, does not overwrite anything already in it
                CustomStyles_writer = csv.writer(CustomStyles_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                CustomStyles_writer.writerow([Entry])

            CellarManager.UpdateCustomStylesListbox(self)

            CellarManager.Ent_NewStyle.delete(0, 'end') #Clear Custom Style entry box
            CellarManager.Ent_NewStyle.focus_set() #Take focus on Custom Style entry box
            self.Combo_Style.set(value=Entry)  # Set value to most recently saved style

        except:
            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue saving the custom style.")

    #When user clicks size button, unlock entry box and take focus. When user unselects size, clear entry box and lock.
    def SelectSize(self, EntryBox, Value):

        try:

            if Value == "Yes": #If user selects size button
                EntryBox.config(state = tk.NORMAL) #activate entry box
                EntryBox.focus_set() #take focus on entry box

            elif Value == "No": #If user un-selects size button
                EntryBox.delete(0, 'end') #Clear entry box
                EntryBox.config(state=tk.DISABLED) #Disable entry box

        except:
            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue selecting the size.")

    #Save details to variables that will be referenced later when clicking "Save" in the CELLAR tab (this function does not make changes to any files)
    def SaveDetails(self, Source):

        try:

            #If user clicks "Clear" in Cellar tab, reset Description and SizePrice to nothing
            if Source == "Clear":

                CellarManager.Description = ""
                CellarManager.Str_SizePrice = ""

            else:

                CellarManager.Description = self.Ent_Description.get() #Store description as a variable
                CellarManager.Str_SizePrice = "" #Store SizePrice as a variable

                #Get price from each entry box if that size is included. If it is included but is missing a price, take focus on that entry box and terminate this function.
                Include4oz = self.Var_4oz.get()
                Wid = self.Ent_4oz
                if Include4oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price4oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = "4 oz. - " + str(Price4oz) + ", "

                Include5oz = self.Var_5oz.get()
                Wid = self.Ent_5oz
                if Include5oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price5oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = str(CellarManager.Str_SizePrice) + "5 oz. - " + str(Price5oz) + ", "

                Include8oz = self.Var_8oz.get()
                Wid = self.Ent_8oz
                if Include8oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price8oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = str(CellarManager.Str_SizePrice) + "8 oz. - " + str(Price8oz) + ", "

                Include12oz = self.Var_12oz.get()
                Wid = self.Ent_12oz
                if Include12oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price12oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = str(CellarManager.Str_SizePrice) + "12 oz. - " + str(Price12oz) + ", "

                Include16oz = self.Var_16oz.get()
                Wid = self.Ent_16oz
                if Include16oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price16oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = str(CellarManager.Str_SizePrice) + "16 oz. - " + str(Price16oz) + ", "

                Include20oz = self.Var_20oz.get()
                Wid = self.Ent_20oz
                if Include20oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price20oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = str(CellarManager.Str_SizePrice) + "20 oz. - " + str(Price20oz) + ", "

                Include32oz = self.Var_32oz.get()
                Wid = self.Ent_32oz
                if Include32oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price32oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = str(CellarManager.Str_SizePrice) + "Crowler - " + str(Price32oz) + ", "

                Include64oz = self.Var_64oz.get()
                Wid = self.Ent_64oz
                if Include64oz == "Yes":
                    Price = Wid.get()
                    if Price == "":
                        Wid.focus_set()
                        return
                    Price64oz = "$" + str(Price)
                    CellarManager.Str_SizePrice = str(CellarManager.Str_SizePrice) + "Growler - " + str(Price64oz) + ", "

                self.Frame_Details.destroy() #Close Details GUI

        except:
            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue saving the details.")

    #If user want to recall info from the last batch of chosen beer, look up info and populate widgets
    def RecallBeerInfo(self, Beer):

        try:

            # Check if there are any Message Windows already open
            for wid in TapStatus.RootWindow.winfo_children():  # Loop through all of widgets in root window
                WidClass = wid.winfo_class()  # Get the class of each widget
                if WidClass == "Toplevel":  # If the widget is a "Toplevel" window
                    wid.destroy()  # Close it

            #Look up info for most recent batch of same beer
            with open(Path_Archive) as csvfile:  # Open CurrentInventory.csv
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV)  # Create list from file

                r = 0
                List_MatchingBeerRows = [] #Create list to hold row index numbers with matching beers
                for BatchRow in readCSV: #Loop through each Batch Row in file
                    FoundBeer = BatchRow[Dict_ArchiveColumn['Beer Name']] #Get the Beer Name of each Batch
                    if FoundBeer == Beer: #If the FoundBeer name matches the Beer name
                        List_MatchingBeerRows.append(r) #add row to list
                    else:
                        pass
                    r = r + 1

                RowIndex = max(List_MatchingBeerRows) #The most recent matching batch will be the one with the highest row index (lowest down on the list)

                # Use Archive dictionary to look up column index value (the nth item in the row)
                self.InputDate = readCSV[RowIndex][Dict_ArchiveColumn['Input Date']]  # [Row][Column]
                self.Beer = readCSV[RowIndex][Dict_ArchiveColumn['Beer Name']]
                self.BrewDate = readCSV[RowIndex][Dict_ArchiveColumn['Brew Date']]
                self.Batch = readCSV[RowIndex][Dict_ArchiveColumn['Batch']]
                self.Style = readCSV[RowIndex][Dict_ArchiveColumn['Style']]
                self.ABV = readCSV[RowIndex][Dict_ArchiveColumn['ABV']]
                self.TankType = readCSV[RowIndex][Dict_ArchiveColumn['Tank Type']]
                self.Quantity = readCSV[RowIndex][Dict_ArchiveColumn['Quantity']]  # Current quantity in cellar
                self.TankVolume = readCSV[RowIndex][Dict_ArchiveColumn['Tank Volume']]
                self.VolUnits = readCSV[RowIndex][Dict_ArchiveColumn['Volume Unit']]
                self.TotalVolume = readCSV[RowIndex][Dict_ArchiveColumn['Total Volume']]
                self.Description = readCSV[RowIndex][Dict_ArchiveColumn['Description']]
                self.SizePrice = readCSV[RowIndex][Dict_ArchiveColumn['Str_SizePrice']]

                self.Quantity = int(self.Quantity)  # Convert float to int (7.0 -> 7)

                #Configure widgets with recalled info
                self.Ent_Beer.delete(0, 'end')  # Clear ABV entry box
                self.Ent_Beer.insert(0, self.Beer)  # Insert ABV value
                self.Combo_Style.set(self.Style)
                self.Combo_TankType.set(self.TankType)
                self.Ent_ABV.delete(0, 'end') #Clear ABV entry box
                self.Ent_ABV.insert(0, self.ABV) #Insert ABV value

                if self.TankType == "Brite": #If recalled tank is a Brite Tank
                    self.Ent_BriteVolume.config(state=tk.NORMAL) #Enable Brite Volume entry box
                    self.Ent_BriteVolume.delete(0, 'end')  # Clear Brite Volume entry box
                    self.Ent_BriteVolume.insert(0, self.TankVolume) #Insert Brite Volume value
                    self.Lbl_BriteVolume.config(state = tk.NORMAL) #Enable Brite Volume label
                    self.Lbl_BriteVolume.config(text="BRITE VOLUME\n" + str(self.VolUnits)) #Configure Brite Volume label text

                    self.Ent_Quantity.config(state=tk.NORMAL) #Enable Quantity label
                    self.Ent_Quantity.delete(0, 'end')  # Clear Quanity entry box
                    self.Ent_Quantity.insert(0, self.Quantity) #Insert Quanity value
                    self.Ent_Quantity.config(state=tk.DISABLED)  #Disable Quantity label
                    self.Lbl_Quantity.config(state = tk.DISABLED) #Disable Quanity label

                else: #If recalled tank is anything other than a Brite Tank
                    self.Ent_BriteVolume.delete(0, 'end') #Clear Brite Volume entry box
                    self.Ent_BriteVolume.config(state=tk.DISABLED) #Disable Brite Volume entry box
                    self.Lbl_BriteVolume.config(state=tk.NORMAL)  # Enable Brite Volume label
                    self.Lbl_BriteVolume.config(text="BRITE VOLUME\n(" + str(self.Val_VolumeUnit) + ")")
                    self.Lbl_BriteVolume.config(state=tk.DISABLED)  #Disable Brite Volume label

                    self.Ent_Quantity.config(state=tk.NORMAL) #Enable Quantity entry box
                    self.Lbl_Quantity.config(state=tk.NORMAL) #Enable Quanity label
                    self.Ent_Quantity.delete(0, 'end') #Clear Quanity entry box
                    self.Ent_Quantity.insert(0, self.Quantity)  # Insert Quanity value

                CellarManager.BuildDetails(self, "Recall", self.Description, self.SizePrice)

        except:
            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue saving the details.")

    #Display message window to user (toplevel)
    def RecallMessageWindow(self):

        self.CloseToplevels()

        BGColor = SI
        FontColor = self.TextColor2

        #Toplevel window
        Frame_Message = tk.Toplevel(TapStatus.RootWindow, bg = BGColor)  # Create toplevel window
        Frame_Message.title("Recall What?")  # Assign window title
        if Platform == "Windows":
            Frame_Message.iconbitmap(Favicon)  # Set favicon
            Frame_Message.grab_set()  # Prevents other Tkinter windows from being used (Does not work on Pi when root window is full screen as splash screen)

        x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
        y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root
        Frame_Message.geometry("+%d+%d" % (x + 180, y + 70))  # Place message window at these coordinates (roughly middle of root window)

        #Top/Bottom Frames
        Frame_Top = tk.Frame(Frame_Message, bg = BGColor)
        Frame_Top.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE, padx=15)
        Frame_Bottom = tk.Frame(Frame_Message, bg=SG)
        Frame_Bottom.pack(side=tk.BOTTOM, fill=tk.X)

        #Message on right
        Message = "Recall info from the last batch of..."
        if self.Val_Theme == "Mosh Pit":
            FontColor = B
        Lbl_Message = tk.Label(Frame_Top, text=Message, font=F4, justify=tk.LEFT, bg = BGColor, fg = FontColor)
        Lbl_Message.pack(side=tk.TOP, pady = 4)

        self.DFLog = pd.read_csv(Path_Archive, names=List_ArchiveHeaders)  # Create DF from Archive file
        List_AllBeers = self.DFLog['Beer Name'].to_list()  # Create list from "Beer Name" column
        List_AllBeers = list(set(List_AllBeers))  # Remove duplicates

        Combo_Beer = ttk.Combobox(Frame_Top, values=sorted(List_AllBeers), width=30, font = F4, state="readonly", height = 10)
        Combo_Beer.pack(side=tk.TOP, pady = 4)
        Combo_Beer.bind("<<ComboboxSelected>>", lambda event: Btn_Yes.config(state = tk.NORMAL))

        ImgWidth = 150
        ImgHeight = 150

        try:
            photo = ImageTk.PhotoImage(Image.open(Path_ImgTape).resize((ImgWidth, ImgHeight)))
        except:
            photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
        Lbl_Image = tk.Label(Frame_Top, image=photo, bg = BGColor)
        Lbl_Image.image = photo
        Lbl_Image.pack(side=tk.TOP)

        # Ok Button
        ImgWidth = 60
        ImgHeight = 60
        BtnWidth = 160
        BtnHeight = 40
        FontSize = F4

        #Yes Button
        try:
            photo = ImageTk.PhotoImage(Image.open(Path_ImgSnowboarder2).resize((ImgWidth, ImgHeight)))
        except:
            photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
        Lbl_Image = tk.Label(Frame_Bottom, image=photo)
        Lbl_Image.image = photo
        Btn_Yes = tk.Button(Frame_Bottom, text="DO IT!", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, state = tk.DISABLED, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
        Btn_Yes.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
        Btn_Yes.config(command=lambda: CellarManager.RecallBeerInfo(self, Combo_Beer.get()))
        Btn_Yes.focus_set()
        Btn_Yes.bind('<Return>', lambda a: CellarManager.RecallBeerInfo(self, Combo_Beer.get()))  # Bind "Enter" button to ClickYes function

        #No Button
        try:
            photo = ImageTk.PhotoImage(Image.open(Path_ImgHazard).resize((ImgWidth, ImgHeight)))
        except:
            photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
        Lbl_Image = tk.Label(Frame_Bottom, image=photo)
        Lbl_Image.image = photo
        Btn_No = tk.Button(Frame_Bottom, text="NO WAY!", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
        Btn_No.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
        Btn_No.config(command=lambda: Frame_Message.destroy())
        Btn_No.focus_set()
        Btn_No.bind('<Return>', lambda a: Frame_Message.destroy())  # Bind "Enter" button to ClickNo function

        Frame_Message.lift()

    #Save New Batch to Inventory and Archive
    def AddtoInventory(self):

        try:

            inputdate = datetime.datetime.strptime(self.Pick_InputDate.get(), '%m/%d/%y').strftime('%m-%d-%y') #Get and configure Input Date
            beer = self.Ent_Beer.get() #Get Beer Name
            brewdate = datetime.datetime.strptime(self.Pick_BrewDate.get(), '%m/%d/%y').strftime('%m-%d-%y') #Get and configure Brew Date
            batch = str(beer) + " - " + str(brewdate) #Create batch string (Beer + Brew Date)
            style = self.Combo_Style.get() #Get Style
            tanktype = self.Combo_TankType.get() #Get Tank Type

            #Check that there are not any duplicate batches in current inventory (same Beer name and Brew Date)
            self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create data frame from CurrentInventory.csv
            List_AllBatches = self.DFCurrentInventory['Batch'].tolist() #Create list of all Batches
            if batch in List_AllBatches: #Loop through all the batches
                ErrorHandling.ShowWarning(self, "Double Trouble", "There's already a batch named '" + str(batch) + "'.\nEnter a different Beer name or Brew Date!")
                self.Ent_Beer.focus_set()
                return
            else: #No duplicate batches
                pass

            #Get ABV and Quantity, check entries
            abv = self.In_ABV.get() #Get ABV
            quantity = self.In_Quantity.get()  # Get Quantity
            quantity = int(quantity)

            if abv == "" or quantity == "": #Is the entry blank?
                pass #continue to check that no entries are blank (This will be caught in that loop)
            else:
                if float(abv) > 100: #Did user enter an ABV value greater than 100?
                    ErrorHandling.ShowWarning(self, "Ugh, Rules!", "You entered an ABV greater than 100%\nTone it down!")
                    self.Ent_ABV.delete(0, 'end') #Clear ABV entry box
                    self.Ent_ABV.focus_set() #Set focus on ABV entry box
                    return #End function

            #Check that no required entries are left blank
            List_Required = [inputdate, beer, brewdate, batch, style, abv, tanktype, quantity] #Create a list of required entries
            for required in List_Required: #Loop through each required entry
                if required == "": #If entry is blank
                    ErrorHandling.ShowWarning(self, "Ugh, Rules!", "Don't leave Keg Punk hangin'\nFill in all info!")
                    return #End function

            tankvolume = self.In_BriteVolume.get() #Get Brite Volume (not required unless Tank Type is Brite)

            #Check if a value for Brite Volume is required
            if tankvolume == "": #If Brite Volume value is blank
                volunit = "Gal"
                if tanktype != "Brite": #If Tank Type is NOT Brite (implies its some kind of keg)
                    tankvolume = Dict_TankVolumeGal[tanktype] #Look up the volume of that kind of keg
                    totalvolume = int(quantity) * float(tankvolume) #Calculate the total volume (Quantity x Keg Volume)
                else: #If Tank Type IS Brite, Brite Volume is required
                    ErrorHandling.ShowWarning(self, "Ugh, Rules!", "You picked Brite...\nnow enter a volume!")
                    return #End function
            else: #If Brite volume is NOT blank
                tankvolume = float(tankvolume) #Convert tankvolume to float
                volunit = self.Val_VolumeUnit #Get Volume Units of brite (set by user in Options)
                totalvolume = int(quantity) * tankvolume #Calculate the total volume (Quantity x Keg Volume)


            try:
                Description = CellarManager.Description
            except:
                Description = "No Description"

            try:
                SizePrice = CellarManager.Str_SizePrice
            except:
                SizePrice = "No Pricing"

            #Save it to Current Inventory
            with open(Path_CurrentInventory, mode='a', newline='') as CurrentInventory_file:  # opens file with 'a' for append, does not overwrite anything already in it
                CurrentInventory_writer = csv.writer(CurrentInventory_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                CurrentInventory_writer.writerow([inputdate, beer, brewdate, batch, style, abv, tanktype, quantity, tankvolume, volunit
                                                     , str(totalvolume) + " " + str(volunit), Description, SizePrice])

            #Save to Archive
            with open(Path_Archive, mode='a', newline='') as Archive_file:  # opens file with 'a' for append, does not overwrite anything already in it
                Archive_writer = csv.writer(Archive_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                Archive_writer.writerow([inputdate, beer, brewdate, batch, style, abv, tanktype, quantity, tankvolume, volunit
                                            , str(totalvolume) + " " + str(volunit), Description, SizePrice])

            CellarManager.UpdateCurrentInventoryListbox(self, "CELLAR") #Call function to update Cellar listbox
            CellarManager.ClearEntry(self) #Call function to clear entry widgets
            self.Description = "No Description" #Reset description
            self.Str_SizePrice = ""

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue saving a new batch to the inventory.")

    #Builds Cellar listbox for Cellar tab
    def BuildCurrentInventoryListbox(self, Frame, Source):

        try:

            # Set headers for listbox columns
            event_header = ['                        BATCH                        ', '    TANK    ', '  QNT.  ']

            style = ttk.Style()
            style.configure("CellarStyle.Treeview", highlightthickness=0, bd=0, font=(F6))

            #Creates multicolumn listbox
            self.Tree_Inventory = ttk.Treeview(Frame, columns=event_header, show="headings", style = "CellarStyle.Treeview")
            vsb = ttk.Scrollbar(Frame, orient="vertical", command=self.Tree_Inventory.yview) #Vertical scroll bar
            self.Tree_Inventory.configure(yscrollcommand=vsb.set)
            self.Tree_Inventory.pack(side=tk.LEFT, fill=tk.BOTH, expand=True, anchor = tk.N)
            vsb.pack(side=tk.RIGHT, fill=tk.BOTH, anchor=tk.E)

            #adds header strings
            for col in event_header:
                self.Tree_Inventory.heading(col, text=col.title())
                self.Tree_Inventory.column(col, width=tkFont.Font().measure(col.title())) #adjust the column's width to the header string

            CellarManager.UpdateCurrentInventoryListbox(self, Source) #Call function to update Cellar listbox
            self.Tree_Inventory.bind('<<TreeviewSelect>>', lambda event: TapStatus.SelectAvailable(self, self.Tree_Inventory, Source)) #Bind click event to listbox (calls SelectAvailable function if user clicks in listbox)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the Cellar listbox.")

    #Update the batches in the Cellar listbox
    def UpdateCurrentInventoryListbox(self, Source):

        try:

            #Clear listbox
            if Source == "Taproom":
                pass
            else:
                for r in self.Tree_Inventory.get_children():
                    self.Tree_Inventory.delete(r)

            TaproomManager.SortCurrentInventoryList(self) #Call function to sort Cellar list by Quantity (Lowest to Highest)

            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders)  # Create DF from OnTap file
            List_AllBatchesOnTap = self.DFOnTap['Batch'].to_list()  # Create list from "Batch" column

            #Open CurrentInventory.csv
            with open(Path_CurrentInventory) as csvfile:
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV)
                rows = len(readCSV) #How many rows are in the file?

                if Source == "Taproom":

                    CellarManager.List_AvailableInCellar = []
                    if rows == 0: #If there are 0 rows (implies there are no batches in Current Inventory)
                        return #End function
                    else: #If there are rows (implies there are batches in Current Inventory)
                        self.List_Rows = [] #Create empty list
                        for i in range(0, rows): #Loop through each row
                            Batch = readCSV[i][Dict_CurrentInventoryColumn['Batch']] #[row index][column index]
                            if Batch in List_AllBatchesOnTap:  # If there is already a tap with a keg of this batch, do not add batch to cellar list
                                pass
                            else: #If there is NOT a tap with a keg of this batch, add to cellar list
                                Tank = readCSV[i][Dict_CurrentInventoryColumn['Tank Type']]
                                Qnt = readCSV[i][Dict_CurrentInventoryColumn['Quantity']]
                                Qnt = int(float(Qnt))  # Convert string to float to integer
                                List_Row = [Batch, Tank, Qnt] #Create list for each row
                                CellarManager.List_AvailableInCellar.append(List_Row)
                                self.List_Rows.append(List_Row) #Add list to list of rows

                elif Source == "CELLAR":

                    if rows == 0:  # If there are 0 rows (implies there are no batches in Current Inventory)
                        return  # End function
                    else:  # If there are rows (implies there are batches in Current Inventory)
                        self.List_Rows = []  # Create empty list
                        for i in range(0, rows):  # Loop through each row
                            Batch = readCSV[i][Dict_CurrentInventoryColumn['Batch']]  # [row index][column index]
                            Tank = readCSV[i][Dict_CurrentInventoryColumn['Tank Type']]
                            Qnt = readCSV[i][Dict_CurrentInventoryColumn['Quantity']]
                            Qnt = int(float(Qnt)) #Convert string to float to integer
                            List_Row = [Batch, Tank, Qnt]  # Create list for each row
                            self.List_Rows.append(List_Row)  # Add list to list of rows

                #Add each row list to listbox
                for row in self.List_Rows:
                    self.Tree_Inventory.insert('', 'end', values=row)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue updating the Cellar listbox.")

    # Builds Custom Styles listbox
    def BuildCustomStylesListbox(self, Frame):

        try:

            # Set headers for listbox columns
            event_header = ['CUSTOM STYLES']

            style = ttk.Style()
            style.configure("CellarStyle.Treeview", highlightthickness=0, bd=0, font=(F6))

            # Creates multicolumn listbox
            self.Tree_CustomStyles = ttk.Treeview(Frame, columns=event_header, show="headings", style="CellarStyle.Treeview")
            vsb = ttk.Scrollbar(Frame, orient="vertical", command=self.Tree_CustomStyles.yview)  # Vertical scroll bar
            self.Tree_CustomStyles.configure(yscrollcommand=vsb.set)
            self.Tree_CustomStyles.pack(side=tk.LEFT, fill=tk.BOTH, expand=True, anchor=tk.N)
            vsb.pack(side=tk.RIGHT, fill=tk.BOTH, anchor=tk.E)
            self.Tree_CustomStyles.bind('<<TreeviewSelect>>', lambda event: CellarManager.ClickCustomStyleListbox(self, self.Tree_CustomStyles))


            # adds header strings
            for col in event_header:
                self.Tree_CustomStyles.heading(col, text=col.title())
                self.Tree_CustomStyles.column(col, width=tkFont.Font().measure(col.title()))  # adjust the column's width to the header string

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the Cellar listbox.")

    # Update the Custom Styles listbox
    def UpdateCustomStylesListbox(self):

        try:

            # Clear listbox
            for r in self.Tree_CustomStyles.get_children():
                self.Tree_CustomStyles.delete(r)

            # Open Custom Styles.csv
            with open(Path_CustomStyles) as csvfile:
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV)

            # Add each style to listbox
            for style in readCSV:
                if "ADD STYLE" in style:
                    pass
                else:
                    self.Tree_CustomStyles.insert('', 'end', values=style)

            # Update Style Combo Box in cellar tab
            with open(Path_CustomStyles) as csvfile:  # Open correct styles file
                readCSV = csv.reader(csvfile, delimiter=',')
                List_Styles = []
                for row in readCSV:  # Create list of styles by looping through each row
                    style = row[0]
                    List_Styles.append(style)
            self.Combo_Style.config(values=List_Styles)  # Update combo drop down

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue updating the Cellar listbox.")

    #If user clicks style in Custom Style listbox, get index of item and enable TRASH IT button
    def ClickCustomStyleListbox(self, Listbox):

        try:

            for item in Listbox.selection(): #Loop through styles in listbox and find style highlighted
                CellarManager.StyleRowIndex = Listbox.index(item) + 1 #Get row index of selected batch in listbox. Add 1 to RowIndex because "ADD STYLE" is always the first item in the file

            with open(Path_CustomStyles) as csvfile: #Open Custom Styles.csv
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV) #Create list from file
                SelectedStyle = readCSV[CellarManager.StyleRowIndex][0] #[Row][Column]

                CellarManager.Btn_Remove.config(state = tk.NORMAL)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue selecting the custom style in the listbox.")

    #Remove selected custom style from Custom Style.csv, update listbox, reset buttons, update Style combo box
    def DeleteCustomStyle(self, RowIndex):

        try:

            List_CustomStyles = ["Styles"] #Column header
            self.DFCustomStyles = pd.read_csv(Path_CustomStyles, names = List_CustomStyles)  # Create DF from CustomStyles file
            self.DFCustomStyles = self.DFCustomStyles.drop(self.DFCustomStyles.index[RowIndex])  # Remove row
            self.DFCustomStyles.to_csv(Path_CustomStyles, index=False, header=False)  # writes Dataframe back to csv

            CellarManager.UpdateCustomStylesListbox(self)

            CellarManager.Btn_Remove.config(state = tk.DISABLED) #Disable "TRASH IT!" button
            CellarManager.Ent_NewStyle.focus_set() #Set focus to New Style entry box

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue deleting the selected custom style.")

    #Clears and resets entry widgets in Cellar screen
    def ClearEntry(self):

        try:

            List_EntryWids = [self.Ent_Beer, self.Ent_ABV, self.Ent_Quantity, self.Ent_BriteVolume] #List of all entry boxes
            for wid in List_EntryWids: #Clear all entry boxes in list
                wid.config(state = tk.NORMAL)
                wid.delete(0, 'end')

            List_ComboWids = [self.Combo_TankType, self.Combo_Style] #List of all combo boxes
            for wid in List_ComboWids: #Clear all combo boxes
                wid.set("")
            self.Combo_TankType.config(state = 'readonly') #Don't allow user to type anything into combobox
            self.Combo_Style.config(state = 'readonly') #Don't allow user to type anything into combobox

            #Disable certain entry boxes and their labels
            List_DisableWids = [self.Ent_Quantity, self.Ent_BriteVolume, self.Lbl_BriteVolume, self.Lbl_Quantity] #Create list of entry boxes and labels to disable
            for wid in List_DisableWids: #Loop through each entry box or label and disable
                wid.config(state = tk.DISABLED)

            self.Ent_Beer.focus_set()

            CellarManager.RecalledDescription = ""
            CellarManager.RecalledSizePriceString = ""
            Keyboard.LiftKeyboard(self)

            CellarManager.SaveDetails(self, "Clear")

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue clearing and reseting the entry widgets.")

    #If user clicks batch in Cellar listbox on Cellar page, get index, batch, and configure "Delete" button
    def ClickCellarListbox(self, Index):

        try:

            try:

                self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create DF from CurrentInventory file
                Batch = self.DFCurrentInventory.iloc[Index, Dict_CurrentInventoryColumn['Batch']] #Get the name of the batch selected
                Tank = self.DFCurrentInventory.iloc[Index, Dict_CurrentInventoryColumn['Tank Type']] #Get the type of tank
                Quantity = self.DFCurrentInventory.iloc[Index, Dict_CurrentInventoryColumn['Quantity']]  # Get the quantity
                self.Btn_Delete.config(state=tk.NORMAL, bg=self.Color2, command = lambda: CellarManager.Delete(self, Index, Batch)) #Configure DELETE button

                if Tank == "Brite": #If user selects a batch that is in a brite, do not allow allocation
                    self.Btn_Allocate.config(state=tk.DISABLED)
                else: #If batch is not in a brite, allow allocation
                    self.Btn_Allocate.config(state=tk.NORMAL, bg=self.Color2, command=lambda: CellarManager.BuildAllocate(self, Batch, Tank, Quantity))  # Configure ALLOCATE button

            except:
                pass

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue when you clicked on the Cellar listbox.")

    #Delete a batch from the Cellar listbox on Cellar page
    def Delete(self, Index, Batch):

        try:

            #Remove batch from CurrentInventory file and update listbox (Check if batch is on tap, and remove if it is)
            self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create DF from CurrentInventory file
            self.DFCurrentInventory = self.DFCurrentInventory.drop(self.DFCurrentInventory.index[Index]) #Remove row with selected batch
            self.DFCurrentInventory.to_csv(Path_CurrentInventory, index=False, header=False)  # writes Dataframe back to csv
            CellarManager.UpdateCurrentInventoryListbox(self, "CELLAR") #update listbox

            #Remove beer from OnTap file (If applicable)
            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders)  # Create DF from OnTap file
            rows = len(self.DFOnTap) #How many rows are in the file?
            if rows == 0: #If there is nothing on tap
                pass
            else: #If there IS something on tap
                self.DFOnTap = self.DFOnTap[self.DFOnTap['Batch'] != Batch] #Sort DF to leave only rows where batch is NOT equal to the batch being deleted
                self.DFOnTap.to_csv(Path_OnTap, index=False, header=False)  # writes Dataframe back to csv

            #Disable/unhighlight "Delete" button
            self.Btn_Delete.config(state = tk.DISABLED, bg = self.Color2) #Disable Delete button

            self.Ent_Beer.focus_set() #Set focus on the Beer entry box
            self.Btn_Allocate.config(state = tk.DISABLED)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue deleting the batch.")

    #BUild GUI to Allocate a keg (or multiple) to other means of removal (Keg sale, donation, distribution, ...)
    def BuildAllocate(self, Batch, Tank, Quantity):

        try:

            Quantity = int(Quantity) #Convert float to integer

            self.CloseToplevels()

            # Toplevel window
            Frame_Allocate = tk.Toplevel(TapStatus.RootWindow)  # Create toplevel window
            if self.Val_ScreenSize == "Desktop":
                Frame_Allocate.geometry("600x400")
                Frame_Allocate.resizable(False, False)  # Do not allow resizing allocation window
            else:
                Frame_Allocate.wm_attributes('-fullscreen', 'true')  # Removes border and title bar from toplevel
            if Platform == "Windows":
                Frame_Allocate.grab_set()  # Prevents other Tkinter windows from being used

            x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
            y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root
            Frame_Allocate.geometry("+%d+%d" % (x + 100, y + 50))  # Place Allocate window at these coordinates (roughly middle of root window)

            # Top/Bottom Frames
            Frame_Top = tk.Frame(Frame_Allocate)
            Frame_Top.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE)
            Frame_TopLeft = tk.LabelFrame(Frame_Top, text = "IN CELLAR")
            Frame_TopLeft.pack(side=tk.LEFT, fill=tk.BOTH, expand=tk.TRUE, padx = 8, pady = 8)
            Frame_TopRight = tk.LabelFrame(Frame_Top, text = "ALLOCATION")
            Frame_TopRight.pack(side=tk.RIGHT, fill=tk.BOTH, expand=tk.TRUE, padx = 8, pady = 8)
            Frame_Bottom = tk.Frame(Frame_Allocate, bg=self.BGColor)
            Frame_Bottom.pack(side=tk.BOTTOM, fill=tk.X)

            # In Cellar Value
            if Quantity == 1:
                Keg = " keg"
            elif Quantity > 1:
                Keg = " kegs"
            Lbl_InCellarValue = tk.Label(Frame_TopLeft, text= "(" + str(Quantity) + ") " + str(Tank) + str(Keg), fg=self.TextColor2, font=F14).pack(side=tk.TOP, padx=1, anchor=tk.N)

            #Get path to tank image
            if Tank == "5 Gal":
                Path_ImgTank = Path_Img5Gal
            elif Tank == "Sixtel" or Tank == "Qtr-BBL":
                Path_ImgTank = Path_ImgSixtel
            elif Tank == "Half-BBL":
                Path_ImgTank = Path_ImgHalfBBL

            ImgWidth = 250
            ImgHeight = 250

            #Tank Image
            try:
                photo = ImageTk.PhotoImage(Image.open(Path_ImgTank).resize((ImgWidth, ImgHeight)))
            except:
                photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
            Lbl_TankImage = tk.Label(Frame_TopLeft, image=photo)
            Lbl_TankImage.image = photo
            Lbl_TankImage.pack(side=tk.TOP)

            #Quantity Label and Combo box
            Lbl_ChooseQuantity = tk.Label(Frame_TopRight, text="QUANTITY", fg=self.TextColor2, font=F10).grid(row = 0, column = 0, padx = 4, pady = 4, sticky = tk.W)
            Values = list(range(1,Quantity + 1))
            CellarManager.Combo_Quantity = ttk.Combobox(Frame_TopRight, values=Values, width=6, font = F8)
            CellarManager.Combo_Quantity.grid(row = 0, column = 1, padx = 4, pady = 4)
            CellarManager.Combo_Quantity.config(state="readonly")  # Don't allow user to type anything into combobox
            CellarManager.Combo_Quantity.bind("<<ComboboxSelected>>", lambda event: Btn_Save.config(state = tk.NORMAL))

            #Allocate To Label
            Lbl_AllocateTo = tk.Label(Frame_TopRight, text="ALLOCATE TO:", fg=self.TextColor2, font=F10).grid(row=1, column=0, padx=4, pady=4, sticky = tk.W)

            #Destination Radio Buttons
            FontSize = F8
            Var_AllocateTo = tk.StringVar(value = 0)
            tk.Radiobutton(Frame_TopRight, text="Distribution", variable=Var_AllocateTo, value="Distribution", font = FontSize, selectcolor=self.Color2).grid(row=2, column=0, padx=4, pady=2, sticky=tk.W)
            tk.Radiobutton(Frame_TopRight, text="Keg Sold In-House", variable=Var_AllocateTo, value="Keg Sold In-House", font = FontSize, selectcolor=self.Color2).grid(row=3, column=0, padx=4, pady=2, sticky=tk.W)
            tk.Radiobutton(Frame_TopRight, text="Waste", variable=Var_AllocateTo, value="Waste", font = FontSize, selectcolor=self.Color2).grid(row=4, column=0, padx=4, pady=2, sticky=tk.W)
            tk.Radiobutton(Frame_TopRight, text="Donation", variable=Var_AllocateTo, value="Donation", font = FontSize, selectcolor=self.Color2).grid(row=5, column=0, padx=4, pady=2, sticky=tk.W)
            tk.Radiobutton(Frame_TopRight, text="Gift", variable=Var_AllocateTo, value="Gift", font = FontSize, selectcolor=self.Color2).grid(row=6, column=0, padx=4, pady=2, sticky=tk.W)
            Var_AllocateTo.set(value = "Distribution")

            #Bottom Menu
            ImgWidth = 60
            ImgHeight = 60
            BtnWidth = 160
            BtnHeight = 40
            FontSize = F4

            #Exit Button
            try:
                photo = ImageTk.PhotoImage(Image.open(Path_ImgSnowboarder).resize((ImgWidth, ImgHeight)))
            except:
                photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
            Lbl_Image = tk.Label(Frame_Bottom, image=photo)
            Lbl_Image.image = photo
            Btn_Exit = tk.Button(Frame_Bottom, text="EXIT", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
            Btn_Exit.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
            Btn_Exit.config(command=lambda: Frame_Allocate.destroy())

            # Save Button
            try:
                photo = ImageTk.PhotoImage(Image.open(Path_ImgRecordPlayer).resize((ImgWidth, ImgHeight)))
            except:
                photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
            Lbl_Image = tk.Label(Frame_Bottom, image=photo)
            Lbl_Image.image = photo
            Btn_Save = tk.Button(Frame_Bottom, text="SAVE", state = tk.DISABLED, width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
            Btn_Save.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
            Btn_Save.config(command=lambda: CellarManager.Allocate(self, Batch, Quantity, CellarManager.Combo_Quantity.get(), Var_AllocateTo.get(), Frame_Allocate))

            #Disable/unhighlight "Allocate" button
            self.Btn_Allocate.config(state = tk.DISABLED, bg = self.Color2) #Disable Delete button

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the allocation GUI.")

    #Once user has chosen and saved the allocation, update Cellar listbox with new quantity, and add to log
    def Allocate(self, Batch, OldQuantity, AllocatedQuantity, Destination, Frame):

        try:

            #Check that quantity value is set
            if AllocatedQuantity == "":
                CellarManager.Combo_Quantity.focus_set()
                return

            NewQuantity = int(OldQuantity) - int(AllocatedQuantity)  # Calculate new quantity (How many kegs are left after allocation?)

            #Adjust Current Inventory Data
            self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create DF from Current Inventory file
            BatchIndex = self.DFCurrentInventory[self.DFCurrentInventory['Batch'] == Batch].index[0]  # Get the index of the row in the DF
            self.List_BatchInfo = self.DFCurrentInventory.loc[BatchIndex, :].values.tolist()  # Create list from DF row

            self.DFCurrentInventory = self.DFCurrentInventory.drop(self.DFCurrentInventory.index[BatchIndex])  # Drop outdated row
            self.DFCurrentInventory.to_csv(Path_CurrentInventory, index=False, header=False)  # writes Data to csv

            if NewQuantity == 0:  #If user allocated all kegs of this batch (nothing left)
                pass
            else:
                # Save it back to CurrentInventory
                self.List_BatchInfo[Dict_CurrentInventoryColumn['Quantity']] = NewQuantity  # Replace current Quantity with new Quantity
                with open(Path_CurrentInventory, mode='a', newline='') as CurrentInventory_file:  # opens file with 'a' for append, does not overwrite anything already in it
                    CurrentInventory_writer = csv.writer(CurrentInventory_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                    CurrentInventory_writer.writerow(self.List_BatchInfo)

            #Update Cellar Listbox
            CellarManager.UpdateCurrentInventoryListbox(self, "CELLAR")  # Call function to update Cellar listbox

            # Get todays date
            try:
                Date = date.today()  # Gets todays date in yyyy-mm-dd format
                format = "%m-%d-%y"
                Date = Date.strftime(format)  # Convert to mm-dd-yy format
                EmptyDate = Date
            except:  # If unable to get date (not connected to Wifi) set as Date Unknown
                Date = "Date Unknown"
                EmptyDate = Date

            #Adjust data being saved to Log
            self.List_BatchInfo[Dict_CurrentInventoryColumn['Quantity']] = AllocatedQuantity  # Replace current Quantity with new allocated quantity

            # Delete things not being saved to Log (delete from highest index to lowest index)
            List_LogRow = self.List_BatchInfo
            List_NotInLogRow = ['Str_SizePrice', 'Description', 'Total Volume'] #since the LogRow is coming from the Cellar, this list will be different than if emptying from Taproom
            for ColumnHeader in List_NotInLogRow:
                del List_LogRow[Dict_CurrentInventoryColumn[ColumnHeader]]

            # Add things being saved to Log
            List_LogRow.append(Destination) #Add destination to row being saved to Log file (this is also done when saving "Emptied" kegs to log from Taproom)
            List_LogRow.append(EmptyDate)  # Add Empty Date
            List_LogRow.append(EmptyDate)  # Add On Tap Date (since it's being allocated, it's the same as the Empty Date)

            Reports.SaveToLog(self, List_LogRow)  # Call function to save data to log file

            #Adjust On Tap Data
            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders)  # Create DF from On Tap file
            Num_OnTap = len(self.DFOnTap)
            if Num_OnTap == 0:
                pass
            else:
                BatchIndex = self.DFOnTap[self.DFOnTap['Batch'] == Batch].index[0]  # Get the index of the row in the DF
                self.List_BatchInfo = self.DFOnTap.loc[BatchIndex, :].values.tolist()  # Create list from DF row

                self.DFOnTap = self.DFOnTap.drop(self.DFOnTap.index[BatchIndex])  # Drop outdated row
                self.DFOnTap.to_csv(Path_OnTap, index=False, header=False)  # writes Data to csv

                # Save it back to On Tap
                self.List_BatchInfo[Dict_OnTapColumn['Quantity']] = NewQuantity  # Replace current Quantity with new Quantity
                with open(Path_OnTap, mode='a', newline='') as OnTap_file:  # opens file with 'a' for append, does not overwrite anything already in it
                    OnTap_writer = csv.writer(OnTap_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                    OnTap_writer.writerow(self.List_BatchInfo)

            #Update On Tap
            TaproomManager.UpdateOnTapListbox(self)

            Frame.destroy() #Close out of Allocate GUI

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue allocating these kegs.")

    #Enables/Disables widgets depending on what type of tank was selected in Tank Type combobox
    def PickTank(self, TankType):

        try:

            Keyboard.ExitKeyboard(self) #Exit Keyboard (if up)

            self.Ent_BriteVolume.delete(0, 'end') #Clear Brite Volume entry box

            if TankType == "Brite": #If tank type selected is "Brite"

                self.Ent_Quantity.config(state=tk.NORMAL) #Enable Quantity entry box
                self.Ent_Quantity.delete(0, 'end') #Clear Quantity entry box
                self.Ent_Quantity.insert(0,'1') #Enter '1' into the Quantity entry box
                self.Ent_Quantity.config(state = tk.DISABLED) #Disable Quantity entry box
                self.Lbl_BriteVolume.config(state=tk.NORMAL) #Enable Brite Volume label
                self.Lbl_Quantity.config(state=tk.DISABLED)  # Disable Quantity label

                self.Ent_BriteVolume.config(state = tk.NORMAL) #Enable Brite Volume entry box
                self.Ent_BriteVolume.focus_set() #Set cursor focus on Brite Volume entry box

            else: #If tank type selected is anything other than "Brite"

                self.Ent_Quantity.config(state=tk.NORMAL) #Enable Quantity entry box
                self.Ent_Quantity.delete(0, 'end') #Clear Quantity entry box
                self.Ent_Quantity.focus_set() #Set cursor focus on Quantity entry box
                self.Lbl_BriteVolume.config(state=tk.DISABLED) #Disable Brite Volume label
                self.Lbl_Quantity.config(state = tk.NORMAL) #Enable Quantity label

                self.Ent_BriteVolume.config(state=tk.DISABLED) #Disable Brite Volume entry box

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue enabling or disabling widgets after selecting a tank.")

    #Data validation for entry boxes (Allow decimals, or integers)
    def CheckEntry(self, Widget, Type, Min, Max):

        try:

            if Type == "Decimal": #If restricting entry to decimals
                Ent = Widget.get() #Get what the user has entered
                self.List_ValidDecimalCharacters = ["0","1","2","3","4","5","6","7","8","9","."] #Allow only these characters
                n = 0
                #Check if character is a number or decimal point (or something not allowed)
                for character in Ent:
                    if character in self.List_ValidDecimalCharacters: #Character is allowed
                        pass #if yes, do nothing
                    else: #Character is not allowed, replace the character with a blank, clear the entry box, and reinsert the string
                        Ent = Ent.replace(Ent[n], '') #Replace with a blank
                        Widget.delete(0, tk.END) #Clear
                        Widget.insert(0, Ent) #Re-insert fixed string
                    n = n + 1

                #This loop check that there is no more than one decimal point in the string
                p = 0
                for character in Ent:
                    if character == ".":
                        p = p + 1
                        if p > 1:
                            Ent = Ent[:-1]
                            Widget.delete(0, tk.END)
                            Widget.insert(0, Ent)
                    else:
                        pass

                #Checks that if the first digit is 0, the second digit is "." (ex. 0.09 or 0.13, not 09.34)
                if len(Ent) > 0: #if there is any entry
                    FirstDig = Ent[0] #What is the first digit?
                    if FirstDig == "0": #If the first digit is "0"
                        if len(Ent) > 1: #and the entry is more than one digit
                            SecDig = Ent[1] #get the second digit
                            if SecDig != ".": #if the second digit is not a decimal
                                Widget.delete(0, tk.END) #Clear all in case user clicks and inserts dumb stuff

                if Ent == "":
                    pass
                else:
                    Ent = float(Ent)  # Convert string to float
                    if Ent < Min:  # If entry is less than min
                        Widget.delete(0, tk.END)  # Clear entry
                    if Ent > Max:  # If entry is greater than max
                        Widget.delete(0, tk.END)  # Clear entry

            if Type == "Integer": #If restricting entry to integers
                Ent = Widget.get()
                self.List_ValidDecimalCharacters = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"]
                n = 0
                # Check if character is a number
                for character in Ent:
                    if character in self.List_ValidDecimalCharacters:
                        pass  # if yes, do nothing
                    else:
                        # if no, replace the character with a blank, clear the entry box, and reinsert the string
                        Ent = Ent.replace(Ent[n], '')
                        Widget.delete(0, tk.END)
                        Widget.insert(0, Ent)
                    n = n + 1

                #Checks that the first digit is not 0 (ex. 094 or 09.43)
                if len(Ent) > 0:
                    FirstDig = Ent[0]
                    if FirstDig == "0":
                        Widget.delete(0, tk.END)

                if Ent == "":
                    pass
                else:
                    Ent = int(Ent) #Convert string to Int
                    if Ent < Min: #If entry is less than min
                        Widget.delete(0, tk.END) #Clear entry
                    if Ent > Max: #If entry is greater than max
                        Widget.delete(0, tk.END) #Clear entry

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue with data entry validation.")

#Reports (Handles compiling, calculating, and displaying stats on Reports tab)
class Reports:

    #When user clicks "Empty", log the finished tank to log (Does not run if user clicks "Return")
    def SaveToLog(self, BatchInfo):

        try:

            #Get individual metrics in order to save to file in correct format
            InputDate = BatchInfo[Dict_LogColumn['Input Date']]
            Beer = BatchInfo[Dict_LogColumn['Beer Name']]
            BrewDate = BatchInfo[Dict_LogColumn['Brew Date']]
            Batch = BatchInfo[Dict_LogColumn['Batch']]
            Style = BatchInfo[Dict_LogColumn['Style']]
            ABV = BatchInfo[Dict_LogColumn['ABV']]
            TankType = BatchInfo[Dict_LogColumn['Tank Type']]
            TankVolume = BatchInfo[Dict_LogColumn['Tank Volume']]
            VolUnit = BatchInfo[Dict_LogColumn['Volume Unit']]
            AllocateTo = BatchInfo[Dict_LogColumn['Allocate To']]
            EmptyDate = BatchInfo[Dict_LogColumn['Empty Date']]
            OnTapDate = BatchInfo[Dict_LogColumn['On Tap Date']]

            if AllocateTo == "Taproom Draft":
                Quantity = 1 #Save 1 keg to the log
            else:
                Quantity = BatchInfo[Dict_LogColumn['Quantity']] #Save the number of allocated kegs to the log

            #Save to Log
            with open(Path_Log, mode='a', newline='') as Log_file:  # opens file with 'a' for append, does not overwrite anything already in it
                Log_writer = csv.writer(Log_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
                Log_writer.writerow([InputDate, Beer, BrewDate, Batch, Style, ABV, TankType, Quantity, TankVolume, VolUnit, AllocateTo, EmptyDate, OnTapDate])

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue saving the empty tank to the log.")

    #Create DF from Log.csv, look up and calculate statistics
    def CalculateStats(self):

        try:

            self.DFLog = pd.read_csv(Path_Log, names=List_LogHeaders)  # Create DF from Log file
            rows = len(self.DFLog)

            #Allocation Stats
            if rows == 0:
                self.TaproomDraftVol = "0"
                self.DistributionVol = "0"
                self.TaproomKegSaleVol = "0"
                self.WasteVol = "0"
                self.DonationVol = "0"
                self.GiftVol = "0"
            else:
                self.TaproomDraftVol = 0
                self.DistributionVol = 0
                self.TaproomKegSaleVol = 0
                self.WasteVol = 0
                self.DonationVol = 0
                self.GiftVol = 0
                for row in range(0,rows):
                    AllocateTo = self.DFLog.iloc[row, Dict_LogColumn['Allocate To']] #Get AllocateTo value (distibution, taproom draft, waste,...)
                    TankType = self.DFLog.iloc[row, Dict_LogColumn['Tank Type']] #Get the type of keg
                    Quantity = self.DFLog.iloc[row, Dict_LogColumn['Quantity']] #Get the quantity of kegs allocated
                    if TankType == "Brite":
                        TankVolume = self.DFLog.iloc[row, Dict_LogColumn['Tank Volume']] #Get the volume of the batch in the brite tank
                        Vol_Units = self.Val_VolumeUnit #Are brite tanks in gallons or bbl's?

                        #If volume units are BBL's, convert to gallons
                        if Vol_Units == 'BBL':
                            TotalVolume = TankVolume * GallonsPerBBL
                        else:
                            TotalVolume = TankVolume #Set the tank volume equal to the total volume

                    else:
                        TankVolumeGal = float(Dict_TankVolumeGal[TankType]) #Get the volume of the keg type in gallons
                        TotalVolume = TankVolumeGal * Quantity #Calculate the total volume in gallons

                    if AllocateTo == "Taproom Draft":
                        self.TaproomDraftVol = round(self.TaproomDraftVol + TotalVolume, 1)
                    elif AllocateTo == "Distribution":
                        self.DistributionVol = round(self.DistributionVol + TotalVolume, 1)
                    elif AllocateTo == "Keg Sold In-House":
                        self.TaproomKegSaleVol = round(self.TaproomKegSaleVol + TotalVolume, 1)
                    elif AllocateTo == "Waste":
                        self.WasteVol = round(self.WasteVol + TotalVolume, 1)
                    elif AllocateTo == "Donation":
                        self.DonationVol = round(self.DonationVol + TotalVolume, 1)
                    elif AllocateTo == "Gift":
                        self.GiftVol = round(self.GiftVol + TotalVolume, 1)

            #Emptied Stats
            #Count number of unique beers, set to dictionary with Beer/Quantity pairs
            List_AllBeers = self.DFLog['Beer Name'].to_list() #Create list from "Beer Name" column
            Dict_BeerCount = {} #Create empty dictionary to hold Beer/Quantity pairs
            for Beer in List_AllBeers: #Loop through list and count Beers
                Dict_BeerCount[Beer] = Dict_BeerCount.get(Beer, 0) + 1 #Update dictionary

            self.NumBeers = len(Dict_BeerCount) #Get the number of beers

            #Count number of Batches
            List_AllBatches = self.DFLog['Batch'].to_list()  # Create list from "Batch" column
            List_AllBatches = list(dict.fromkeys(List_AllBatches)) #Create dictionary and remove duplicates
            self.NumBatches = len(List_AllBatches) #Count number of Batches by getting length of List_AllBeers

            #ABV
            List_AllABV = self.DFLog['ABV'].to_list()  # Create list from "ABV" column
            if len(List_AllABV) == 0:
                self.MinABV = "0%"
                self.AvgABV = "0%"
                self.MaxABV = "0%"
            else:
                self.MinABV = min(List_AllABV) #Get min ABV
                self.AvgABV = round(sum(List_AllABV) / len(List_AllABV), 1) #Calculate Avg ABV
                self.MaxABV = max(List_AllABV) #Get max ABV

            #Tanks
            self.Dict_TankQuantity = {}  # Create empty dictionary to hold Tank/Quantity pairs
            self.NumTanksEmptiedValue = 0

            #Open log file and read row into a list
            with open(Path_Log) as csvfile:
                readCSV = csv.reader(csvfile, delimiter=',')
                readCSV = list(readCSV)  # Create list from file data

            #Get Tanks emptied by clicking 'Empty' on taproom tab
            for Row in range(0,rows): #Loop through each row
                AllocateTo = readCSV[Row][Dict_LogColumn['Allocate To']] #Get the Allocate To value
                if AllocateTo == "Taproom Draft": #If tank was allocated to Taproom Draft
                    Tank = readCSV[Row][Dict_LogColumn['Tank Type']] #Get the type of tank
                    self.Dict_TankQuantity[Tank] = self.Dict_TankQuantity.get(Tank, 0) + 1  # Update dictionary
                    self.NumTanksEmptiedValue = self.NumTanksEmptiedValue + 1

            #Cellar Stats
            self.DFCurrentInventory = pd.read_csv(Path_CurrentInventory, names=List_CurrentInventoryHeaders)  # Create DF from Current Inventory file

            List_AllBeersInCellar = self.DFCurrentInventory['Beer Name'].to_list()  # Create list from "Beer Name" column
            Dict_BeerCountInCellar = {}  # Create empty dictionary to hold Beer/Quantity pairs
            for Beer in List_AllBeersInCellar:  # Loop through list and count Beers
                Dict_BeerCountInCellar[Beer] = Dict_BeerCountInCellar.get(Beer, 0) + 1  # Update dictionary

            # Count number of Beers by getting length of Dict_BeerCount
            self.NumBeersInCellar = len(Dict_BeerCountInCellar)

            # Count number of Batches by getting length of List_AllBeers
            self.NumBatchesInCellar = len(List_AllBeersInCellar)

            # Tanks
            List_AllTanksInCellar = self.DFCurrentInventory['Tank Type'].to_list()  # Create list from "Tank Type" column
            List_AllTankQuantitiesInCellar = self.DFCurrentInventory['Quantity'].to_list()  # Create list from "Quantity" column

            # Create Dictionary from two lists to form Tank/Qnt pairs
            self.NumTanksInCellar = 0
            self.Dict_TankCountInCellar = {}
            for tank, qnt in zip(List_AllTanksInCellar, List_AllTankQuantitiesInCellar):
                self.Dict_TankCountInCellar[tank] = self.Dict_TankCountInCellar.get(tank, 0) + qnt
                self.NumTanksInCellar = self.NumTanksInCellar + qnt

            # ABV of Cellar
            List_AllABVCellar = self.DFCurrentInventory['ABV'].to_list()  # Create list from "ABV" column
            if len(List_AllABVCellar) == 0:
                self.CellarMinABV = "0%"
                self.CellarAvgABV = "0%"
                self.CellarMaxABV = "0%"
            else:
                self.CellarMinABV = min(List_AllABVCellar)  # Get min ABV
                self.CellarAvgABV = round(sum(List_AllABVCellar) / len(List_AllABVCellar), 1)  # Calculate Avg ABV
                self.CellarMaxABV = max(List_AllABVCellar)  # Get max ABV

            #On Tap Stats
            self.DFOnTap = pd.read_csv(Path_OnTap, names=List_OnTapHeaders)  # Create DF from OnTap file

            List_AllBeersOnTap = self.DFOnTap['Beer Name'].to_list()  # Create list from "Beer Name" column

            # Count number of taps full by getting length of List_AllBeersOnTap
            self.NumOnTap = len(List_AllBeersOnTap)
            self.NumTaps = self.Val_NumTaps

            # ABV of On Tap
            List_AllABVOnTap = self.DFOnTap['ABV'].to_list()  # Create list from "ABV" column
            if len(List_AllABVOnTap) == 0:
                self.OnTapMinABV = "0%"
                self.OnTapAvgABV = "0%"
                self.OnTapMaxABV = "0%"
            else:
                self.OnTapMinABV = min(List_AllABVOnTap)  # Get min ABV
                self.OnTapAvgABV = round(sum(List_AllABVOnTap) / len(List_AllABVOnTap), 1)  # Calculate Avg ABV
                self.OnTapMaxABV = max(List_AllABVOnTap)  # Get max ABV

            # Tanks On Tap
            List_AllTanksOnTap = self.DFOnTap['Tank Type'].to_list()  # Create list from "Tank Type" column
            self.Dict_TankCountOnTap = {}

            #Get the number of each type of tank currently on tap
            for tank in TankTypes:
                NumTankType = List_AllTanksOnTap.count(tank)
                if NumTankType != 0:
                    self.Dict_TankCountOnTap[tank] = NumTankType #Create a dictionary with tank/qty pairs

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue calculating the report statistics.")

    #Build widgets to display report statistics
    def BuildReport(self, Frame):

        try:

            FontSize = F6

            #Allocation Statistics frame
            self.Frame_Allocation = tk.Frame(Frame, bg=self.BGColor)
            self.Frame_Allocation.pack(side=tk.LEFT, padx=4, pady=4, anchor=tk.NW)
            self.Frame_AllocationLabel = tk.Frame(self.Frame_Allocation, bg=self.Color)
            self.Frame_AllocationLabel.pack(side=tk.TOP, fill=tk.X)
            self.Lbl_Allocation = tk.Label(self.Frame_AllocationLabel, text="ALLOCATION", fg=self.TextColor2, bg=self.Color, font=FontSize)
            self.Lbl_Allocation.pack(side=tk.TOP, fill = tk.X)
            self.Frame_AllocationBottom = tk.Frame(self.Frame_Allocation, bg=self.BGColor)
            self.Frame_AllocationBottom.pack(side=tk.TOP, anchor=tk.NW)
            #Emptied Statistics frame
            self.Frame_Emptied = tk.Frame(Frame, bg=self.BGColor)
            self.Frame_Emptied.pack(side=tk.LEFT, padx=4, pady=4, anchor=tk.NW)
            self.Frame_EmptiedLabel = tk.Frame(self.Frame_Emptied, bg = self.Color)
            self.Frame_EmptiedLabel.pack(side = tk.TOP, fill = tk.X)
            self.Lbl_Emptied = tk.Label(self.Frame_EmptiedLabel, text="EMPTIED", fg=self.TextColor2, bg=self.Color, font=FontSize)
            self.Lbl_Emptied.pack(side=tk.TOP)
            #Cellar Statistics frame
            self.Frame_CellarReport = tk.Frame(Frame, bg=self.BGColor)
            self.Frame_CellarReport.pack(side=tk.LEFT, padx=4, pady=4, anchor=tk.NW)
            self.Frame_CellarLabel = tk.Frame(self.Frame_CellarReport, bg=self.Color)
            self.Frame_CellarLabel.pack(side=tk.TOP, fill=tk.X)
            self.Lbl_Cellar = tk.Label(self.Frame_CellarLabel, text="IN CELLAR", fg=self.TextColor2, bg=self.Color, font=FontSize)
            self.Lbl_Cellar.pack(side=tk.TOP)
            #On Tap Statistics frame
            self.Frame_OnTap = tk.Frame(Frame, bg=self.BGColor)
            self.Frame_OnTap.pack(side=tk.LEFT, padx=4, pady=4, anchor=tk.NW)
            self.Frame_OnTapLabel = tk.Frame(self.Frame_OnTap, bg=self.Color)
            self.Frame_OnTapLabel.pack(side=tk.TOP, fill=tk.X)
            self.Lbl_OnTap = tk.Label(self.Frame_OnTapLabel, text="ON TAP", fg=self.TextColor2, bg=self.Color, font=FontSize)
            self.Lbl_OnTap.pack(side=tk.TOP)

            FontSize = F6
            PadY = 4
            PadX = 2

            #Allocation Labels
            self.Lbl_TaproomDraft = tk.Label(self.Frame_AllocationBottom, text="VOLUME (Gal)", fg=self.Color, bg=self.BGColor, font=FontSize)
            self.Lbl_TaproomDraft.grid(row = 0, column = 1, padx = 4)

            List_AllocationLabels = ["EMPTIED - ", "DISTRIBUTION - ", "IN-HOUSE \nKEG SALE - ", "WASTE - ", "DONATION - ", "GIFT - "]
            r = 1
            for label in List_AllocationLabels:
                AllocationLabel = tk.Label(self.Frame_AllocationBottom, text=label, fg=self.TextColor, bg=self.BGColor, font=FontSize)
                AllocationLabel.grid(row=r, column=0, pady=PadY, padx = PadX, sticky=tk.E)
                r = r + 1

            List_AllocationVolumes = [self.TaproomDraftVol, self.DistributionVol, self.TaproomKegSaleVol, self.WasteVol, self.DonationVol, self.GiftVol]
            r = 1
            for label in List_AllocationVolumes:
                AllocationVolume = tk.Label(self.Frame_AllocationBottom, text=label, fg=self.TextColor, bg=self.BGColor, font=FontSize)
                AllocationVolume.grid(row=r, column=1, pady=PadY, padx = PadX, sticky=tk.E)
                r = r + 1

            #Emptied Stats
            PadY = 10
            self.Frame_Input = tk.Frame(self.Frame_Emptied, bg = self.BGColor)
            self.Frame_Input.pack(side = tk.TOP, anchor = tk.N, fill = tk.X, pady = PadY)
            self.Frame_InputTop = tk.Frame(self.Frame_Input, bg=self.BGColor)
            self.Frame_InputTop.pack(side=tk.TOP, fill = tk.X, anchor = tk.N)
            self.Frame_InputBottom = tk.Frame(self.Frame_Input, bg=self.BGColor)
            self.Frame_InputBottom.pack(side=tk.TOP, fill = tk.X)

            FontSize1 = F4
            FontSize2 = F6

            self.Lbl_Input = tk.Label(self.Frame_InputTop, text = "COUNT", fg = self.Color, bg = self.BGColor, font = FontSize1)
            self.Lbl_Input.pack(side = tk.TOP, fill = tk.X, expand = tk.TRUE)
            self.Lbl_NumBeersVal = tk.Label(self.Frame_InputBottom, text=str(self.NumBeers), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_NumBeersVal.grid(row=1, column=0, sticky=tk.N)
            self.Lbl_NumBeers = tk.Label(self.Frame_InputBottom, text = "BEERS", fg = self.TextColor, bg = self.BGColor, font = FontSize1)
            self.Lbl_NumBeers.grid(row = 2, column = 0, sticky = tk.N, padx = 9)
            self.Lbl_NumBatches = tk.Label(self.Frame_InputBottom, text=str(self.NumBatches), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_NumBatches.grid(row=1, column=1, sticky=tk.N)
            self.Lbl_NumBatches = tk.Label(self.Frame_InputBottom, text="BATCHES", fg=self.TextColor, bg=self.BGColor, font=FontSize1)
            self.Lbl_NumBatches.grid(row=2, column=1, sticky=tk.N, padx = 9)

            # ABV Stats
            self.Frame_ABV = tk.Frame(self.Frame_Emptied, bg=self.BGColor)
            self.Frame_ABV.pack(side=tk.TOP, fill = tk.X, anchor=tk.N, pady = PadY)
            self.Frame_ABVTop = tk.Frame(self.Frame_ABV, bg=self.BGColor)
            self.Frame_ABVTop.pack(side=tk.TOP, anchor=tk.N)
            self.Frame_ABVBottom = tk.Frame(self.Frame_ABV, bg=self.BGColor)
            self.Frame_ABVBottom.pack(side=tk.TOP, anchor=tk.N)

            # ABV Stats Labels
            self.Lbl_ABV = tk.Label(self.Frame_ABVTop, text="% ABV", fg=self.Color, bg=self.BGColor, font=FontSize1)
            self.Lbl_ABV.pack(side=tk.TOP)

            List_Range = ['MIN', 'AVG', 'MAX']
            c = 0
            for Range in List_Range:
                ABVRange = tk.Label(self.Frame_ABVBottom, text=Range, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                ABVRange.grid(row=2, column=c, sticky=tk.N)
                c = c + 1

            List_RangeValues = [self.MinABV, self.AvgABV, self.MaxABV]
            c = 0
            for Value in List_RangeValues:
                RangeValue = tk.Label(self.Frame_ABVBottom, text=str(Value), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
                RangeValue.grid(row=1, column=c, sticky=tk.N, padx=8)
                c = c + 1

            #Tanks
            self.Frame_Tanks = tk.Frame(self.Frame_Emptied, bg=self.BGColor)
            self.Frame_Tanks.pack(side=tk.TOP, fill = tk.X, anchor=tk.N, pady = PadY)
            self.Frame_TanksTop = tk.Frame(self.Frame_Tanks, bg=self.BGColor)
            self.Frame_TanksTop.pack(side=tk.TOP, fill=tk.X)
            self.Frame_TanksBottom = tk.Frame(self.Frame_Tanks, bg=self.BGColor)
            self.Frame_TanksBottom.pack(side=tk.TOP, fill=tk.BOTH, expand = tk.TRUE)
            self.Frame_TanksBottomLeft = tk.Frame(self.Frame_TanksBottom, bg=self.BGColor)
            self.Frame_TanksBottomLeft.pack(side=tk.LEFT, fill=tk.Y, expand = tk.TRUE)
            self.Frame_TanksBottomRight = tk.Frame(self.Frame_TanksBottom, bg=self.BGColor)
            self.Frame_TanksBottomRight.pack(side=tk.RIGHT, fill=tk.Y, expand = tk.TRUE)

            self.Lbl_Tanks = tk.Label(self.Frame_TanksTop, text="TANKS", fg=self.Color, bg=self.BGColor, font=FontSize1)
            self.Lbl_Tanks.pack(side=tk.TOP)

            #Left/Right frames for Type/Qnt
            self.Lbl_TankType = tk.Label(self.Frame_TanksBottomLeft, text="TYPE", fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_TankType.grid(row=0, column=0, sticky=tk.N)
            self.Lbl_TankQnt = tk.Label(self.Frame_TanksBottomRight, text="QNT", fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_TankQnt.grid(row=0, column=0, sticky=tk.N)

            #Dynamically create labels for Tank and Qnt based on Dict_TankQuantity
            r = 1
            for Tank in self.Dict_TankQuantity:
                Count = self.Dict_TankQuantity[Tank]
                Lbl_Tank = tk.Label(self.Frame_TanksBottomLeft, text=Tank, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                Lbl_Tank.grid(row=r, column=0, sticky=tk.N)

                Lbl_Count = tk.Label(self.Frame_TanksBottomRight, text=Count, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                Lbl_Count.grid(row=r, column=0, sticky=tk.N)

                r = r + 1

            # Total Tanks Emptied
            Lbl_TotalTanksEmptied = tk.Label(self.Frame_TanksBottomLeft, text="TOTAL", fg=self.TextColor, bg=self.BGColor, font=FontSize1)
            Lbl_TotalTanksEmptied.grid(row=r, column=0, sticky=tk.N)
            Lbl_TotalTanksEmptiedValue = tk.Label(self.Frame_TanksBottomRight, text=self.NumTanksEmptiedValue, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
            Lbl_TotalTanksEmptiedValue.grid(row=r, column=0, sticky=tk.N)

            # Cellar Stats
            self.Frame_CellarCount = tk.Frame(self.Frame_CellarReport, bg=self.BGColor)
            self.Frame_CellarCount.pack(side=tk.TOP, anchor=tk.N, fill = tk.X, pady = PadY)
            self.Frame_CellarCountTop = tk.Frame(self.Frame_CellarCount, bg=self.BGColor)
            self.Frame_CellarCountTop.pack(side=tk.TOP, fill=tk.X)
            self.Frame_CellarCountBottom = tk.Frame(self.Frame_CellarCount, bg=self.BGColor)
            self.Frame_CellarCountBottom.pack(side=tk.TOP, fill=tk.X)

            # Cellar Stats Labels
            self.Lbl_CellarCount = tk.Label(self.Frame_CellarCountTop, text="COUNT", fg=self.Color, bg=self.BGColor, font=FontSize1)
            self.Lbl_CellarCount.pack(side=tk.TOP)
            self.Lbl_NumBeersVal = tk.Label(self.Frame_CellarCountBottom, text=str(self.NumBeersInCellar), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_NumBeersVal.grid(row=1, column=0, sticky=tk.N)
            self.Lbl_NumBeers = tk.Label(self.Frame_CellarCountBottom, text="BEERS", fg=self.TextColor, bg=self.BGColor, font=FontSize1)
            self.Lbl_NumBeers.grid(row=2, column=0, sticky=tk.N, padx=9)
            self.Lbl_NumBatches = tk.Label(self.Frame_CellarCountBottom, text=str(self.NumBatchesInCellar), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_NumBatches.grid(row=1, column=1, sticky=tk.N)
            self.Lbl_NumBatches = tk.Label(self.Frame_CellarCountBottom, text="BATCHES", fg=self.TextColor, bg=self.BGColor, font=FontSize1)
            self.Lbl_NumBatches.grid(row=2, column=1, sticky=tk.N, padx=9)

            # Cellar ABV Stats
            self.Frame_CellarABV = tk.Frame(self.Frame_CellarReport, bg=self.BGColor)
            self.Frame_CellarABV.pack(side=tk.TOP, fill=tk.X, anchor=tk.N, pady = PadY)
            self.Frame_CellarABVTop = tk.Frame(self.Frame_CellarABV, bg=self.BGColor)
            self.Frame_CellarABVTop.pack(side=tk.TOP, anchor=tk.N)
            self.Frame_CellarABVBottom = tk.Frame(self.Frame_CellarABV, bg=self.BGColor)
            self.Frame_CellarABVBottom.pack(side=tk.TOP, anchor=tk.N)

            # On Tap ABV Stats Labels
            self.Lbl_CellarABV = tk.Label(self.Frame_CellarABVTop, text="% ABV", fg=self.Color, bg=self.BGColor, font=F2)
            self.Lbl_CellarABV.pack(side=tk.TOP)

            List_Range = ['MIN', 'AVG', 'MAX']
            c = 0
            for Range in List_Range:
                ABVRange = tk.Label(self.Frame_CellarABVBottom, text=Range, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                ABVRange.grid(row=2, column=c, sticky=tk.N)
                c = c + 1

            List_RangeValues = [self.CellarMinABV, self.CellarAvgABV, self.CellarMaxABV]
            c = 0
            for Value in List_RangeValues:
                RangeValue = tk.Label(self.Frame_CellarABVBottom, text=str(Value), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
                RangeValue.grid(row=1, column=c, sticky=tk.N, padx=8)
                c = c + 1

            #Tanks
            self.Frame_TanksInCellar = tk.Frame(self.Frame_CellarReport, bg=self.BGColor)
            self.Frame_TanksInCellar.pack(side=tk.TOP, fill=tk.X, anchor=tk.N, pady = PadY)
            self.Frame_TanksInCellarTop = tk.Frame(self.Frame_TanksInCellar, bg=self.BGColor)
            self.Frame_TanksInCellarTop.pack(side=tk.TOP, fill=tk.X)
            self.Frame_TanksInCellarBottom = tk.Frame(self.Frame_TanksInCellar, bg=self.BGColor)
            self.Frame_TanksInCellarBottom.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE)
            self.Frame_TanksInCellarBottomLeft = tk.Frame(self.Frame_TanksInCellarBottom, bg=self.BGColor)
            self.Frame_TanksInCellarBottomLeft.pack(side=tk.LEFT, fill=tk.Y, expand=tk.TRUE)
            self.Frame_TanksInCellarBottomRight = tk.Frame(self.Frame_TanksInCellarBottom, bg=self.BGColor)
            self.Frame_TanksInCellarBottomRight.pack(side=tk.RIGHT, fill=tk.Y, expand=tk.TRUE)

            self.Lbl_Tanks = tk.Label(self.Frame_TanksInCellarTop, text="TANKS", fg=self.Color, bg=self.BGColor, font=FontSize1)
            self.Lbl_Tanks.pack(side=tk.TOP)

            # Left/Right frames for Type/Qnt
            self.Lbl_TankType = tk.Label(self.Frame_TanksInCellarBottomLeft, text="TYPE", fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_TankType.grid(row=0, column=0, sticky=tk.N)
            self.Lbl_TankQnt = tk.Label(self.Frame_TanksInCellarBottomRight, text="QNT", fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_TankQnt.grid(row=0, column=0, sticky=tk.N)

            # Dynamically create labels for Tank and Qnt based on Dict_TankCount
            r = 1
            for Tank in self.Dict_TankCountInCellar:
                Count = self.Dict_TankCountInCellar[Tank]
                Lbl_Tank = tk.Label(self.Frame_TanksInCellarBottomLeft, text=Tank, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                Lbl_Tank.grid(row=r, column=0, sticky=tk.N)

                Lbl_Count = tk.Label(self.Frame_TanksInCellarBottomRight, text=Count, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                Lbl_Count.grid(row=r, column=0, sticky=tk.N)

                r = r + 1

            #Total Tanks in Cellar
            Lbl_TotalTanks = tk.Label(self.Frame_TanksInCellarBottomLeft, text="TOTAL", fg=self.TextColor, bg=self.BGColor, font=FontSize1)
            Lbl_TotalTanks.grid(row=r, column=0, sticky=tk.N)
            Lbl_TotalTanksValue = tk.Label(self.Frame_TanksInCellarBottomRight, text=self.NumTanksInCellar, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
            Lbl_TotalTanksValue.grid(row=r, column=0, sticky=tk.N)

            #On Tap
            self.Frame_OnTapCount = tk.Frame(self.Frame_OnTap, bg=self.BGColor)
            self.Frame_OnTapCount.pack(side=tk.TOP, fill=tk.X, anchor=tk.N, pady = PadY)
            self.Frame_OnTapTop = tk.Frame(self.Frame_OnTapCount, bg=self.BGColor)
            self.Frame_OnTapTop.pack(side=tk.TOP, fill=tk.X)
            self.Frame_OnTapBottom = tk.Frame(self.Frame_OnTapCount, bg=self.BGColor)
            self.Frame_OnTapBottom.pack(side=tk.TOP, fill=tk.X)
            
            # OnTap Stats Labels
            self.Lbl_OnTapCurrently = tk.Label(self.Frame_OnTapTop, text="          TAPS FULL          ", fg=self.Color, bg=self.BGColor, font=FontSize1)
            self.Lbl_OnTapCurrently.pack(side=tk.TOP)
            self.Lbl_TapsFull = tk.Label(self.Frame_OnTapBottom, text= str(self.NumOnTap) + " of " + str(self.NumTaps), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_TapsFull.pack(side=tk.TOP)

            # On Tap ABV Stats
            self.Frame_OnTapABV = tk.Frame(self.Frame_OnTap, bg=self.BGColor)
            self.Frame_OnTapABV.pack(side=tk.TOP, fill=tk.X, anchor=tk.N, pady = PadY)
            self.Frame_OnTapABVTop = tk.Frame(self.Frame_OnTapABV, bg=self.BGColor)
            self.Frame_OnTapABVTop.pack(side=tk.TOP, anchor=tk.N)
            self.Frame_OnTapABVBottom = tk.Frame(self.Frame_OnTapABV, bg=self.BGColor)
            self.Frame_OnTapABVBottom.pack(side=tk.TOP, anchor=tk.N)

            # On Tap ABV Stats Labels
            self.Lbl_OnTapABV = tk.Label(self.Frame_OnTapABVTop, text="% ABV", fg=self.Color, bg=self.BGColor, font=FontSize1)
            self.Lbl_OnTapABV.pack(side=tk.TOP)

            List_Range = ['MIN', 'AVG', 'MAX']
            c = 0
            for Range in List_Range:
                ABVRange = tk.Label(self.Frame_OnTapABVBottom, text=Range, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                ABVRange.grid(row=2, column=c, sticky=tk.N)
                c = c + 1

            List_RangeValues = [self.OnTapMinABV, self.OnTapAvgABV, self.OnTapMaxABV]
            c = 0
            for Value in List_RangeValues:
                RangeValue = tk.Label(self.Frame_OnTapABVBottom, text=str(Value), fg=self.TextColor, bg=self.BGColor, font=FontSize2)
                RangeValue.grid(row=1, column=c, sticky=tk.N, padx=8)
                c = c + 1

            # Tanks On Tap
            self.Frame_TanksOnTap = tk.Frame(self.Frame_OnTap, bg=self.BGColor)
            self.Frame_TanksOnTap.pack(side=tk.TOP, fill=tk.X, anchor=tk.N)
            self.Frame_TanksOnTapTop = tk.Frame(self.Frame_TanksOnTap, bg=self.BGColor)
            self.Frame_TanksOnTapTop.pack(side=tk.TOP, fill=tk.X)
            self.Frame_TanksOnTapBottom = tk.Frame(self.Frame_TanksOnTap, bg=self.BGColor)
            self.Frame_TanksOnTapBottom.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE)
            self.Frame_TanksOnTapBottomLeft = tk.Frame(self.Frame_TanksOnTapBottom, bg=self.BGColor)
            self.Frame_TanksOnTapBottomLeft.pack(side=tk.LEFT, fill=tk.Y, expand=tk.TRUE)
            self.Frame_TanksOnTapBottomRight = tk.Frame(self.Frame_TanksOnTapBottom, bg=self.BGColor)
            self.Frame_TanksOnTapBottomRight.pack(side=tk.RIGHT, fill=tk.Y, expand=tk.TRUE)

            self.Lbl_TanksOnTap = tk.Label(self.Frame_TanksOnTapTop, text="TANKS", fg=self.Color, bg=self.BGColor, font=FontSize1)
            self.Lbl_TanksOnTap.pack(side=tk.TOP)

            # Left/Right frames for Type/Qnt
            self.Lbl_TankTypeOnTap = tk.Label(self.Frame_TanksOnTapBottomLeft, text="TYPE", fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_TankTypeOnTap.grid(row=0, column=0, sticky=tk.N)
            self.Lbl_TankQntOnTap = tk.Label(self.Frame_TanksOnTapBottomRight, text="QNT", fg=self.TextColor, bg=self.BGColor, font=FontSize2)
            self.Lbl_TankQntOnTap.grid(row=0, column=0, sticky=tk.N)

            # Dynamically create labels for Tank and Qnt based on Dict_TankQuantity
            r = 1
            for Tank in self.Dict_TankCountOnTap:
                Count = self.Dict_TankCountOnTap[Tank]
                Lbl_TankOnTap = tk.Label(self.Frame_TanksOnTapBottomLeft, text=Tank, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                Lbl_TankOnTap.grid(row=r, column=0, sticky=tk.N)

                Lbl_CountOnTap = tk.Label(self.Frame_TanksOnTapBottomRight, text=Count, fg=self.TextColor, bg=self.BGColor, font=FontSize1)
                Lbl_CountOnTap.grid(row=r, column=0, sticky=tk.N)

                r = r + 1

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the report.")

#Tap List (Handles creating and adjusting Tap List display screen)
class TapList:

    #Get Tap List options and build the Tap List to display on a second screen
    def CreateTapListScreen(self, Frame, Reset):

        if Reset == "True":

            # Check if Tap List GUI is hidden
            NumGUI = 0
            for wid in Frame.winfo_children():
                if wid.winfo_class() == "Toplevel":
                    if wid.winfo_name() == 'taplist':
                        NumGUI = NumGUI + 1

            # If the Tap List GUI is hidden, do not run this function
            if NumGUI == 0:
                return

            for wid in self.Frame_Top.winfo_children():
                if wid.winfo_class() == "Label":
                    wid.destroy()

            for wid in self.Frame_Middle.winfo_children():
                if wid.winfo_class() == "Frame":
                    wid.destroy()

            CellarManager.Btn_ExitTapList.destroy()

        elif Reset == "False":
            pass

        self.GetTapListOptions()

        # Set option values to simpler variables
        Name = self.Val_Name #Name of brewery, bar, ...
        ListName = self.Val_ListName #What the user wants to refer to the list as (Draft List, Beer List, On Tap,...)
        TopTitle = self.Val_TopTitle #What combination of Name and List Name does user want displayed
        BeerFontSize = self.Val_BeerFontSize
        StyleFontSize = self.Val_StyleFontSize
        SizePriceFontSize = self.Val_SizePriceFontSize
        PadX = self.Val_PadX  # Horizantal spacing
        PadY = self.Val_PadY  # Vertical spacing
        Columns = int(self.Val_Columns)  # What did the user set as the number of columns they want in the tap list?
        NameFontSize = self.Val_NameFontSize
        ListNameFontSize = self.Val_ListNameFontSize
        DisplayStyle = self.Val_DisplayStyle
        DisplayABV = self.Val_DisplayABV
        DisplayDescription = self.Val_DisplayDescription
        DisplayWrap = self.Val_DisplayWrap
        DescriptionFontSize = self.Val_DescriptionFontSize
        DisplayPricing = self.Val_DisplayPricing

        BackgroundColor = Dict_Colors[self.Val_BackgroundColor]
        TopBackgroundColor = Dict_Colors[self.Val_TopBackgroundColor]
        NameTextColor = Dict_Colors[self.Val_NameTextColor]
        ListNameTextColor = Dict_Colors[self.Val_ListNameTextColor]
        BeerBackgroundColor = Dict_Colors[self.Val_BeerBackgroundColor]
        BeerTextColor = Dict_Colors[self.Val_BeerTextColor]
        StyleBackgroundColor = Dict_Colors[self.Val_StyleBackgroundColor]
        StyleTextColor = Dict_Colors[self.Val_StyleTextColor]
        SizePriceBackgroundColor = Dict_Colors[self.Val_SizePriceBackgroundColor]
        SizePriceTextColor = Dict_Colors[self.Val_SizePriceTextColor]
        DescriptionBackgroundColor = Dict_Colors[self.Val_DescriptionBackgroundColor]
        DescriptionTextColor = Dict_Colors[self.Val_DescriptionTextColor]

        List_DarkColors = [B,AB,GM,SG] #Background colors that would be hard to see a black button on
        if Reset == "True":
            self.Frame_Top.config(bg=TopBackgroundColor)
            self.Frame_Middle.config(bg = BackgroundColor)
            if TopBackgroundColor in List_DarkColors: #If background color is dark, configure Exit button image to white
                Path_Image = path.join('img', "KickWhite.png")  # Get path to image
            else:
                Path_Image = path.join('img', "Kick.png")  # Get path to image

        elif Reset == "False":
            x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
            y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root

            self.Frame_TapListWindow = tk.Toplevel(Frame, name = 'taplist') #Create toplevel GUI for tap list
            self.Frame_TapListWindow.geometry("+%d+%d" % (x + 810, y))  # Places Tap List toplevel to the right of the main screen (aiming for second screen to the right)

            self.Frame_Top = tk.Frame(self.Frame_TapListWindow, bg = TopBackgroundColor)
            self.Frame_Top.pack(side = tk.TOP, fill = tk.X)
            self.Frame_Middle = tk.Frame(self.Frame_TapListWindow, bg = BackgroundColor)
            self.Frame_Middle.pack(side=tk.TOP, fill=tk.BOTH, expand = tk.TRUE)

            if TopBackgroundColor in List_DarkColors: #If background color
                Path_Image = path.join('img', "KickWhite.png")  # Get path to image
            else:
                Path_Image = path.join('img', "Kick.png")  # Get path to image

        render = ImageTk.PhotoImage(Image.open(Path_Image).resize((50, 50)))  # Create and size image
        img = tk.Label(Frame, image=render)  # Create label from image
        img.image = render

        CellarManager.Btn_ExitTapList = tk.Button(self.Frame_Top, bg=TopBackgroundColor, bd = 0, image=img.image, command=lambda: TapList.HideTapListScreen(self))  # Place label on button
        CellarManager.Btn_ExitTapList.pack(side=tk.RIGHT, anchor = tk.NE)

        #Create top title labels based on users preference
        if TopTitle == 'Name Only':
            self.Lbl_TopTitle1 = tk.Label(self.Frame_Top, text=Name, font=NameFontSize, bg = TopBackgroundColor, fg = NameTextColor)
            self.Lbl_TopTitle1.pack()
        elif TopTitle == 'Name + List Name':
            self.Lbl_TopTitle1 = tk.Label(self.Frame_Top, text=Name, font=NameFontSize, bg = TopBackgroundColor, fg = NameTextColor)
            self.Lbl_TopTitle1.pack(side = tk.TOP)
            self.Lbl_TopTitle2 = tk.Label(self.Frame_Top, text=ListName, font=ListNameFontSize, bg = TopBackgroundColor, fg = ListNameTextColor)
            self.Lbl_TopTitle2.pack(side = tk.TOP)
        elif TopTitle == 'List Name + Name':
            self.Lbl_TopTitle1 = tk.Label(self.Frame_Top, text=ListName, font=ListNameFontSize, bg = TopBackgroundColor, fg = ListNameTextColor)
            self.Lbl_TopTitle1.pack(side = tk.TOP)
            self.Lbl_TopTitle2 = tk.Label(self.Frame_Top, text=Name, font=NameFontSize, bg = TopBackgroundColor, fg = NameTextColor)
            self.Lbl_TopTitle2.pack(side = tk.TOP)
        elif TopTitle == 'List Name Only':
            self.Lbl_TopTitle1 = tk.Label(self.Frame_Top, text=ListName, font=ListNameFontSize, bg = TopBackgroundColor, fg = ListNameTextColor)
            self.Lbl_TopTitle1.pack(side=tk.TOP)

        #Open On Tap file
        with open(Path_OnTap) as csvfile:
            readCSV = csv.reader(csvfile, delimiter=',')
            readCSV = list(readCSV)
            rows = len(readCSV)  # How many rows (beers) are in the file (on tap)?

            # Check if there are any beers on tap, if there are, look up info
            if rows == 0:  # If rows == 0, this implies no beers on tap
                return  # End function
            else:  # If there are beers on tap

                List_ColumnNums = []  # Create list to hold dynamically created column numbers
                for c in range(0, Columns):
                    List_ColumnNums.append(c)  # Add column number to list

                #Loop through beers and add to columns
                r = 0
                ThisRowNum = 0
                for i in range(0, rows):  # Loop through each row and look up Beer info
                    Beer = readCSV[i][Dict_OnTapColumn['Beer Name']]
                    Style = readCSV[i][Dict_OnTapColumn['Style']]
                    ABV = readCSV[i][Dict_OnTapColumn['ABV']]
                    Description = readCSV[i][Dict_OnTapColumn['Description']]
                    SizePrice = readCSV[i][Dict_OnTapColumn['Str_SizePrice']]

                    #This for loop creates a new "wrapped" description string
                    WrappedDescription = "" #Create a blank string
                    w = 1
                    for word in Description.split(): #Loop through each word in the original string
                        if w%int(int(DisplayWrap)) == 0: #Use modulo funtion to determine if word number is a divisor of the number set by user
                            WrappedDescription = WrappedDescription + " " + str(word) + "\n" #If it is a divisor, add a new line
                        else:
                            WrappedDescription = WrappedDescription + " " + str(word) #If not a divisor, add words to end of string
                        w = w + 1

                    #Count the number of "words" in the pricing string
                    NumWords = 0
                    for word in SizePrice.split(", "):  # Loop through each word in the original string
                        if word == "":
                            pass
                        else:
                            NumWords = NumWords + 1

                    #Split the pricing string at ", "
                    WrappedPricing = ""  # Create a blank string
                    w = 1
                    for word in SizePrice.split(", "):  # Loop through each word in the original string
                        if word == "": #if word is nothing, do nothing
                            pass
                        else:
                            if w <= NumWords - 1:
                                WrappedPricing = str(WrappedPricing) + str(word) + "\n" #If word is not the last word, add a new line
                            else:
                                WrappedPricing = str(WrappedPricing) + str(word) #if word is the last word, do not add new line
                        w = w + 1


                    if Beer == "Busted":
                        pass
                    else:
                        ColumnNum = r%Columns #Calculates what column number this beer should go in (ex. if r = 5 and user set it to 2 columns, then 5mod2 = 1. This beer goes in column 1)
                        ThisColumnNum = List_ColumnNums[ColumnNum]  # Get correct frame from list of frames
                        self.Frame_Middle.columnconfigure(ColumnNum, weight=1)

                        #Get the row number
                        if ThisColumnNum == 0:
                                ThisRowNum = ThisRowNum + 1

                        self.Frame_Middle.rowconfigure(ThisRowNum-1, weight=1)
                        # Create frame to hold all beer info
                        Frame_Beer = tk.Frame(self.Frame_Middle, bg=BackgroundColor)
                        Frame_Beer.grid(column = ThisColumnNum, row = ThisRowNum-1, padx=PadX, pady=PadY, sticky = tk.NSEW)

                        #Beer Name
                        Frame_BeerName = tk.Frame(Frame_Beer, bg=BeerBackgroundColor)
                        Frame_BeerName.pack(side=tk.TOP, fill=tk.X, expand = tk.FALSE, anchor = tk.N)
                        Lbl_Beer = tk.Label(Frame_BeerName, text=Beer, font=BeerFontSize, fg=BeerTextColor, justify=tk.LEFT, bg=BeerBackgroundColor)
                        Lbl_Beer.pack(side=tk.LEFT, padx=8)

                        Frame_Bottom = tk.Frame(Frame_Beer, bg=BackgroundColor)
                        Frame_Bottom.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE, anchor = tk.N)
                        Frame_BeerAndDescription = tk.Frame(Frame_Bottom, bg=O)
                        Frame_BeerAndDescription.pack(side=tk.LEFT, fill=tk.BOTH, expand=tk.TRUE, anchor = tk.NW)
                        Frame_Price = tk.Frame(Frame_Bottom, bg=SizePriceBackgroundColor)
                        Frame_Price.pack(side=tk.RIGHT, fill=tk.Y, expand=tk.FALSE, anchor=tk.E)

                        # Style/ABV
                        if DisplayStyle == "No" and DisplayABV == "No":
                            pass
                        else:
                            if DisplayStyle == "Yes" and DisplayABV == "No":
                                StyleABV = Style
                            elif DisplayStyle == "No" and DisplayABV == "Yes":
                                StyleABV = ABV + "%"
                            elif DisplayStyle == "Yes" and DisplayABV == "Yes":
                                StyleABV = Style + " - " + ABV + "%"

                            Frame_StyleABV = tk.Frame(Frame_BeerAndDescription, bg=StyleBackgroundColor)
                            Frame_StyleABV.pack(side=tk.TOP, fill=tk.X, expand=tk.FALSE, anchor = tk.NW)
                            Lbl_StyleABV = tk.Label(Frame_StyleABV, text=StyleABV, font=StyleFontSize, fg=StyleTextColor, justify=tk.LEFT, bg=StyleBackgroundColor)
                            Lbl_StyleABV.pack(side=tk.LEFT, padx=8, anchor = tk.NW)

                        #Description
                        if DisplayDescription == "Yes":
                            Frame_Description = tk.Frame(Frame_BeerAndDescription, bg=DescriptionBackgroundColor)
                            Frame_Description.pack(side=tk.TOP, fill=tk.BOTH, expand = tk.TRUE, anchor = tk.NW)
                            Lbl_Description = tk.Label(Frame_Description, text=str(WrappedDescription), font=DescriptionFontSize, fg=DescriptionTextColor, justify=tk.LEFT, bg=DescriptionBackgroundColor)
                            Lbl_Description.pack(side=tk.TOP, padx = 4, anchor = tk.NW)
                        else:
                            Frame_BeerAndDescription.config(bg = StyleBackgroundColor)

                        #If Price is only thing displayed
                        if DisplayDescription == "No" and DisplayStyle == "No" and DisplayABV == "No":
                            Frame_BeerAndDescription.config(bg=SizePriceBackgroundColor)

                        #Pricing
                        if DisplayPricing == "Yes":
                            Frame_Pricing = tk.Frame(Frame_Price, bg=SizePriceBackgroundColor)
                            Frame_Pricing.pack(side=tk.RIGHT, fill=tk.Y, expand=tk.FALSE, anchor=tk.E)
                            Lbl_Pricing = tk.Label(Frame_Pricing, text=WrappedPricing, font=SizePriceFontSize, fg=SizePriceTextColor, justify=tk.RIGHT, bg=SizePriceBackgroundColor)
                            Lbl_Pricing.pack(side=tk.RIGHT, anchor = tk.NE, padx = 8, pady = 4)
                        else:
                            pass

                        r = r + 1

        self.Frame_TapList.lift()

    #Destroy Tap List
    def HideTapListScreen(self):

        self.Frame_TapListWindow.destroy()

    #Expand Tap List to fill screen that it is on (remove top bar)
    def FullScreen(self):

        try:
            self.Frame_TapListWindow.wm_attributes('-fullscreen', 'true')  # Removes border and title bar from toplevel
        except:
            print("Tap List is not visible.")

#Keyboard (Handles building and functionality of the on-screen keyboard)
class Keyboard:

    #Builds on-screen keyboard in cellar screen if click the "KEYBOARD" button
    def BuildKeyboard(self, Frame, Source):

        try:

            # Clear Keyboard if up
            for wid in TapStatus.RootWindow.winfo_children():
                if wid.winfo_class() == "Toplevel":
                    if wid.winfo_name() == 'keyboard':
                        wid.destroy()

            #Build and place keyboard toplevel frame
            if Source == "Cellar":
                self.Frame_Keyboard = tk.Toplevel(Frame, name = 'keyboard', highlightbackground="white", highlightcolor="white", highlightthickness=3, bg = self.BGColor) #Keyboard frame
                self.Frame_Keyboard.overrideredirect(True)  # Removes border and title bar from toplevel
                x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
                y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root

                #Formatting Variables
                if Platform == "Windows":
                    self.Frame_Keyboard.geometry("+%d+%d" % (x + 8, y + 258))  # Places Keyboard directly over the top of the CELLAR label and listbox
                    self.Frame_Keyboard.geometry("800x252") #Size of Keyboard frame
                    Height = 2
                    Width = 6
                    PadX = 2
                    PadY = 4
                    Font = F5
                elif Platform == "Pi":
                    self.Frame_Keyboard.geometry("+%d+%d" % (x, y + 235))  # Places Keyboard directly over the top of the CELLAR label and listbox
                    self.Frame_Keyboard.geometry("800x245")  # Size of Keyboard frame
                    Font = F4
                    Height = 2
                    Width = 3
                    PadX = 3
                    PadY = 1

            elif Source == "Details":
                self.Frame_Keyboard = tk.Frame(Frame, name='keyboard', highlightbackground="white", highlightcolor="white", highlightthickness=3, bg=self.BGColor)  # Keyboard frame
                self.Frame_Keyboard.pack()

                # Formatting Variables
                if Platform == "Windows":
                    Height = 2
                    Width = 6
                    PadX = 2
                    PadY = 4
                    Font = F5
                elif Platform == "Pi":
                    Font = F4
                    Height = 2
                    Width = 3
                    PadX = 3
                    PadY = 1

            Relief = 'raised' #Gives 3D appearance to buttons
            ActiveBackground = self.Color
            Bd = 1 #Border width
            NumRow = 0 #What row should all the numbers be on?
            LetterRowQ = 1 #What row should letters QWERTYUIOP be on?
            LetterRowA = 2 #What row should letters ASDFGHJKL be on?
            LetterRowZ = 3 #What row should letters ZXCVBNM be on?

            #Numbers
            c = 1
            List_Numbers = [1,2,3,4,5,6,7,8,9,0]
            for n in List_Numbers:
                self.Btn_n = tk.Button(self.Frame_Keyboard, text=str(n), height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda n = n: Keyboard.ClickNum(self, str(n)))
                self.Btn_n.grid(row=NumRow, column=c, padx=PadX, pady=PadY)
                c = c + 1

            # Letters (Q row)
            c = 1
            List_QRowUpper = ['Q', 'W', 'E', 'R', 'T', 'Y', 'U', 'I', 'O', 'P']
            for q in List_QRowUpper:
                self.Btn_q = tk.Button(self.Frame_Keyboard, text=str(q), height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda q = q: Keyboard.ClickNum(self, str(q)))
                self.Btn_q.grid(row=LetterRowQ, column=c, padx=PadX, pady=PadY)
                c = c + 1

            # Letters (A row)
            c = 1
            List_ARowUpper = ['A', 'S', 'D', 'F', 'G', 'H', 'J', 'K', 'L']
            for a in List_ARowUpper:
                self.Btn_a = tk.Button(self.Frame_Keyboard, text=str(a), height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda a = a: Keyboard.ClickNum(self, str(a)))
                self.Btn_a.grid(row=LetterRowA, column=c, padx=PadX, pady=PadY)
                c = c + 1

            # Letters (Z row)
            c = 1
            List_ZRowUpper = ['Z', 'X', 'C', 'V', 'B', 'N', 'M']
            for z in List_ZRowUpper:
                self.Btn_z = tk.Button(self.Frame_Keyboard, text=str(z), height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda z=z: Keyboard.ClickNum(self, str(z)))
                self.Btn_z.grid(row=LetterRowZ, column=c, padx=PadX, pady=PadY)
                c = c + 1

            # Esc Button
            self.Btn_Esc = tk.Button(self.Frame_Keyboard, text="Esc", height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda: self.Frame_Keyboard.destroy())
            self.Btn_Esc.grid(row=NumRow, column=0, padx=PadX, pady=PadY)

            # Case Button
            self.Btn_Case = tk.Button(self.Frame_Keyboard, text="Lower\nCase", height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda: Keyboard.ChangeCase(self, self.Btn_Case.cget('text')))
            self.Btn_Case.grid(row=LetterRowQ, column=0, padx=PadX, pady=PadY)

            # Dash Button
            self.Btn_Dash = tk.Button(self.Frame_Keyboard, text="-", height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda: Keyboard.ClickNum(self, "-"))
            self.Btn_Dash.grid(row=LetterRowQ, column=11, padx=PadX, pady=PadY)

            # Back Space Button
            self.Btn_Del = tk.Button(self.Frame_Keyboard, text="Back\nSpace", height=Height, width=Width, relief=Relief, state = tk.DISABLED, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda: Keyboard.ClickBackSpace(self))
            self.Btn_Del.grid(row=NumRow, column=11, padx=PadX, pady=PadY)

            # Dec Button
            self.Btn_Dec = tk.Button(self.Frame_Keyboard, text=".", height=Height, width=Width, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda: Keyboard.ClickNum(self, "."))
            self.Btn_Dec.grid(row=LetterRowZ, column=8, padx=PadX, pady=PadY)

            #Space Bar
            if Platform == "Windows":
                SpaceHeight = 2
                SpaceWidth = 19
            elif Platform == "Pi":
                SpaceHeight = 2
                SpaceWidth = 18
            self.Space_Dec = tk.Button(self.Frame_Keyboard, text="SPACE", height=SpaceHeight, width=SpaceWidth, relief=Relief, activebackground=ActiveBackground, bd=Bd, font=Font, command=lambda: Keyboard.ClickNum(self, " "))
            self.Space_Dec.grid(row=LetterRowZ, column=9, columnspan = 3, padx=PadX, pady=PadY)

            Keyboard.NewEntry(self) #Call function to create new entry (blank list)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue building the keyboard.")

    #New Entry creates a blank list
    def NewEntry(self):
        try:

            Keyboard.Entry = []

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue creating a new entry while using the keyboard.")

    #Gets text or value of button clicked and inserts it into the entry box that has focus
    def ClickNum(self, Text):

        try:

            try: #This checks that there is focus. If there is NOT focus, exit keyboard
                Keyboard.focus = focused_entry  # gets entry box that has focus
                pass
            except:
                Keyboard.ExitKeyboard(self)
                return

            Keyboard.Entry.append(Text)  # adds text of button to list
            EntryLength = len(Keyboard.focus.get()) #Gets length of any text already in box. If user starts typing something, clicks something else, then comes back, it will add characters to end of any existing text
            Keyboard.focus.insert(len(Keyboard.Entry) + EntryLength, Text)  # adds new text to end of text in entry box

            #Change to upper case if add space (new word)
            if Text == " ":
                Keyboard.ChangeCase(self, "Upper\nCase")

            self.Btn_Del.config(state = tk.NORMAL)

            Dict_UpperLower = {'A': 'a', 'B': 'b', 'C': 'c', 'D': 'd', 'E': 'e', 'F': 'f', 'G': 'g', 'H': 'h', 'I': 'i', 'J': 'j', 'K': 'k', 'L': 'l', 'M': 'm', 'N': 'n', 'O': 'o', 'P': 'p', 'Q': 'q', 'R': 'r', 'S': 's', 'T': 't', 'U': 'u', 'V': 'v', 'W': 'w', 'X': 'x', 'Y': 'y', 'Z': 'z'}
            Keyboard.List_UpperCase = Dict_UpperLower.keys() #Create list of keys (upper case letters) from dictionary

            LastCharacter = Keyboard.Entry[-1] #Get last character added
            if LastCharacter in Keyboard.List_UpperCase: #If the last character was an upper case, change case
                Keyboard.ChangeCase(self, "Lower\nCase")

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue when you clicked a keyboard button.")

    #Click 'Back Space' to remove last character
    def ClickBackSpace(self):

        try:

            CurrentText = Keyboard.focus.get() #Get text in entry box
            self.focus = focused_entry #Get widget that has focus
            NewWord = CurrentText[:-1] #Remove last character
            self.focus.delete(0, 'end')  # clears widget (entry box)
            self.focus.insert(0, NewWord) #Re-insert new word
            Keyboard.NewEntry(self)

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue using 'Del' in the on-screen keyboard.")

    #If keyboard is up when user clicks something, lift keyboard to front
    def LiftKeyboard(self):

        try:

            try:
                exist = self.Frame_Keyboard.winfo_exists()  # Find if keyboard exists
                if exist == 1:  # If keyboard DOES exist
                    self.Frame_Keyboard.lift() #Lift keyboard to front
                else:
                    pass
            except:
                pass

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue lifting the keyboard to the front.")

    #Change keyboard between upper and lower case
    def ChangeCase(self, Case):

        try:

            List_Numbers = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '0']
            List_Other = ['Esc', 'Lower\nCase', 'Upper\nCase', 'SPACE', '.', '-', 'Back\nSpace']
            Dict_UpperLower = {'A':'a', 'B': 'b', 'C': 'c', 'D': 'd', 'E': 'e', 'F':'f', 'G':'g','H':'h', 'I':'i','J':'j','K':'k','L':'l','M':'m','N':'n','O':'o','P':'p','Q':'q','R':'r','S':'s','T':'t','U':'u','V':'v','W':'w','X':'x', 'Y':'y', 'Z':'z'}
            Dict_LowerUpper = {'a': 'A', 'b': 'B', 'c': 'C', 'd': 'D', 'e': 'E', 'f': 'F', 'g': 'G', 'h': 'H', 'i': 'I', 'j': 'J', 'k': 'K', 'l': 'L', 'm': 'M', 'n': 'N', 'o': 'O', 'p': 'P', 'q': 'Q', 'r': 'R', 's': 'S', 't': 'T', 'u': 'U', 'v': 'V', 'w': 'W', 'x': 'X', 'y': 'Y', 'z': 'Z'}

            #Case = self.Btn_Case.cget('text') #Get the text from the Upper/Lower Case button

            #If the case is lower, change to upper case
            if Case == "Lower\nCase":
                self.Btn_Case.config(text = "Upper\nCase") #Change button text

                for wid in self.Frame_Keyboard.winfo_children(): #Loop through all widgets in keyboard frame
                    if wid.winfo_class() == "Button": #If the widget is a button
                        UpperCaseLetter = wid.cget('text') #Get the button text

                        if UpperCaseLetter in List_Numbers: #If the button is a number button, skip it
                            pass
                        elif UpperCaseLetter in List_Other: #If the button is a not a number or letter, skip it
                            pass
                        else: #If the button is a letter
                            LowerCaseLetter = Dict_UpperLower[UpperCaseLetter] #Look up the corresponding lower case letter
                            wid.config(text = LowerCaseLetter) #reconfigure the button text
                            wid.config(command = lambda LowerCaseLetter = LowerCaseLetter: Keyboard.ClickNum(self, str(LowerCaseLetter))) #Reconfigure function with new text

                    else: #Not a button
                        pass

            #If the case is upper, change to lower case
            else:
                self.Btn_Case.config(text="Lower\nCase")  # Change button text

                for wid in self.Frame_Keyboard.winfo_children():  # Loop through all widgets in keyboard frame
                    if wid.winfo_class() == "Button":  # If the widget is a button
                        LowerCaseLetter = wid.cget('text')  # Get the button text

                        if LowerCaseLetter in List_Numbers:  # If the button is a number button, skip it
                            pass
                        elif LowerCaseLetter in List_Other:  # If the button is a not a number or letter, skip it
                            pass
                        else:  # If the button is a letter
                            UpperCaseLetter = Dict_LowerUpper[LowerCaseLetter]  # Look up the corresponding upper case letter
                            wid.config(text=UpperCaseLetter)  # reconfigure the button text
                            wid.config(command = lambda UpperCaseLetter = UpperCaseLetter: Keyboard.ClickNum(self, str(UpperCaseLetter))) #Reconfigure function with new text

                    else:  # Not a button
                        pass

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue changing to between upper and lower case on the keyboard.")

    #Destroy Keyboard
    def ExitKeyboard(self):

        try:

            try:
                exist = self.Frame_Keyboard.winfo_exists()  # Find if keyboard exists
                if exist == 1:  # If keyboard DOES exist
                    self.Frame_Keyboard.destroy()  # Destroy keyboard
                else:
                    pass
            except:
                pass

        except:

            ErrorHandling.ShowError(self, "Epic Fail!", "There was an issue exiting the keyboard.")

#Error Handing (Handles info, warning, and error messages)
class ErrorHandling:

    #Show Info Messagebox ("i" in a blue triangle)
    def ShowInfo(self, Title, Message):

        ErrorHandling.MessageWindow(self, Title, Message, "Info")

    #Show Warning Messagebox ("!" in a yellow triangle)
    def ShowWarning(self, Title, Message):

        ErrorHandling.MessageWindow(self, Title, Message, "Warning")

    #Show Error Messagebox ("X" in a red circle)
    def ShowError(self, Title, TopMessage):

        ex_type, ex_value, ex_traceback = sys.exc_info() # Get current system exception
        trace_back = traceback.extract_tb(ex_traceback) # Extract unformatter stack traces as tuples
        trace = trace_back[0] # Get first element of traceback

        Line = str(trace[1]) #Line Number
        Func = str(trace[2]) #Function
        Code = str(trace[3]) #Full line of code

        Type = ex_type.__name__ #Type of error
        Message = ex_value #Error message

        ErrorHandling.RecordError(self, Type, Message, Line, Func, Code, FullDetails) #Record error to History File

        ErrorMessage = "\n\nMESSAGE: " + str(Message) + "\n" + "LINE: " + str(Line) + "\n" + "FUNC: " + str(Func) + "\n\n"
        FullMessage = str(TopMessage) + str(ErrorMessage) + str(FullDetails) + "\nGo to https://www.arithmech.com/contact for support."

        ErrorHandling.MessageWindow(self, Title, FullMessage, "Error")

    #Record Error to History File
    def RecordError(self, Type, Message, Line, Func, Code, FullDetails):

        try:
            Date = date.today()
        except:
            Date = "Date Unknown"

        with open('History.csv', mode='a', newline='') as History_file:  # opens file with 'a' for append, does not overwrite anything already in it
            History_writer = csv.writer(History_file, delimiter=',', quotechar='"', quoting=csv.QUOTE_MINIMAL)
            History_writer.writerow([Type, Message, Line, Func, Code, FullDetails, Date])

    #Display message window to user (toplevel)
    def MessageWindow(self, Title, Message, Type):

        self.CloseToplevels()

        # Toplevel window
        Frame_Message = tk.Toplevel(TapStatus.RootWindow) #Create toplevel window
        Frame_Message.title(Title) #Assign window title
        if Platform == "Windows":
            Frame_Message.iconbitmap(Favicon)  # Set favicon
            Frame_Message.grab_set()  # Prevents other Tkinter windows from being used (Does not work on Pi when root window is full screen as splash screen)

        x = TapStatus.RootWindow.winfo_x()  # Get X coordinate of root
        y = TapStatus.RootWindow.winfo_y()  # Get Y coordinate of root
        Frame_Message.geometry("+%d+%d" % (x + 100, y + 150)) #Place message window at these coordinates (roughly middle of root window)

        # Top/Bottom Frames
        Frame_Top = tk.Frame(Frame_Message)
        Frame_Top.pack(side=tk.TOP, fill=tk.BOTH, expand=tk.TRUE, padx = 15)
        Frame_Bottom = tk.Frame(Frame_Message, bg=SG)
        Frame_Bottom.pack(side=tk.BOTTOM, fill=tk.X)

        # Image on left
        if Type == "Info":
            Path_Img = Path_ImgSoundboard
        if Type == "Warning":
            Path_Img = Path_ImgRules
        elif Type == "Error":
            Path_Img = Path_ImgSkull

        ImgWidth = 110
        ImgHeight = 110

        try:
            photo = ImageTk.PhotoImage(Image.open(Path_Img).resize((ImgWidth, ImgHeight)))
        except:
            photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
        Lbl_Image = tk.Label(Frame_Top, image=photo)
        Lbl_Image.image = photo
        Lbl_Image.pack(side=tk.LEFT)

        # Message on right
        Lbl_Message = tk.Label(Frame_Top, text=Message, font=F4, justify=tk.LEFT)
        Lbl_Message.pack(side=tk.LEFT, padx=4)

        # Ok Button
        ImgWidth = 60
        ImgHeight = 60
        BtnWidth = 160
        BtnHeight = 40
        FontSize = F4

        try:
            photo = ImageTk.PhotoImage(Image.open(Path_ImgSpeaker).resize((ImgWidth, ImgHeight)))
        except:
            photo = ImageTk.PhotoImage(Image.open('Ghost.png').resize((ImgWidth, ImgHeight)))
        Lbl_Image = tk.Label(Frame_Bottom, image=photo)
        Lbl_Image.image = photo
        Btn_Ok = tk.Button(Frame_Bottom, text="I hear you! ", width=BtnWidth, height=BtnHeight, bd=1, image=Lbl_Image.image, bg=self.Color, compound=tk.LEFT, font=FontSize, fg=self.TextColor2, anchor=tk.W)
        Btn_Ok.pack(side=tk.RIGHT, padx=4, pady=4, anchor=tk.E)
        Btn_Ok.config(command=lambda: ErrorHandling.ClickOK(self, Frame_Message))
        Btn_Ok.focus_set()
        Btn_Ok.bind('<Return>', lambda a: ErrorHandling.ClickOK(self, Frame_Message)) #Bind "Enter" button to ClickOK function

        Frame_Message.lift()

    #Click OK on message box
    def ClickOK(self, Frame):

        Frame.destroy() #Destroy message box

#Called when focus changes between entry boxes (This needs to stay outside of a class)
def remember_focus(event):

    try:

        global focused_entry
        focused_entry = event.widget  # creates global variable that stores the widget that has focus

    except:

        print("Error with remember_focus")